﻿if not myAutoMacro then
	return
end

-- library initialization
local MAM = myAutoMacro
local L = LibStub("AceLocale-3.0"):GetLocale("myAutoMacro", true)

-- cache
local print, string, tonumber, tostring, format, wipe, table, type, pairs, ipairs  = print, string, tonumber, tostring, format, wipe, table, type, pairs, ipairs
local _



-- housekeeping functions ------------------

local function DeepCopy(src)
	local res = {}
    for k, v in pairs(src) do
        if type(v) == "table" then
            v = DeepCopy(v)
        end
        res[k] = v
    end
    return res
end



-- databases -------------------------------

-- zone type
local zoneType = {
	L["None"], -- no zone selected
	L["Raid"], -- raid
	L["Dungeon"], -- dungeon
	L["Battleground"], -- bg
	L["Arena"], -- arena
	L["Capital"], -- alliance or horde or neutral capitals
	L["World"], -- rest of the world
}

-- zone id by type
local zoneID = {
	[2] = {
		824, -- Dragon Soul
		800, -- Firelands
		773, -- Throne of The Four Winds
		758, -- Bastion of Twilight
		754, -- Blackwing Descent
		752, -- Baradin Hold
	},
	[3] = {
		819, -- Hour of Twilight
		820, -- End Time
		816, -- Well of Eternity
		793, -- Zul'Gurub
		781, -- Zul'Aman
		769, -- The Vortex Pinnacle
		768, -- The Stonecore
		767, -- Throne Of The Tides
		764, -- Shadowfang Keep
		759, -- Halls Of Origination
		757, -- Grim Batol
		756, -- Deadmines
		753, -- Blackrock Caverns
		747, -- Lost City Of The Tolvir
	},
	[6] = {
		301, -- Stormwind
		341, -- Ironforge
		381, -- Darnassus
		471, -- The Exodar
		321, -- Orgrimmar
		362, -- ThunderBluff
		382, -- Undercity
		480, -- Silvermoon City
		504, -- Dalaran
		481, -- Shattrah
	},
	[7] = {
		-90, -- anywhere
	},
	[4] = {
		401, -- Alterac Valley
		443, -- Warsong Gulsh
		461, -- Arathi Basin
		482, -- Eye of the Storm
		540, -- Isle of Conquest
		512, -- Strand of the Ancient
		626, -- Twin Peaks
		736, -- The Battle for Gilneas
		},
	[5] = {
		-80, -- Blade's Edge Arena
		-79, -- Nagrand Arena
		-78, -- Ruins of Lordaeron
		-77, -- Dalaran Arena
		-76, -- The Ring of Valor
	},
	[1] = {
	},
}

-- arena translation table
local arenaTable = {
	["enUS"] = {
		["Blade's Edge Arena"] = -80,
		["Nagrand Arena"] = -79,
		["Ruins of Lordaeron"] = -78,
		["Dalaran Arena"] = -77,
		["The Ring of Valor"] = -76,
	},
	["deDE"] = {
		["Arena des Schergrats"] = -80,
		["Arena von Nagrand"] = -79,
		["Ruinen von Lordaeron"] = -78,
		["Arena von Dalaran"] = -77,
		["Der Ring der Ehre"] = -76,
	},
	["frFR"] = {
		["Arène des Tranchantes"] = -80,
		["Arène de Nagrand"] = -79,
		["Ruines de Lordaeron"] = -78,
		["Arène de Dalaran"] = -77,
		["L'Arène des valeureux"] = -76,
	},
	["koKR"] = {
		["칼날 투기장"] = -80,
		["나그란드 투기장"] = -79,
		["로데론의 폐허"] = -78,
		["달라란 투기장"] = -77,
		["용맹의 투기장"] = -76,
	},
	["esES"] = {
		["Arena Filospada"] = -80,
		["Arena de Nagrand"] = -79,
		["Ruinas de Lordaeron"] = -78,
		["Arena de Dalaran"] = -77,
		["El Anillo del Valor"] = -76,
	},
	["esMX"] = {
		["Arena Filospada"] = -80,
		["Arena de Nagrand"] = -79,
		["Ruinas de Lordaeron"] = -78,
		["Arena de Dalaran"] = -77,
		["El Círculo del Valor"] = -76,
	},
	["ptBR"] = {
		["Arena da Lâmina Afiada"] = -80,
		["Arena de Nagrand"] = -79,
		["Ruínas de Lordaeron"] = -78,
		["Arena de Dalaran"] = -77,
		["Ringue dos Valorosos"] = -76,
	},
	["ruRU"] = {
		["Арена Острогорья"] = -80,
		["Арена Награнда"] = -79,
		["Руины Лордерона"] = -78,
		["Арена Даларана"] = -77,
		["Круг Доблести"] = -76,
	},
	["zhCN"] = {
		["刀锋山竞技场"] = -80,
		["纳格兰竞技场"] = -79,
		["洛丹伦废墟"] = -78,
		["达拉然竞技场"] = -77,
		["勇气竞技场"] = -76,
	},
	["zhTW"] = {
		["劍刃競技場"] = -80,
		["納葛蘭競技場"] = -79,
		["羅德隆廢墟"] = -78,
		["達拉然競技場"] = -77,
		["勇武之環"] = -76,
	},
}

-- boss ids by zone
local bossID = {
	[824] = {
		[55265] = L["Morchok"],
		[55308] = L["Warlord Zon'ozz"],
		[55312] = L["Yor'sahj"],
		[55689] = L["Hagara"],
		[55294] = L["Ultraxion"],
		[55870] = L["Warmaster Blackhorn"], -- captain swaze
		[55891] = L["Warmaster Blackhorn"], -- ka'anu reevs
		[-55870] = L["Spine of Deathwing"], -- we detect spine using again captain swaze, see /myAutomacro.lua and options. we use dummy -swaze here for listing and registring of the macro
		[-55891] = L["Spine of Deathwing"], -- -ka'anu reevs
		[56103] = L["Madness of Deathwing"], -- thrall
	}, -- Dragon Soul
	[800] = {
		[52498] = L["Beth'tilac"],
		[52577] = L["Lord Rhyolith"], -- left foot
		[53087] = L["Lord Rhyolith"], -- right foot
		[54015] = L["Alysrazor"], -- majordomo
		[53691] = L["Shannox"],
		[53695] = L["Shannox"], -- rageface
		[53694] = L["Shannox"], -- riplimb
		[53494] = L["Baleroc"],
		[52571] = L["Majordomo Staghelm"],
		[52409] = L["Ragnaros"],
	}, -- Firelands
	[773] = {
		[45870] = L["Conclave of Wind"], -- anshal
		[45871] = L["Conclave of Wind"], -- nezir
		[45872] = L["Conclave of Wind"], -- rohash
		[46753] = L["Al'Akir"],
	}, -- Throne of The Four Winds
	[758] = {
		[44600] = L["Halfus Wyrmbreaker"],
		[44687] = L["Halfus Wyrmbreaker"], -- proto-behemoth
		[44652] = L["Halfus Wyrmbreaker"], -- slate dragon
		[44645] = L["Halfus Wyrmbreaker"], -- nether scion
		[44797] = L["Halfus Wyrmbreaker"], -- time warden
		[44650] = L["Halfus Wyrmbreaker"], -- storm rider
		[44641] = L["Halfus Wyrmbreaker"], -- welps
		[45993] = L["Valiona and Theralion"], -- theralion
		[45992] = L["Valiona and Theralion"], -- valiona
		[43687] = L["Ascendant Council"], -- feludius
		[43686] = L["Ascendant Council"], -- ignacious
		[43688] = L["Ascendant Council"], -- arion
		[43689] = L["Ascendant Council"], -- terrastra
		[43324] = L["Cho'gall"],
		[45213] = L["Sinestra"],
	}, -- Bastion of Twilight
	[754] = {
		[41570] = L["Magmaw"],
		[42180] = L["Omnotron Defense System"], -- toxitron
		[42166] = L["Omnotron Defense System"], -- arcanotron
		[42179] = L["Omnotron Defense System"], -- electron
		[42178] = L["Omnotron Defense System"], -- electron
		[41378] = L["Maloriak"],
		[41442] = L["Atramedes"],
		[43296] = L["Chimaeron"],
		[44202] = L["Chimaeron"], -- finkle
		[44418] = L["Chimaeron"], -- bile-o-tron
		[41376] = L["Nefarian"],
		[41270] = L["Nefarian"], -- onyxia
	}, -- Blackwing Descent
	[752] = {
		[47120] = L["Argaloth"],
		[52363] = L["Occu'thar"],
		[55869] = L["Alizabal"],
	}, -- Baradin Hold
	[819] = {
		[54590] = L["Arcurion"],
		[54968] = L["Asira Dawnslayer"],
		[54938] = L["Archbishop Benedictus"],		
	}, -- Hour of Twilight
	[820] = {
		[54431] = L["Echo of Baine"],
		[54445] = L["Echo of Jaina"],
		[54123] = L["Echo of Sylvanas"],		
		[54544] = L["Echo of Tyrande"],
		[54432] = L["Murozond"],
	}, -- End Time
	[816] = {
		[55085] = L["Peroth'arn"],
		[54853] = L["Queen Azshara"],
		[54969] = L["Mannoroth and Captain Varo'then"], -- mannoroth
		[55419] = L["Mannoroth and Captain Varo'then"], -- varo'then
	}, -- Well of Eternity
	[793] = {
		[52155] = L["High Priest Venoxis"],
		[52151] = L["Bloodlord Mandokir"],
		[52059] = L["High Priestess Kilnara"],
		[52053] = L["Zanzil"],
		[52148] = L["Jin'do the Godbreaker"],
	}, -- Zul'Gurub
	[781] = {
		[23574] = L["Akil'zon"],
		[23576] = L["Nalorakk"],
		[23578] = L["Jan'alai"],
		[23577] = L["Halazzi"],
		[24239] = L["Hex Lord Malacrass"],
		[23863] = L["Daakara"],
	}, -- Zul'Aman
	[769] = {
		[43878] = L["Grand Vizier Ertan"],
		[43873] = L["Altairus"],
		[43875] = L["Asaad"],
	}, -- The Vortex Pinnacle
	[768] = {
		[43438] = L["Corborus"],
		[43214] = L["Slabhide"],
		[42188] = L["Ozruk"],
		[42333] = L["High Priestess Azil"],
	}, -- The Stonecore
	[767] = {
		[40586] = L["Lady Naz'jar"],
		[40765] = L["Commander Ulthok"],
		[40825] = L["Erunak Stonespeaker"],
		[40792] = L["Ozumat"], -- neptulon
	}, -- Throne Of The Tides
	[764] = {
		[46962] = L["Baron Ashbury"],
		[3887] = L["Baron Silverlaine"],
		[4278] = L["Commander Springvale"],
		[46963] = L["Lord Walden"],
		[46964] = L["Lord Godfrey"],
	}, -- Shadowfang Keep
	[759] = {
		[39425] = L["Temple Guardian Anhuur"],
		[39428] = L["Earthrager Ptah"],
		[39788] = L["Anraphet"],
		[39587] = L["Isiset"],
		[39731] = L["Setesh"],
		[39378] = L["Rajh"],
	}, -- Halls Of Origination
	[757] = {
		[39625] = L["General Umbriss"],
		[40177] = L["Forgemaster Throngus"],
		[40319] = L["Drahga Shadowburner"],
		[40484] = L["Erudax"],
	}, -- Grim Batol
	[756] = {
		[47162] = L["Glubtok"],
		[47296] = L["Helix Gearbreaker"],
		[43778] = L["Foe Reaper 5000"],
		[47626] = L["Admiral Ripsnarl"],
		[47739] = L["\"Captain\" Cookie"],
		[49541] = L["Vanessa VanCleef"],
	}, -- Deadmines
	[753] = {
		[39665] = L["Rom'ogg Bonecrusher"],
		[39679] = L["Corla"],
		[39698] = L["Karsh Steelbender"],
		[39700] = L["Beauty"],
		[39705] = L["Ascendant Lord Obsidius"],
	}, -- Blackrock Caverns
	[747] = {
		[44577] = L["General Husam"],
		[43612] = L["High Prophet Barim"],
		[43614] = L["Lockmaw & Augh"], -- lockmaw
		[44819] = L["Siamat"],
	}, -- Lost City Of The Tolvir
}



-- getter functions ------------------------

-- zone type
function MAM:GetZoneType()
	return zoneType
end

-- boss
function MAM:GetBoss(zone)
	local list = {}
	if bossID[zone] then
		list = DeepCopy(bossID[zone])
	end
	list[-100] = L["None"]

	return list
end

-- boss table
function MAM:GetBossTable()
	return DeepCopy(bossID)
end

-- boss name
function MAM:GetBossName(zone, ID)
	if bossID[zone] then
		if bossID[zone][ID] then
			return bossID[zone][ID]
		end
	end
	return ""
end

-- zone
function MAM:GetZone(zoneType)
	local list = {}
	if zoneID[zoneType] then
		list = DeepCopy(zoneID[zoneType])
	end
	table.insert(list, 1, -100)
	
	return list
end

-- arena id
function MAM:GetArenaID(locale, name)
	return arenaTable[locale][name]
end

-- arena table per locale
function MAM:GetArenaTablePerLocale(locale)
	return arenaTable[locale]
end

