﻿--[[
Title: myAutoMacro
Author: Istaran | Medivh - EU
Version: 1.2.2
Release date: 2012-10-21T15:53:51Z
myAutoMacro is licensed under GPLv3.
]]


-- ace addon creation and constants ---

myAutoMacro = LibStub("AceAddon-3.0"):NewAddon("myAutoMacro", "AceConsole-3.0", "AceEvent-3.0", "AceComm-3.0")
local MAM = myAutoMacro

-- ACE library initialization
local L = LibStub("AceLocale-3.0"):GetLocale("myAutoMacro", true)
local ACR = LibStub("AceConfigRegistry-3.0")
local AIS = LibStub("LibAdvancedIconSelector-1.0", true)

-- cache
local print, string, tonumber, tostring, format, wipe, table, type, pairs, ipairs  = print, string, tonumber, tostring, format, wipe, table, type, pairs, ipairs
local _

-- constants
MAM.NORMAL_COLOR = "|cff00E6E3"
MAM.HIGHLIGHT_COLOR = "|cffFF8000"
MAM.FORMATED_ADDON_NAME = MAM.NORMAL_COLOR .. L["myAutoMacro: "]
MAM.MAX_AUTOMACRO = 5
MAM.MACRO_PREFIX = "mAM#"
MAM.MACRO_SUFFIX = "_"
MAM.MACRO_DEFAULT_ICON = "ACHIEVEMENT_GUILDPERK_FASTTRACK_RANK2"
MAM.ADDON_PREFIX = "myAutoMacro_com"
--[===[@debug@
MAM.VERSION = "1.0.#"
--@end-debug@]===]
MAM.VERSION = MAM.VERSION or GetAddOnMetadata("myAutoMacro", "Version")


-- default settings
MAM.defaults = {
	profile = {
		general = {
			macroNumber = 1,
			verbose = true,
			splashMessage = false,
			printZoneID = false,
			printNPCID = false,
			incomming = true,
			perChar = true,
		},
	},
}



-- housekeeping functions ------------------

local function HlString(str)
	return MAM.HIGHLIGHT_COLOR .. str .. MAM.NORMAL_COLOR
end



-- addon loading ---------------------------

-- loading
function MAM:OnEnable()
	-- user data
	MAM.db = LibStub("AceDB-3.0"):New("myAutoMacro_data", MAM.defaults)
	MAM.db.RegisterCallback(self, "OnProfileChanged", "ProfileChanged")
	MAM.db.RegisterCallback(self, "OnProfileCopied", "ProfileChanged")
	MAM.db.RegisterCallback(self, "OnProfileReset", "ProfileChanged")
	MAM.db.global.library = MAM.db.global.library or {}
	MAM.db.global.custom = MAM.db.global.custom or {}
	MAM.db.global.custom.npc = MAM.db.global.custom.npc or {}
	MAM.db.global.custom.zone = MAM.db.global.custom.zone or {}
	MAM.db.global.blacklisted = MAM.db.global.blacklisted or {}
	-- current macros are stored in the user db to avoid unnecessary switching on login and allow switch of non per character stored macro when user logs with a different character
	MAM.db.profile.currentMacros = MAM.db.profile.currentMacros or {}

	-- chat command
	MAM:RegisterChatCommand("myAutoMacro","SlashCommands")
	MAM:RegisterChatCommand("mam", "SlashCommands")

	-- event registring
	-- ZONE_CHANGED_NEW_AREA isn't triggered when UI is reload (but is triggered upon login). To identify the zone after a reload, we listen to PLAYER_LOGIN.
	-- This raises an issue as upon login, the function is called 2 times. The first call returns 14 in Azeroth for exemple
	-- However, when used as argument for GetMapNameByID(), the function returns nil.
	MAM:RegisterEvent("ZONE_CHANGED_NEW_AREA", "IdentifyZone")
	MAM:RegisterEvent("PLAYER_LOGIN", "IdentifyZone")
	MAM:RegisterEvent("UNIT_TARGET", "TargetChanged")
	MAM:RegisterEvent("UPDATE_MOUSEOVER_UNIT", "MouseOverChanged")
	MAM:RegisterEvent("PLAYER_REGEN_DISABLED", "StartCombat")
	MAM:RegisterEvent("PLAYER_REGEN_ENABLED", "EndCombat")
	MAM:RegisterEvent("PLAYER_TALENT_UPDATE", "UpdateIconList")

	-- communication
	MAM:RegisterComm(MAM.ADDON_PREFIX, "IncommingMacro")

	-- queud macros table
	MAM.queuedMacros = {}

	-- recap table
	MAM.assoList = {}

	-- get current locale
	MAM.locale = GetLocale()

	-- create example macro only one time
	MAM:CreateExampleMacro()

	if not InCombatLockdown() then
		MAM:FullInit()
	else
		MAM.mustFinishInit = true
	end
end

-- no combat requiring init
function MAM:FullInit()
	-- create macros
	MAM:CreateMacros()

	-- load configuration
	MAM:LoadConfig()

	-- splash message
	if MAM.db.profile.general.splashMessage then
		print(MAM.NORMAL_COLOR .. "myAutoMacro v" .. MAM.VERSION .. L[" loaded."])
	end
end

function MAM:CreateExampleMacro()
	if not MAM.db.global.exampleCreated then
		libID = #MAM.db.global.library + 1
		MAM.db.global.library[libID] = {}
		MAM.db.global.library[libID].name = L["Targetting example"]
		MAM.db.global.library[libID].body = "/tar least important target\n/tar important target\n/targetlasttarget [@target,dead]\n/tar most important target\n/targetlasttarget [@target,dead]"
		MAM.db.global.library[libID].texture = MAM.MACRO_DEFAULT_ICON
		MAM.db.global.exampleCreated = true
	end
end



-- automacro creation ----------------------

-- macros creation
function MAM:CreateMacros()
	-- tables and local vars
	MAM.db.profile.macro = MAM.db.profile.macro or {}
	local maxMacro = 36 -- ig max number of global macros

	-- create macro infos
	for i = 1, MAM.db.profile.general.macroNumber do
		-- initialize currentMacro field. As macro are on global storing, we need to check that the current macro hasn't been deleted from another character.
		-- if yes, we reset the current macro
		MAM.db.profile.currentMacros[i] = MAM.db.profile.currentMacros[i] or ""
		if not MAM.db.global.library[MAM.db.profile.currentMacros[i]] or MAM.db.global.library[MAM.db.profile.currentMacros[i]] == "deleted" then
			MAM.db.profile.currentMacros[i] = ""
		end

		-- creates tables in user db
		MAM.db.profile.macro[i] = MAM.db.profile.macro[i] or {}
		MAM.db.profile.macro[i].zone = MAM.db.profile.macro[i].zone or {}
		MAM.db.profile.macro[i].npc = MAM.db.profile.macro[i].npc or {}

		-- checks whether we already have a macro in game, first by name, and if not, by going through all the macro looking for a mAM prefix and resetting the currentMacro part
		local macroName = ""
		if MAM.db.global.library[MAM.db.profile.currentMacros[i]] then
			macroName = MAM.db.global.library[MAM.db.profile.currentMacros[i]].name
		end
		local isMacro = GetMacroInfo(MAM.MACRO_PREFIX .. i .. MAM.MACRO_SUFFIX .. macroName)
		if not isMacro then
			for index = 1, maxMacro do
				if GetMacroInfo(index) and string.find(GetMacroInfo(index), MAM.MACRO_PREFIX .. i) then
					isMacro = true
					EditMacro(index, MAM.MACRO_PREFIX .. i .. MAM.MACRO_SUFFIX, MAM.MACRO_DEFAULT_ICON)
					MAM.db.profile.currentMacros[i] = ""
				end
			end
		end

		-- creates effectively a new ig macro
		if not isMacro then
			if GetNumMacros() < 36 then
				CreateMacro(MAM.MACRO_PREFIX .. i .. MAM.MACRO_SUFFIX, MAM.MACRO_DEFAULT_ICON, "")
				MAM.db.profile.macro[i].texture = MAM.MACRO_DEFAULT_ICON
			else
				MAM:MacroCreationError(i)
			end
		end
	end

	-- delete unused automacros, we use directly macro indexes
	local unused = MAM.db.profile.general.macroNumber + 1
	while unused <= MAM.MAX_AUTOMACRO do
		local index = maxMacro
		while index >= 1 do
			if GetMacroInfo(index) and string.find(GetMacroInfo(index), MAM.MACRO_PREFIX .. unused) then
				DeleteMacro(index)
			end
			 index = index - 1
		end
		unused = unused + 1
	end
end

-- macro creation error
function MAM:MacroCreationError(num)
	print(MAM.FORMATED_ADDON_NAME .. format(L["The creation of %s has failed because of a lack of storage space."], HlString("Automacro" .. num)))
	UIErrorsFrame:AddMessage(MAM.FORMATED_ADDON_NAME .. format(L["The creation of %s has failed because of a lack of storage space."], HlString("Automacro" .. num)))
end



-- macro body editing ----------------------

-- zone identification
function MAM:IdentifyZone(mode)
	-- normal zoning
	local zoneID = GetCurrentMapAreaID()
	local zoneNameByID = GetMapNameByID(zoneID)
	local doNotChanged = false

	-- we need this for arena only (though it will be triggered each time the function is called)
	local arenaID = MAM:GetArenaID(MAM.locale, GetRealZoneText())
	if arenaID then
		zoneID = arenaID
	end

	-- changes automacro if not targeting a npc for which we have a macro
	if UnitExists("target") then
		doNotChanged = MAM:IdentifyNPC(UnitGUID("target"), "player", "checkOnly")
	end
	if not doNotChanged then
		MAM:AutomacroUpdating("zone", zoneID)
	end

	-- help provided to user to add new zones
	if MAM.db.profile.general.printZoneID and zoneNameByID and mode ~= "silent" then
		print(MAM.FORMATED_ADDON_NAME .. HlString(zoneNameByID) .. L[" ID: "] .. HlString(zoneID))
	end
end

-- npc identification, @unit is unitid of the unit who has seen the npc
function MAM:IdentifyNPC(GUID, unit, mode)
	local unit = unit or "player"
	-- extracts unit type
	local unitType = bit.band(tonumber(string.sub(GUID, 5, 5)), 0x7)

	-- checks whether it is an npc, converts hex to dec and change automacro
	if unitType == 3 or unitType == 5 then
		local npcID = tonumber("0x" .. string.sub(GUID, 6, 10))
		local isInDB

		-- see comment in function SpecialNPCHandler()
		if npcID == 55870 or npcID == 55891 then
			MAM:RegisterEvent("UPDATE_INSTANCE_INFO", "SpecialNPCHandler")
			MAM.pendingID = npcID
			MAM.pendingMode = mode
			RequestRaidInfo()
		else
			isInDB = MAM:AutomacroUpdating("npc", npcID, mode)
		end

		-- help provided to user to add new npcs
		if MAM.db.profile.general.printNPCID and unit == "player" and (mode ~= "silent" or mode ~= "checkOnly") then
			print(MAM.FORMATED_ADDON_NAME .. L["ID of this npc is: "] .. HlString(npcID))
		end

		-- if checkmode
		if mode == "checkOnly" then
			return isInDB
		end
	end
end

-- handling of special NPC
function MAM:SpecialNPCHandler()
	-- we can only rely on the same npc for Blackhorn and Spine encounter (swaze and reevs). So we test for the number of boss defeated and replace the ID by the dummy -ID
	-- -ID is associated with the correct encounter (Spine) in the addon db. Works in another way for LFR and works partially as I didn't find a way to test it more than once a week

	local numInstanceSaved = GetNumSavedInstances()
	local currentInstance, currentInstType = GetInstanceInfo()
	local ID = MAM.pendingID
	local mode = MAM.pendingMode

	if MAM.pendingID then
		if IsPartyLFG() and IsInLFGDungeon() and currentInstType == "raid" then
			local _, _, blackHDead = GetLFGDungeonEncounterInfo(417, 6) -- blackhorn
			if blackHDead then
				ID = -ID
			end
		else
			local i = 1
			while i <= numInstanceSaved do
				local name, _, _, _, _, _, _, _, _, _, _, bossDead = GetSavedInstanceInfo(i)
				if name == currentInstance then
					if bossDead >= 6 then
						ID = -ID
					end
					break
				end
				i = i + 1
			end
		end
	end

	MAM:UnregisterEvent("UPDATE_INSTANCE_INFO")
	MAM:AutomacroUpdating("npc", ID, mode)
	MAM.pendingID = nil
	MAM.pendingMode = nil
end

-- automacros updating, cycling through each automacro
function MAM:AutomacroUpdating(macroType, ID, mode)
	for i = 1, MAM.db.profile.general.macroNumber do
		-- we need to initialize queued macro tables here on the very first call
		MAM.queuedMacros[i] = MAM.queuedMacros[i] or {}

		-- check when we need to decide if we must change the macro on zone change and we have a target. Function is stopped there if true
		if mode == "checkOnly" and MAM.db.profile.macro[i][macroType][ID] == MAM.db.profile.currentMacros[i] then
			return true
		end

		-- checking if zone or npc has a macro associated in user db and if automacro isn't already using the good macro
		if MAM.db.profile.macro[i][macroType][ID] and MAM.db.profile.macro[i][macroType][ID] ~= MAM.db.profile.currentMacros[i]  then
			MAM:SetMacro(macroType, ID, i)
		end
	end
end

-- macro updating
function MAM:SetMacro(macroType, ID, i)
	-- we fetch the library to get the library id associated with the NPC/zone ID for macro i
	local libID = MAM.db.profile.macro[i][macroType][ID]

	if not InCombatLockdown() then
		-- registers old macro name
		local macroOldName = ""
		if MAM.db.global.library[MAM.db.profile.currentMacros[i]] then
			macroOldName = MAM.db.global.library[MAM.db.profile.currentMacros[i]].name
		end
		-- gets new macro
		local macroNewName = MAM.db.global.library[libID].name
		local macroBody = MAM.db.global.library[libID].body
		local macroIcon = MAM.db.global.library[libID].texture

		-- edits macro in game
		EditMacro(MAM.MACRO_PREFIX .. i .. MAM.MACRO_SUFFIX .. macroOldName, MAM.MACRO_PREFIX .. i .. MAM.MACRO_SUFFIX .. macroNewName, macroIcon, macroBody)

		-- registers current macro for each automacro
		MAM.db.profile.currentMacros[i] = libID

		-- prints chat message
		MAM:PrintAutoMacroState("macroUpdated", libID, i)
	else
		-- stores called automacros if combat lockdown is active. They will be set up as soon as player is out of combat
		MAM.mustUpdateMacro = true
		MAM.queuedMacros[i].macroType = macroType
		MAM.queuedMacros[i].ID = ID

		-- prints chat message
		MAM:PrintAutoMacroState("macroQueued", libID, i)
	end
end

-- queued macros updating
function MAM:UpdateQueuedMacros()
	for i = 1, MAM.db.profile.general.macroNumber do
		if MAM.queuedMacros[i].macroType and MAM.queuedMacros[i].ID then
			MAM:SetMacro(MAM.queuedMacros[i].macroType, MAM.queuedMacros[i].ID, i)
			MAM.queuedMacros[i].macroType = nil
			MAM.queuedMacros[i].ID = nil
		end
	end
end

-- chat message
function MAM:PrintAutoMacroState(state, libID, i)
	if MAM.db.profile.general.verbose then
		print(MAM.FORMATED_ADDON_NAME .. format(L[state], HlString("Automacro" .. i), HlString(MAM.MACRO_PREFIX .. i .. MAM.MACRO_SUFFIX .. MAM.db.global.library[libID].name)))
	end
end



-- helper functions ------------------------

-- target GUID
function MAM:TargetChanged(event, unit)
	local GUID = UnitGUID(unit .. "target")
	if GUID then
		MAM:IdentifyNPC(GUID, unit)
	end
end

-- mouseover GUID
function MAM:MouseOverChanged()
	local GUID = UnitGUID("mouseover")
	if GUID then
		MAM:IdentifyNPC(GUID)
	end
end

-- generic in combat watching
function MAM:StartCombat()
	MAM.inCombat = true
	ACR:NotifyChange("myAutoMacro")
end

function MAM:EndCombat()
	MAM.inCombat = false
	ACR:NotifyChange("myAutoMacro")
	if MAM.mustFinishInit then
		MAM:FullInit()
	elseif MAM.mustUpdateMacro then
		MAM:UpdateQueuedMacros()
	end
end

-- update icon list
function MAM:UpdateIconList()
	if MAM.iconSearchObj then
		local spellIcons = MAM:GetSpellMacroIcons()
		local SpellIcons = {
			count = #spellIcons,
			GetIconInfo = function(index)
				return index, "Spell", spellIcons[index]
			end,
		}

		MAM.iconSearchObj:ReplaceSection("SpellIcons", SpellIcons)
	end
end



-- comm functions --------------------------

-- receiving
function MAM:IncommingMacro(prefix, message, canal, sender)
	-- early return in case a undesired message arrives here/we receive a self sent message
	if not MAM.db.profile.general.incomming or prefix ~= MAM.ADDON_PREFIX or sender == UnitName("player") or MAM.db.global.blacklisted[sender] then
		return
	end

	-- decode the message
	local macroName = MAM:DecodeMacro(message)

	-- pops the frame
	if not MAM.incommingFrame then
		MAM:CreateIncommingFrame()
	end
	MAM.incommingFrame:Show()
	MAM.incommingFrame.txt:SetText(format(L["%s wishes to share the macro %s with you. Do you accept?"], HlString(sender), HlString(macroName)))
end

-- frame for incomming macro
function MAM:CreateIncommingFrame()
	-- main frame
	MAM.incommingFrame = CreateFrame("Frame", nil, UIParent)
	local frame = MAM.incommingFrame
	local width, height = 350, 150
	frame:SetWidth(width)
	frame:SetHeight(height)
	frame:SetPoint("Center", UIParent, "Center", 0, 250)
	frame:SetBackdrop({	bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background", edgeFile = "Interface\\Buttons\\WHITE8X8", edgeSize = 2})
	frame:SetBackdropBorderColor(0, 0.9, 0.89)
	frame:EnableMouse(true)
	frame:SetMovable(true)

	frame:SetScript("OnMouseDown", function()
		frame:StartMoving()
	end)
	frame:SetScript("OnMouseUp", function()
		frame:StopMovingOrSizing()
	end)
	frame:Hide()

	-- title
	local title = CreateFrame("Frame", nil, frame)
	title:SetHeight(25)
	title:SetPoint("TOP", frame, "TOP", 0, -10)
	title:SetBackdrop({	bgFile = "", edgeFile = "Interface\\Buttons\\WHITE8X8", edgeSize = 0.75})
	title:SetBackdropBorderColor(0, 0.9, 0.89)
	title.txt = title:CreateFontString()
	title.txt:SetPoint("CENTER", title, "CENTER")
	title.txt:SetFont("Fonts\\FRIZQT__.TTF", 12)
	title.txt:SetShadowColor(0, 0, 0, 1)
	title.txt:SetShadowOffset(1, -1)
	title.txt:SetTextColor(0, 0.9, 0.89)
	title.txt:SetText(L["Incomming macro!"])
	title:SetWidth(title.txt:GetStringWidth() * 1.1)

	-- buttons
	local reject = CreateFrame("Button", nil, frame, "OptionsButtonTemplate")
	reject:SetPoint("BOTTOMLEFT", frame, "BOTTOM", 30, 10)
	reject:SetText(L["Reject"])
	reject:SetScript("OnClick", function()
		frame:Hide()
	end)
	local accept = CreateFrame("Button", nil, frame, "OptionsButtonTemplate")
	accept:SetPoint("BOTTOMRIGHT", frame, "BOTTOM", -30, 10)
	accept:SetText(L["Accept"])
	accept:SetScript("OnClick", function()
		local libID = #MAM.db.global.library + 1
		MAM.db.global.library[libID] = {}
		MAM.db.global.library[libID].name = MAM.macroParam[1]
		MAM.db.global.library[libID].texture = MAM.macroParam[2]
		MAM.db.global.library[libID].body = MAM.macroParam[3]
		ACR:NotifyChange("myAutoMacro")

		wipe(MAM.macroParam)
		frame:Hide()
	end)

	-- text
	frame.txt = frame:CreateFontString()
	frame.txt:SetPoint("LEFT", frame, "LEFT", 20, 0)
	frame.txt:SetPoint("RIGHT", frame, "RIGHT", -20, 0)
	frame.txt:SetHeight(100)
	frame.txt:SetFont("Fonts\\FRIZQT__.TTF", 12)
	frame.txt:SetShadowColor(0, 0, 0, 1)
	frame.txt:SetShadowOffset(1, -1)
	frame.txt:SetWordWrap(true)
end

-- code function, takes name, icon path and body as @. Returns a string with open/close markups
function MAM:CodeMacro(macroName, macroIcon, macroBody)
	return "#mam/" .. macroName .. "/mam##mam/" .. macroIcon .. "/mam##mam/" .. macroBody .. "/mam#"
end

-- decode function, takes a string as @, returns 3 values being name/icon/body of the macro
function MAM:DecodeMacro(macroString)
	MAM.macroParam = MAM.macroParam or {}
	for value in string.gmatch(macroString, "#mam/.-/mam#") do
		value = string.gsub(value, "#mam/", "")
		value = string.gsub(value, "/mam#", "")
		table.insert(MAM.macroParam, value)
	end

	return MAM.macroParam[1], MAM.macroParam[2], MAM.macroParam[3]
end



-- configuration ---------------------------

-- slash commands
function MAM:SlashCommands(cmd)
	local argTable = {}
	local i = 1
	for arg in string.gmatch(cmd, "[^%s]+") do
		if i > 3 then
			argTable[3] = argTable[3] .. " " .. arg
		else
			argTable[i] = arg
		end
		i = i + 1
	end

	if argTable[1] == "config" then
		InterfaceOptionsFrame_OpenToCategory("myAutoMacro")
	elseif argTable[1] == "detect" then
		MAM:IdentifyZone()
		MAM:MouseOverChanged()
	elseif argTable[1] == "help" then
		print(MAM.FORMATED_ADDON_NAME)
		print(MAM.NORMAL_COLOR .. L["Commands are:"])
		print(HlString("config") .. L[" to open configuration pannel."])
		print(HlString("detect") .. L[" to detect the current zone."])
		print(HlString("switch") .. L[" to switch a given automacro to a given macro."])
		print(HlString("show") .. L[" to show current association of your automacros."])
		print(HlString("help") .. L[" this dialog."])
	elseif argTable[1] == "switch" then
		local switchDone
		if argTable[3] and argTable[2] then
			switchDone = MAM:SwitchMacro(MAM:GetLibraryMacroIndex(argTable[3]), argTable[2])
		end
		if not switchDone then
			print(MAM.FORMATED_ADDON_NAME .. format(L["Switch arguments must be: switch %s %s."], HlString(L["\"automacro number\""]), HlString(L["\"macro name\""])))
		end
	elseif argTable[1] == "show" then
		MAM:ShowAssociations()
		MAM.showAssoFromCmd = true
	else
		print(MAM.NORMAL_COLOR .. "myAutoMacro v" .. tostring(MAM.VERSION) .. " | Istaran - Medivh EU.")
		print(MAM.FORMATED_ADDON_NAME .. L["Please type \/mam help to get help."])
	end
end

-- load configuration
function MAM:LoadConfig()
	MAM.options = MAM:DummyOptions()
	ACR:RegisterOptionsTable("myAutoMacro", MAM.options)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("myAutoMacro", "myAutoMacro")
end

-- profile changed
function MAM:ProfileChanged()
	-- recreate automacros from the addon pov if new hasn't
	MAM.db.profile.currentMacros = MAM.db.profile.currentMacros or {}
	MAM:CreateMacros()

	-- force a zone detection
	MAM:IdentifyZone("silent")
end

-- immediate macro switch
function MAM:GetLibraryMacroIndex(macroName)
	local macroIndex
	for macro in ipairs(MAM.db.global.library) do
		if MAM.db.global.library[macro] ~= "deleted" then
			if MAM.db.global.library[macro].name == macroName then
				macroIndex = macro
			end
		end
	end
	if not macroIndex then
		print(MAM.FORMATED_ADDON_NAME .. L["This macro doesn't exists."])
		return false
	else
		return macroIndex
	end
end

function MAM:SwitchMacro(currentMacro, currentAutomacro)
	if not string.find(currentAutomacro, "%d") or tonumber(currentAutomacro) < 1 or tonumber(currentAutomacro) > MAM.db.profile.general.macroNumber then
		print(MAM.FORMATED_ADDON_NAME .. L["Please enter the number of an existing automacro."])
		return false
	elseif not currentMacro then
		return false
	end
	local currentAutomacro = tonumber(currentAutomacro)
	local macroOldName = ""
	if MAM.db.global.library[MAM.db.profile.currentMacros[currentAutomacro]] then
		macroOldName = MAM.db.global.library[MAM.db.profile.currentMacros[currentAutomacro]].name
	end
	local macroNewName = MAM.db.global.library[currentMacro].name
	local macroBody = MAM.db.global.library[currentMacro].body
	local macroIcon = MAM.db.global.library[currentMacro].texture

	EditMacro(MAM.MACRO_PREFIX .. currentAutomacro .. MAM.MACRO_SUFFIX .. macroOldName, MAM.MACRO_PREFIX .. currentAutomacro .. MAM.MACRO_SUFFIX .. macroNewName, macroIcon, macroBody)
	MAM:PrintAutoMacroState("macroUpdated", currentMacro, currentAutomacro)
	MAM.db.profile.currentMacros[currentAutomacro] = currentMacro

	return true
end
