﻿--[[========================================================================================
      AdvancedIconSelector-KeywordData provides keyword data associated with World of
      Warcaft icons to World of Warcraft addons.
      
      Copyright (c) 2011 David Forrester  (Darthyl of Bronzebeard-US)
        Email: darthyl@hotmail.com
      
      Permission is hereby granted, free of charge, to any person obtaining a copy
      of this software and associated documentation files (the "Software"), to deal
      in the Software without restriction, including without limitation the rights
      to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
      copies of the Software, and to permit persons to whom the Software is
      furnished to do so, subject to the following conditions:
      
      The above copyright notice and this permission notice shall be included in
      all copies or substantial portions of the Software.
      
      THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
      IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
      FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
      AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
      LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
      OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
      THE SOFTWARE.
    ========================================================================================]]

--[[========================================================================================
      If you are making use of LibAdvancedIconSelector in your addon:
      
      You CAN package this keyword data alongside your addon so that
      AdvancedIconSelector doesn't have to be installed for your icons to
      have keywords, but you'll need to rename this folder so that your addon
      can be installed side-by-side with AIS.  The keyword data should not be
      embedded in your addon, however, as it's designed to be loaded on-demand.
      
      For example, if you want to package keyword data alongside an addon named
      "Foo" that makes use of the icon selector, then you should:
        a) Rename this folder from "AdvancedIconSelector-KeywordData" to "Foo-KeywordData"
        b) Change the title in the TOC to "Foo [KeywordData]" or something similar
        c) Change ADDON_NAME below to "Foo-KeywordData" (but do NOT change MAJOR_VERSION)
        d) Load the addon on-demand just before displaying an icon selector,
           unless there's already more up-to-date keyword data loaded:
              local keywordsLib = LibStub("LibAdvancedIconSelector-KeywordData-1.0", true)
			  local myRevision = GetAddOnMetadata("Foo-KeywordData", "X-Revision")
              if not keywordsLib or (myRevision and keywordsLib:GetRevision() < myRevision) then
                  LoadAddOn("Foo-KeywordData")
              end
      
      Do not change the X-Revision number in the TOC unless you've got a very good reason
      to prioritize your keyword library over the one provided by AIS.
    ========================================================================================]]

local ADDON_NAME = "myAutoMacro_KeywordData"

-- Do NOT change the MAJOR_VERSION string to the name of your addon, however,
-- as this is used to obtain the most up-to-date keyword data, regardless of
-- what addon it came from.
local MAJOR_VERSION = "LibAdvancedIconSelector-KeywordData-1.0"
local MINOR_VERSION = GetAddOnMetadata(ADDON_NAME, "X-Revision")

if not LibStub then error(ADDON_NAME .. " requires LibStub to operate") end
local lib = LibStub:NewLibrary(MAJOR_VERSION, MINOR_VERSION)
if not lib then return end

local DEBUG = false
function lib:Debug(...)
	if DEBUG then
		print("|cff00ff00[AIS-KWD] [Debug]|r", ...)
	end
end

lib:Debug("Keyword data loaded!")

-- Returns the keyword library revision, as specified by X-Revision in the TOC.
function lib:GetRevision()
	return MINOR_VERSION
end

-- Returns the keywords associated with the given texture filename.
function lib:GetKeywords(texture)
	if texture then
		return lib.keywords[strlower(texture)]
	end
end

--#### Everything below this line has been automatically generated by the Icon Keyword Editor. ####
lib.keywords = {
	["ability_ambush"] = "purple hidden stealth hide hiding rogue leaves racial:shadowmeld(night_elf) talent:feral_instinct(druid)",
	["ability_backstab"] = "red silver pierce puncture bloody steel metal sword blade weapon gushing gash injury talent:deep_wounds(warrior) tab:combat(rogue) spell:backstab(rogue) talent:puncturing_wounds(rogue) mastery:strikes_of_opportunity(warrior)",
	["ability_bullrush"] = "red tauren horned horns furry animal creature beast roar anger angry fury furious rage raging aggression head spell:challenging_shout(warrior) spell:frenzied_regeneration(druid) talent:natural_reaction(druid)",
	["ability_cheapshot"] = "brown eyeball whites sword blade weapon threatened humanoid stabbing spell:cheap_shot(rogue)",
	["ability_creature_cursed_01"] = "orange runes of power symbols circle emblem disease skul aural magic spell sigil seal",
	["ability_creature_cursed_02"] = "red skull and crossbones jolly roger undeath undead evil deadly poisonous toxic corpse talent:will_of_the_necropolis(death_knight)",
	["ability_creature_cursed_03"] = "skull purple dead dying magic spell head talent:ebon_plaguebringer(death_knight)",
	["ability_creature_cursed_04"] = "red swirly vortex portal maelstrom spiraling magic spell",
	["ability_creature_cursed_05"] = "white skull death dead magic spell face",
	["ability_creature_disease_01"] = "green brown rotten apple mushroom fungus fungi diseased",
	["ability_creature_disease_02"] = "skull green death dead goo poison toxic ectoplasm magic spell head",
	["ability_creature_disease_03"] = "green pink poisoned diseased pox head talent:savage_combat(rogue)",
	["ability_creature_disease_04"] = "green wolf canine dog worg animal furry beast anger angry fury furious rage raging aggression ectoplasmic ghost apparition spirit baring teeth magic spell head",
	["ability_creature_disease_05"] = "hand purple curse shadow unholy magic talent:resilient_infection(death_knight) companion:kirin_tor_familiar",
	["ability_creature_poison_01"] = "toxic disease teeth goo green pink saliva bite jaws gums",
	["ability_creature_poison_02"] = "green goo water liquid disease toxic nature magic spell power",
	["ability_creature_poison_03"] = "posion green rip tear wound claw pierce",
	["ability_creature_poison_04"] = "poisonous green thorns plant painful sharp vines roots",
	["ability_creature_poison_05"] = "green ghoul disease ghost teeth apparition head",
	["ability_creature_poison_06"] = "bubbles disease green blood water liquid surface toxic talent:master_poisoner(rogue)",
	["ability_criticalstrike"] = "bloody dried covered soaked swinging sword weapon moving motion spell:recklessness(warrior) talent:lethality(rogue) talent:blood-caked_blade(death_knight)",
	["ability_deathknight_boneshield"] = "green skeletal skeleton talent:bone_shield(death_knight)",
	["ability_deathknight_brittlebones"] = "broken skeletal skeleton blue shattered shards fragments talent:brittle_bones(death_knight)",
	["ability_deathknight_desolation"] = "curse blood purple shadow unholy magic spell talent:hand_of_doom(death_knight)",
	["ability_deathknight_hemorrhagicfever"] = "red blood horror hemorrhage magic spell",
	["ability_deathknight_pillaroffrost"] = "frozen ice icy cold freezing frosty snowy blue stone talent:pillar_of_frost(death_knight)",
	["ability_deathknight_runicimpowerment"] = "frozen ice icy cold freezing frosty blue blade battleaxe weapon",
	["ability_deathknight_sanguinfortitude"] = "red silver wooden shield armor defense protection blocking blood buckler talent:sanguine_fortitude(death_knight)",
	["ability_deathknight_summongargoyle"] = "black bat vampire fangs teeth creature animal bite head face talent:summon_gargoyle(death_knight)",
	["ability_deathwing_assualtaspects"] = "neltharion red orange glowing iris eyeball black dragon demonic evil staring stare",
	["ability_deathwing_bloodcorruption_death"] = "bloody dripping drips drops liquid skull red evil unholy",
	["ability_deathwing_bloodcorruption_earth"] = "red bloody dripping drips drops liquid sphere",
	["ability_deathwing_cataclysm"] = "red orange neltharion black fire fiery burning hot heat flames flaming blazing scorching searing dragonbreath mouth head",
	["ability_deathwing_fierygrip"] = "red orange fire burning hot heat flames flaming blazing scorching searing beam laser flare pillar power magic spell neltharion",
	["ability_deathwing_grasping_tendrils"] = "red orange fire fiery burning hot heat flames flaming blazing scorching searing lava magma corruption tentacle neltharion",
	["ability_deathwing_sealarmorbreachtga"] = "red orange burning tendons searing neltharion",
	["ability_deathwing_shrapnel"] = "ice icy cold frozen freezing frosty steel metal shards icicles",
	["ability_defend"] = "silver steel metal armor protection blocking spears weapons spell:shield_block(warrior) talent:bastion_of_defense(warrior) pet_stance:defensive(hunter)",
	["ability_devour"] = "gray grey eat teeth bite talent:intimidation(hunter)",
	["ability_druid_aquaticform"] = "whale tail animal creature critter ocean sea water blue outline magic silhouette spell:aquatic_form(druid)",
	["ability_druid_balanceofpower"] = "green scale level weight talent:balance_of_power(druid)",
	["ability_druid_bash"] = "blue brown bear animal furry creature beast paw claws foot scratch spell:bash(druid) talent:brutal_impact(druid)",
	["ability_druid_berserk"] = "cat kitty feline animal furry creature beast tiger lion panther orange red roar anger angry fury furious rage raging aggression mouth teeth bite head talent:berserk(druid)",
	["ability_druid_catform"] = "kitty feline animal furry creature beast claw paw blue outline scratch silhouette spell:cat_form(druid)",
	["ability_druid_catformattack"] = "purple blue black kitty feline animal furry creature beast paw claw scratch panther",
	["ability_druid_challangingroar"] = "bear animal furry creature beast shout anger angry fury furious rage raging aggression red orange head spell:challenging_roar(druid)",
	["ability_druid_cower"] = "black cat kitty feline animal furry creature scared terrified afraid fear blue spell:scare_beast(hunter) spell:cower(druid)",
	["ability_druid_cyclone"] = "green swirly tornado whirlwind nature magic spiraling vortex",
	["ability_druid_dash"] = "fast run green animal cat kitty feline furry creature beast speed go tail paw spell:dash(druid)",
	["ability_druid_demoralizingroar"] = "brown pink bear animal furry creature beast head teeth bite shout talent:spirit_bond(hunter) spell:demoralizing_roar(druid) talent:feral_aggression(druid)",
	["ability_druid_disembowel"] = "claw tip sharp blood animal creature pierce red scratch talent:ruthlessness(rogue) spell:rake(druid)",
	["ability_druid_dreamstate"] = "wisp power purple head arcane shadow magic spell talent:dreamstate(druid)",
	["ability_druid_earthandsky"] = "green blue silver helmet armor defense protection magic spell power talent:earth_and_moon(druid)",
	["ability_druid_eclipse"] = "planet lunar solar blue magic spell mastery:total_eclipse(druid)",
	["ability_druid_eclipseorange"] = "planet lunar solar magic spell",
	["ability_druid_empoweredrejuvination"] = "healing restoration star magic spell nature talent:swift_rejuvenation(druid)",
	["ability_druid_empoweredtouch"] = "hand light magic spell healing restoration talent:empowered_touch(druid)",
	["ability_druid_enrage"] = "purple tauren bull horned horns furry animal creature beast anger angry fury furious raging aggression head baring teeth magic spell:enrage(druid)",
	["ability_druid_ferociousbite"] = "red cat kitty feline animal furry creature beast teeth fangs face talent:bestial_wrath(hunter) spell:ferocious_bite(druid)",
	["ability_druid_flightform"] = "flying wings blue bird animal winged creature feathered feathers magic spell:flight_form(druid) spell:swift_flight_form(druid)",
	["ability_druid_flourish"] = "green plant life healing restoration nourishing grass herbs magic nature spell talent:wild_growth(druid)",
	["ability_druid_forceofnature"] = "treant tree form purple green magic spell enchanted enchantment talent:force_of_nature(druid)",
	["ability_druid_galewinds"] = "purple tornado gusty cyclone swirly nature magic spiraling vortex whirlwind talent:gale_winds(druid)",
	["ability_druid_giftoftheearthmother"] = "green healing restoration growing sprout life hand nurturing nurture nature magic spell power talent:living_seed(druid)",
	["ability_druid_healinginstincts"] = "owl face bird animal winged creature feathered feathers eyes talent:nurturing_instinct(druid)",
	["ability_druid_improvedmoonkinform"] = "bird animal winged creature feathered feathers outline silhouette blue purple nature magic spell power head",
	["ability_druid_improvedtreeform"] = "leaf blue life healing restoration plant growth nature magic spell power",
	["ability_druid_infectedwound"] = "diseased pox green red blood scratch scar talent:infected_wounds(druid)",
	["ability_druid_kingofthejungle"] = "yellow orange red lion roar teeth head mouth bite feline cat kitty animal furry creature beast talent:king_of_the_jungle(druid)",
	["ability_druid_lacerate"] = "wound blood red fangs mouth teeth bite spell:lacerate(druid)",
	["ability_druid_lunarguidance"] = "white black priest prayer light moon worgen spell:revive(druid)",
	["ability_druid_manatree"] = "life plant healing restoration moon sky green blue nature magic spell power talent:gift_of_the_earthmother(druid)",
	["ability_druid_mangle"] = "red purple black wound scratch blood claw cat kitty feline animal furry creature beast rip tear",
	["ability_druid_mangle.tga"] = "red purple wound scratch blood claw cat kitty feline animal furry creature beast rip tear spell:maim(druid) talent:fury_swipes(druid)",
	["ability_druid_mangle2"] = "red brown claw scratch blood wound animal creature talent:mangle(druid)",
	["ability_druid_mastershapeshifter"] = "black orange animal cat kitty feline furry creature beast transformation talent:master_shapeshifter(druid)",
	["ability_druid_maul"] = "blue brown scratch paw claw cat kitty feline animal furry creature beast bear spell:maul(druid)",
	["ability_druid_naturalperfection"] = "healing restoration protection protective green magic spell power talent:nature's_ward(druid)",
	["ability_druid_nourish"] = "plant leaf tree restoration healing nourishing green purple nature magic spell:nourish(druid)",
	["ability_druid_owlkinfrenzy"] = "moonkin red orange fire fiery burning hot heat flames flaming blazing scorching searing anger angry fury furious rage raging aggression antlers nature magic spell talent:owlkin_frenzy(druid)",
	["ability_druid_predatoryinstincts"] = "glowing eyes hidden ambush hide stealth talent:aggression(druid)",
	["ability_druid_primalagression"] = "yellow claw bear animal furry creature beast scratch paw blood rip talent:rend_and_tear(druid)",
	["ability_druid_primalprecision"] = "yellow spot light point sights marksmanship",
	["ability_druid_primaltenacity"] = "white red brown fangs teeth bloody anger angry fury furious rage raging aggression bite bitten furry animal creature beast worg face",
	["ability_druid_prowl"] = "hidden hide hiding stealth blue ambush spell:prowl(druid)",
	["ability_druid_rake"] = "white rip tear blood wound paw animal creature cat kitty feline furry beast wolf canine dog rend spell:claw(druid) racial_passive:flayer(worgen) pet_command:claw(hunter)",
	["ability_druid_ravage"] = "black red rip tear wound claw pierce spell:ravage(druid)",
	["ability_druid_replenish"] = "healing restoration life green nature magic power poison toxic roots surrounding talent:revitalize(druid)",
	["ability_druid_skinteeth"] = "cat kitty feline animal furry creature beast face head fangs bite glowing eyes red orange spell:savage_roar(druid)",
	["ability_druid_starfall"] = "blue white comets meteors moonlight moonbeams magic power blast burst sky stars arcane nature talent:starfall(druid)",
	["ability_druid_supriseattack"] = "purple black cat kitty feline animal furry creature beast prowl hidden hiding ambush grass sneaking hunting face spell:pounce(druid)",
	["ability_druid_swipe"] = "cat kitty feline animal furry creature beast claw paw red scratch",
	["ability_druid_tigersroar"] = "orange black cat kitty feline animal furry creature beast mouth fangs bite anger angry fury furious rage raging aggression face talent:survival_instincts(druid)",
	["ability_druid_travelform"] = "blue outline silhouette horseshoe hoofprint zhevra swift fast running nature magic power spell:travel_form(druid)",
	["ability_druid_treeoflife"] = "blue leaf healing restoration nature magic spell power outline silhouette talent:tree_of_life(druid)",
	["ability_druid_twilightswrath"] = "purple power lightning magic arcane shadow nature",
	["ability_druid_typhoon"] = "purple swirly disease poison typoon cyclone torrent tornado nature magic spiraling vortex maelstrom whirlwind talent:typhoon(druid)",
	["ability_dualwield"] = "silver metal swords blades weapons daggers knives knife cross battle duel spell:mutilate(rogue) talent:nerves_of_cold_steel(death_knight) passive:dual_wield(hunter) passive:dual_wield(rogue) passive:dual_wield(death_knight) talent:dual_wield_specialization(warrior) talent:ambidexterity(rogue) talent:dual_wield(shaman)",
	["ability_dualwieldspecialization"] = "blue yellow orange fire fiery burning hot heat flames flaming blazing scorching searing ice icy cold frozen freezing frosty empowered magic weapons swords blades talent:threat_of_thassarian(death_knight)",
	["ability_ensnare"] = "blue brown net catch rope kidnap talent:trap_mastery(hunter)",
	["ability_eyeoftheowl"] = "white beak flying flight sight vision",
	["ability_fiegndead"] = "gray grey death tombstone graveyard zombie ghoul ghost buried",
	["ability_ghoulfrenzy"] = "claw cat kitty feline animal furry creature beast rend tear wound blood red talent:flurry(warrior) talent:flurry(shaman) spell:rip(druid) pet_command:attack(hunter)",
	["ability_golemstormbolt"] = "white gray grey bullet pellet shoot ammo ammunition spell:scatter_shot(hunter)",
	["ability_golemthunderclap"] = "gray grey purple lightning stone fist punch power earthen nature magic knuckles spell:intimidating_shout(warrior) professions:toughness(mining)",
	["ability_gouge"] = "red silver steel metal rip tear gash sword blade weapon dagger knife wound blood spell:rend(warrior) spell:gouge(rogue) talent:improved_gouge(rogue)",
	["ability_heroicleap"] = "jump flying flight red spell:heroic_leap(warrior)",
	["ability_hibernation"] = "sleepy tired dead closed eyes hibernating talent:mental_agility(priest)",
	["ability_hunter_aimedshot"] = "tip sharp precision precise target point arrowhead spear marksmanship shoot blue bullseye",
	["ability_hunter_animalhandler"] = "creature bird winged feathered feathers purple sky hawk hippogryph moonlight talent:animal_handler(hunter) talent:disentanglement(druid)",
	["ability_hunter_aspectmastery"] = "blue purple tiger power head face transformation animal cat kitty feline furry creature beast",
	["ability_hunter_aspectofthefox"] = "red orange white animal creature canine head ears hearing spell:aspect_of_the_fox(hunter)",
	["ability_hunter_aspectofthemonkey"] = "black yellow banana ape primate fruit gripping animal creature hand",
	["ability_hunter_aspectoftheviper"] = "blue purple eyeball beast snake animal creature sight vision face talent:fervor(hunter)",
	["ability_hunter_assassinate"] = "white skull skeleton skeletal arrow dead head bones talent:marked_for_death(hunter)",
	["ability_hunter_assassinate2"] = "tip point arrowhead spear blood red pierce puncture shoot spell:kill_shot(hunter)",
	["ability_hunter_beastcall"] = "brown wooden whistle blow noise sound instrument spell:call_pet(hunter)",
	["ability_hunter_beastcall02"] = "brown wooden weapon slingshot stick rubber band passive:control_pet(hunter)",
	["ability_hunter_beastmastery"] = "orange red dinosaur animal creature reptile teeth bite head rage roar savage talent:beast_mastery(hunter)",
	["ability_hunter_beastsoothe"] = "brown hand slap motion spell:revive_pet(hunter) spell:soothe(druid)",
	["ability_hunter_beasttaming"] = "green whip mace weapon torture hand spikes ball spell:tame_beast(hunter) mastery:master_of_beasts(hunter)",
	["ability_hunter_beasttraining"] = "brown treat yummie food biscuit spell:feed_pet(hunter)",
	["ability_hunter_beastwithin"] = "transformation blue red eyeball magic spell power talent:the_beast_within(hunter)",
	["ability_hunter_bestialdiscipline"] = "animals dinosaur reptile wolf canine dog worg furry cat kitty feline fangs transformation beasts rage pack group savage creatures yellow white black panther tab:beast_mastery(hunter) talent:bestial_discipline(hunter)",
	["ability_hunter_camouflage"] = "green brown hiding hidden hide stealth sneaky ambush rogue leaves tab:survival(hunter)",
	["ability_hunter_catlikereflexes"] = "kitty feline animal furry creature beast panther yellow",
	["ability_hunter_chimerashot2"] = "purple tip arrowhead weapon point sharp pierce puncture staff javelin spear talent:chimera_shot(hunter)",
	["ability_hunter_cobrashot"] = "green silver staff tip point arrowhead weapon spell:cobra_shot(hunter)",
	["ability_hunter_cobrastrikes"] = "purple snake poisonous toxic king deadly venomous fangs bite sting viper talent:cobra_strikes(hunter) companion:cobra_hatchling",
	["ability_hunter_combatexperience"] = "purple brown red horn",
	["ability_hunter_criticalshot"] = "purple arrowhead weapon point sharp pierce puncture spear javelin marksmanship shoot",
	["ability_hunter_disarmingshot"] = "purple silver arrowhead shoot",
	["ability_hunter_displacement"] = "blue shadow mirror image deception deceit night elf speed dash running spell:camouflage(hunter)",
	["ability_hunter_eagleeye"] = "bird animal winged creature feathered feathers flying sky vision sight beak head spell:eagle_eye(hunter)",
	["ability_hunter_efficiency"] = "silver weapons spears staves staff arrows arrowheads ammunition ammo fireworks rockets talent:concussive_barrage(hunter)",
	["ability_hunter_efficiency_brown"] = "silver weapons spears staves staff arrows arrowheads ammunition ammo fireworks rockets",
	["ability_hunter_explosiveshot"] = "orange yellow red boom explosion fireworks spear javelin arrowhead fuse weapon talent:explosive_shot(hunter)",
	["ability_hunter_ferociousinspiration"] = "red power circle magic spell talent:ferocious_inspiration(hunter)",
	["ability_hunter_fervor"] = "yellow brown black dinosaur animal creature beast reptile mouth teeth man beard transformation savage face head",
	["ability_hunter_focusedaim"] = "red white silver target arrows arrowheads precision points piercing pierce bullseye tab:marksmanship(hunter) talent:efficiency(hunter)",
	["ability_hunter_focusfire"] = "brown silver bow arrowhead weapon shoot aim marksman precision tip point sharp talent:focus_fire(hunter)",
	["ability_hunter_goforthethroat"] = "yellow black cat kitty feline animal furry creature beast hand death talent:go_for_the_throat(hunter)",
	["ability_hunter_harass"] = "shout red cry anger angry fury furious rage raging aggression upset talent:second_wind(warrior)",
	["ability_hunter_huntervswild"] = "cliff sky mountains standing view scenery landscape background daytime blue talent:hunter_vs._wild(hunter)",
	["ability_hunter_huntingparty"] = "blue bow talent:hunting_party(hunter)",
	["ability_hunter_improvedsteadyshot"] = "yellow silver arrowhead tip sharp point puncture pierce talent:improved_steady_shot(hunter)",
	["ability_hunter_improvedtracking"] = "snowy trek journey walking ice icy cold frozen freezing frosty footprints pawprints white talent:pathing(hunter)",
	["ability_hunter_invigeration"] = "wolf attack blue black yellow dog canine animal creature outlines silhouettes talent:invigoration(hunter)",
	["ability_hunter_killcommand"] = "red magic order blood spell:kill_command(hunter)",
	["ability_hunter_lockandload"] = "shotgun gunpowder pistol rifle red talent:lock_and_load(hunter)",
	["ability_hunter_longevity"] = "wolf canine dog worg animal furry creature beast anger angry fury furious rage raging aggression intimidating intimidation yellow gray grey growling snarling baring teeth head talent:longevity(hunter)",
	["ability_hunter_longshots"] = "blue sky arrows missed sticking out of ground grass talent:sniper_training(hunter)",
	["ability_hunter_markedfordeath"] = "hunter's red marksmanship arrow pointing down",
	["ability_hunter_mastermarksman"] = "brown eyeball sights shoot targetting reticle talent:master_marksman(hunter)",
	["ability_hunter_masterscall"] = "orange white blue cat kitty feline animal furry creature beast tiger fangs roar hiss bite running face spell:master's_call(hunter)",
	["ability_hunter_mastertactitian"] = "purple tactics",
	["ability_hunter_mendpet"] = "bloody paw hurt injured injury bandaged claws cat kitty feline animal furry creature beast tiger wrapped bandages spell:mend_pet(hunter) talent:improved_mend_pet(hunter)",
	["ability_hunter_misdirection"] = "arrowhead shoot pierce puncture swirly blue spiral spell:misdirection(hunter)",
	["ability_hunter_onewithnature"] = "green magic life restoration meditation talent:one_with_nature(hunter)",
	["ability_hunter_pathfinding"] = "compass planet directions blue",
	["ability_hunter_pathfinding2"] = "horse pack mule donkey riding cloaked rider blue talent:pathfinding(hunter)",
	["ability_hunter_pet_assist"] = "cat kitty feline animal furry creature beast transformation blue red pet_stance:assist(hunter)",
	["ability_hunter_pet_bat"] = "black furry animal winged creature fangs vampire teeth face head",
	["ability_hunter_pet_bear"] = "brown animal furry creature beast head face teeth anger angry fury furious rage raging aggression hungry talent:feral_charge(druid)",
	["ability_hunter_pet_boar"] = "pink head animal creature tusks",
	["ability_hunter_pet_cat"] = "lion fangs teeth kitty feline animal furry creature beast head talent:predatory_strikes(druid)",
	["ability_hunter_pet_chimera"] = "black golden yellow beast animal creature tongue teeth head talent:crouching_tiger,_hidden_chimera(hunter)",
	["ability_hunter_pet_corehound"] = "red yellow orange magma puppy dog lava animal creature firelands head companion:core_hound_pup",
	["ability_hunter_pet_crab"] = "orange pincers sea ocean animal creature companion:strand_crawler",
	["ability_hunter_pet_crocolisk"] = "crocodile animal creature reptile bite teeth jaws gray grey head",
	["ability_hunter_pet_devilsaur"] = "raptor dinosaur animal creature beast reptile teeth bite green head",
	["ability_hunter_pet_dragonhawk"] = "bird animal winged creature feathered feathers flying flight jousting silver gray grey head companion:blue_mini_jouster",
	["ability_hunter_pet_gorilla"] = "grey gray animal creature primate head",
	["ability_hunter_pet_goto"] = "black blue cyan order signal pointing cat kitty feline animal furry creature beast outlines silhouettes pet_command:move_to(hunter)",
	["ability_hunter_pet_hyena"] = "head fangs teeth bite growl anger angry fury furious rage raging aggression animal creature canine yellow snarl baring",
	["ability_hunter_pet_moth"] = "animal creature companion:blue_moth companion:white_moth companion:yellow_moth",
	["ability_hunter_pet_netherray"] = "blue outland animal creature",
	["ability_hunter_pet_owl"] = "beak animal winged creature feathered feathers flying flight head companion:tickbird_hatchling companion:white_tickbird_hatchling",
	["ability_hunter_pet_raptor"] = "dinosaur animal creature beast reptile horn head mount red",
	["ability_hunter_pet_ravager"] = "outland animal creature yellow head",
	["ability_hunter_pet_rhino"] = "brown gray grey head furry hairy animal creature horns",
	["ability_hunter_pet_scorpid"] = "scorpion animal creature claws pincers yellow",
	["ability_hunter_pet_silithid"] = "red purple bug ahn'qiraj",
	["ability_hunter_pet_spider"] = "bug animal creature red head",
	["ability_hunter_pet_sporebat"] = "outland swamp animal creature blue",
	["ability_hunter_pet_tallstrider"] = "plainstrider purple beak head feathered bird animal winged creature feathers",
	["ability_hunter_pet_turtle"] = "green head slow tortoise animal creature spell:polymorph:_turtle(mage)",
	["ability_hunter_pet_vulture"] = "pink bird animal winged creature feathered feathers beak head companion:gold_mini_jouster",
	["ability_hunter_pet_warpstalker"] = "green outland terokkar forest animal creature head",
	["ability_hunter_pet_wasp"] = "blue purple wings winged animal creature outland swamp zangarmarsh",
	["ability_hunter_pet_windserpent"] = "orange animal creature beast flying flight outland blade's edge mountains head",
	["ability_hunter_pet_wolf"] = "gray grey canine dog animal furry creature beast anger angry fury furious rage raging aggression intimidating intimidation growling snarling baring teeth head racial_passive:viciousness(worgen)",
	["ability_hunter_pet_worm"] = "pink slimy animal creature",
	["ability_hunter_piercingshots"] = "silver steel metal chestplate armor defense protection horned horns helmet pierced heart torso arrow weapon shoot talent:piercing_shots(hunter)",
	["ability_hunter_pointofnoescape"] = "blue surrounded arrows trapped talent:point_of_no_escape(hunter)",
	["ability_hunter_posthaste"] = "blue brown running exit vehicle leave walking fast swift dash foot boot talent:posthaste(hunter)",
	["ability_hunter_potentvenom"] = "green silver poisoned arrowhead tip deadly shoot toxic spell:widow_venom(hunter) talent:noxious_stings(hunter)",
	["ability_hunter_quickshot"] = "silver arrowhead spear shoot tip point sharp pierce puncture spell:serpent_sting(hunter) talent:improved_serpent_sting(hunter)",
	["ability_hunter_rapidkilling"] = "death graves graveyard dead red moon talent:rapid_killing(hunter) talent:overkill(rogue)",
	["ability_hunter_rapidregeneration"] = "silver blue rifle firing shooting shotgun aiming talent:rapid_recuperation(hunter)",
	["ability_hunter_readiness"] = "blue purple time clock sundial slow fast speed magic spell power talent:readiness(hunter)",
	["ability_hunter_resistanceisfutile"] = "yellow silver surrounded threatened no escape trapped arrows arrowheads talent:resistance_is_futile(hunter)",
	["ability_hunter_resourcefulness"] = "blue brown campfire stick smoke camping sparks talent:resourcefulness(hunter)",
	["ability_hunter_runningshot"] = "shooting arrow red outline silhouette marksmanship aim spell:rapid_fire(hunter)",
	["ability_hunter_separationanxiety"] = "pet friends sad leaving dog wolf canine worg animal furry creature beast separating black silhouettes outlines talent:kindred_spirits(hunter)",
	["ability_hunter_serpentswiftness"] = "yellow viper snake fast speed strike striking venomous slimy animal creature head talent:serpent_spread(hunter)",
	["ability_hunter_sickem"] = "red white wolf canine dog worg animal furry creature beast bite fangs teeth growling snarling anger angry fury furious rage raging aggression intimidating baring head talent:sic_'em!(hunter)",
	["ability_hunter_silenthunter"] = "gray grey targeting reticle owl beast feathered animal creature sight vision precision aim face talent:improved_kill_command(hunter)",
	["ability_hunter_snaketrap"] = "snakes orange blue green deadly venomous animals creatures spell:snake_trap(hunter)",
	["ability_hunter_snipershot"] = "red gray grey black targeting reticle aim precision marksmanship shooting spell:hunter's_mark(hunter)",
	["ability_hunter_snipertraining"] = "red black targeting reticle shoot precision marksmanship",
	["ability_hunter_steadyshot"] = "yellow white arrowhead shoot feathers spell:steady_shot(hunter)",
	["ability_hunter_survivalinstincts"] = "black cat kitty feline animal furry creature beast orange purple outline silhouette",
	["ability_hunter_swiftstrike"] = "red silver battleaxe blade weapon blood rend tear rip fast swing talent:raging_blow(warrior)",
	["ability_hunter_thrillofthehunt"] = "green crossbow arrow weapon shoot aim talent:thrill_of_the_hunt(hunter)",
	["ability_hunter_traplauncher"] = "red silver bear animal furry creature beast spikes spell:trap_launcher(hunter)",
	["ability_hunter_wildquiver"] = "green gray grey arrows fur mastery:wild_quiver(hunter)",
	["ability_hunter_zenarchery"] = "aiming bow arrow shooting orange firing talent:careful_aim(hunter)",
	["ability_impalingbolt"] = "purple arrowhead weapon point sharp pierce puncture spear javelin marksmanship shoot spell:arcane_shot(hunter)",
	["ability_kick"] = "brown gray grey boot step foot walking running spell:kick(rogue) talent:improved_kick(rogue)",
	["ability_mage_arcanebarrage"] = "blue magic blast burst bolts missiles nukes spells power nature talent:shooting_stars(druid) talent:arcane_barrage(mage)",
	["ability_mage_brainfreeze"] = "white talent:brain_freeze(mage)",
	["ability_mage_burnout"] = "soul drained magic orange dust posession demonic evil mouth",
	["ability_mage_chilledtothebone"] = "cold chilly ice icy frozen freezing frosty skull snowy blue undeath undead scourge corpse",
	["ability_mage_coldasice"] = "blue icy frozen freezing frosty shield armor defense protection magic spell power shards broken talent:shattered_barrier(mage)",
	["ability_mage_conjurefoodrank10"] = "mana strudel conjured warm yummie",
	["ability_mage_conjurefoodrank12"] = "blue potion bottled water liquid remedy tonic medicine healing restoration",
	["ability_mage_conjurefoodrank9"] = "conjured mana pie whipped cream custard yummie spell:conjure_refreshment(mage)",
	["ability_mage_conjurewater11"] = "blue champagne bottled wine juice fancy potion medicine tonic remedy restoration",
	["ability_mage_deepfreeze"] = "frozen cold chilly blue ice icy freezing frosty magic spell power talent:deep_freeze(mage)",
	["ability_mage_fierypayback"] = "fire burning hot heat flames flaming blazing scorching searing fury rage magic power destruction demonic red orange",
	["ability_mage_firestarter"] = "red orange yellow fiery burning hot heat flames flaming blazing scorching searing blast burst magic pillar talent:firestarter(mage) talent:sunfire(druid)",
	["ability_mage_frostfirebolt"] = "magic ice icy cold frozen freezing frosty fiery burning hot heat flames flaming blazing scorching searing missile nuke power red orange blue spell:frostfire_bolt(mage)",
	["ability_mage_hotstreak"] = "fire fiery burning heat flames flaming blazing scorching searing hand blood red orange magic spell power talent:hot_streak(mage) talent:improved_hot_streak(mage)",
	["ability_mage_incantersabsorbtion"] = "rune of power symbol hand red outline silhouette magic spell talent:incanter's_absorption(mage)",
	["ability_mage_invisibility"] = "blue stealth fade cloaked hidden witch magic powerful wizard spell:invisibility(mage)",
	["ability_mage_livingbomb"] = "fire fiery burning hot heat magic red orange power talent:living_bomb(mage)",
	["ability_mage_missilebarrage"] = "magic power bolts fire fiery burning hot heat flames flaming blazing scorching searing ice icy cold frozen freezing frosty arcane purple talent:missile_barrage(mage)",
	["ability_mage_moltenarmor"] = "fire fiery burning hot heat flames flaming blazing scorching searing shield barrier defense protection magic ward absorb red orange power elemental spell:molten_armor(mage)",
	["ability_mage_netherwindpresence"] = "arcane purple star flower magic power talent:netherwind_presence(mage)",
	["ability_mage_potentspirit"] = "demonic skull face hooded cloaked shadow unholy purple evil magic power talent:arcane_flows(mage) spell:soul_harvest(warlock)",
	["ability_mage_shattershield"] = "blue ice icy cold frozen freezing frosty armor defense protection blocking barrier magic spell destroy chilly defend rune of power symbol emblem sigil seal",
	["ability_mage_studentofthemind"] = "brown tap thoughts telepathy power magic talent:train_of_thought(priest)",
	["ability_mage_timewarp"] = "purple golden yellow hourglass twisted bent bending sands of bloodlust magic power spell:time_warp(mage)",
	["ability_mage_tormentoftheweak"] = "fear intimidation terror horror blue red cold frozen man chilly ice icy freezing frosty freeze",
	["ability_mage_wintersgrasp"] = "cold chilly ice icy frozen freezing frosty blue skeleton skeletal bones hand claw magic spell power talent:fingers_of_frost(mage)",
	["ability_mage_worldinflames"] = "fire fiery burning hot heat flaming blazing scorching searing orange people ash charred magic spell power",
	["ability_marksmanship"] = "red silver target throwing knife thrown weapon aim bullseye spell:shoot(warrior) talent:bombardment(hunter) spell:shoot(rogue) talent:precision(rogue) talent:precision(warrior)",
	["ability_meleedamage"] = "silver steel metal blade weapon spell:overpower(warrior) spell:raptor_strike(hunter) racial_passive:sword_specialization(human)",
	["ability_miling"] = "brown mortar and pestle bowl flowers grinding herbs mash inks professions:milling(inscription)",
	["ability_mount_alliancepvpmount"] = "battle warhorse steed armored helmet blue",
	["ability_mount_armoredbluewindrider"] = "wyvern horde flying flight animal creature swift fast head purple",
	["ability_mount_bigblizzardbear"] = "white polar animal furry creature beast goggles",
	["ability_mount_blackbattlestrider"] = "mechanostrider gnome gnomish engineering device machine robot mechanical",
	["ability_mount_blackdirewolf"] = "canine dog worg animal furry creature beast teeth fangs growling snarling intimidating pet head baring mount:black_wolf mount:brown_wolf mount:swift_brown_wolf mount:timber_wolf",
	["ability_mount_blackpanther"] = "head cat kitty feline animal furry creature beast companion:panther_cub",
	["ability_mount_bluewindrider"] = "wyvern horde flying flight furry animal creature head mount:blue_wind_rider",
	["ability_mount_camel_brown"] = "tol'vir head furry animal creature uldum blue mount:brown_riding_camel",
	["ability_mount_camel_gray"] = "tol'vir head furry animal creature uldum grey green",
	["ability_mount_camel_tan"] = "tol'vir head furry animal creature uldum gold blue mount:tan_riding_camel",
	["ability_mount_celestialhorse"] = "stars blue sky flying flight mount:celestial_steed",
	["ability_mount_charger"] = "golden yellow fire fiery burning hot heat flames flaming blazing scorching searing hoofprint horseshoe felsteed dreadsteed",
	["ability_mount_cockatricemount"] = "silvermoon feathered animal creature beak head purple mount:red_hawkstrider",
	["ability_mount_cockatricemount_black"] = "silvermoon feathered animal creature beak head mount:black_hawkstrider",
	["ability_mount_cockatricemount_blue"] = "silvermoon feathered animal creature beak head mount:blue_hawkstrider",
	["ability_mount_cockatricemount_green"] = "hawkstrider silvermoon feathered animal creature beak head",
	["ability_mount_cockatricemount_purple"] = "silvermoon feathered animal creature beak head pink mount:purple_hawkstrider",
	["ability_mount_cockatricemountelite"] = "silvermoon feathered animal creature beak head armored purple mount:swift_pink_hawkstrider",
	["ability_mount_cockatricemountelite_black"] = "hawkstrider silvermoon feathered animal creature beak head armored",
	["ability_mount_cockatricemountelite_blue"] = "hawkstrider silvermoon feathered animal creature beak head armored",
	["ability_mount_cockatricemountelite_green"] = "silvermoon feathered animal creature beak head armored turquoise mount:swift_green_hawkstrider",
	["ability_mount_cockatricemountelite_purple"] = "silvermoon feathered animal creature beak head armored pink mount:swift_purple_hawkstrider",
	["ability_mount_cockatricemountelite_white"] = "hawkstrider silvermoon feathered animal creature beak head armored",
	["ability_mount_drake_albino"] = "dragon flight flying head creature blue turquoise white",
	["ability_mount_drake_azure"] = "dragon flight flying head creature blue",
	["ability_mount_drake_blue"] = "dragon flight flying head creature turquoise green mount:albino_drake",
	["ability_mount_drake_bronze"] = "yellow dragon flight flying head creature gold mount:bronze_drake_mount",
	["ability_mount_drake_proto"] = "dragon northrend creature head red companion:proto-drake_whelp mount:violet_proto-drake",
	["ability_mount_drake_red"] = "dragon flight flying head creature mount:red_drake",
	["ability_mount_drake_twilight"] = "purple dragon flight flying head creature mount:black_drake_mount",
	["ability_mount_dreadsteed"] = "yellow orange hoofprint horseshoe felsteed",
	["ability_mount_ebonblade"] = "winged steed of flying flight bird animal creature feathered feathers skeleton skeletal bones undead scourge corpse head",
	["ability_mount_ebongryphon"] = "alliance bird animal winged creature feathered feathers beak head flight flying black burgundy",
	["ability_mount_fireravengodmount"] = "fiery burning hot heat flames flaming blazing scorching searing bird animal winged creature feathered feathers flying flight beak head",
	["ability_mount_flyingcarpet"] = "elegant tailoring cloth flight red",
	["ability_mount_fossilizedraptor"] = "white gray grey bones skeleton skeletal undead corpse mount:fossilized_raptor",
	["ability_mount_frostyflyingcarpet"] = "elegant tailoring cloth flight frozen cold ice icy freezing blue",
	["ability_mount_goldengryphon"] = "alliance bird animal winged creature feathered feathers beak head flight flying brown white yellow",
	["ability_mount_greenwindrider"] = "wyvern horde flying flight animal creature purple mount:green_wind_rider",
	["ability_mount_gryphon_01"] = "alliance bird animal winged creature feathered feathers beak head flight flying armored blue white swift fast",
	["ability_mount_gyrocoptor"] = "blue gnomish gnome engineering gyrocopter device flying machine flight",
	["ability_mount_gyrocoptorelite"] = "silver gnomish gnome engineering gyrocopter device flying machine flight face angry anger teeth",
	["ability_mount_hordepvpmount"] = "warbear polar animal furry creature beast red white head",
	["ability_mount_jungletiger"] = "animal feline cat kitty furry creature beast head striped stripes orange spell:aspect_of_the_cheetah(hunter) spell:tiger's_fury(druid) talent:primal_madness(druid)",
	["ability_mount_kodo_01"] = "animal beast creature head grey mount:gray_kodo mount:white_kodo mount:great_gray_kodo mount:great_white_kodo",
	["ability_mount_kodo_02"] = "animal beast creature head green",
	["ability_mount_kodo_03"] = "animal beast creature head mount:great_brown_kodo mount:brown_kodo",
	["ability_mount_kodosunwalkerelite"] = "pink animal beast creature head swift fast",
	["ability_mount_kotobrewfest"] = "blue brown kodo animal beast creature head",
	["ability_mount_magnificentflyingcarpet"] = "purple elegant tailoring cloth flight swift fast mount:magnificent_flying_carpet",
	["ability_mount_mammoth_black"] = "furry hairy animal creature big tusks trunk head",
	["ability_mount_mammoth_black_3seater"] = "furry hairy animal creature big tusks trunk head seats vehicle blue",
	["ability_mount_mammoth_brown"] = "furry hairy animal creature big tusks trunk head mount:wooly_mammoth",
	["ability_mount_mammoth_brown_3seater"] = "furry hairy animal creature big tusks trunk head seats vehicle mount:traveler's_tundra_mammoth",
	["ability_mount_mammoth_white"] = "furry hairy animal creature big tusks trunk head",
	["ability_mount_mammoth_white_3seater"] = "furry hairy animal creature big tusks trunk head seats vehicle",
	["ability_mount_mechastrider"] = "blue gnomish gnome engineering robot device machine mechanostrider",
	["ability_mount_mountainram"] = "furry animal creature goat head white",
	["ability_mount_netherdrakeelite"] = "flying flight black purple",
	["ability_mount_netherdrakepurple"] = "flying flight black",
	["ability_mount_nightmarehorse"] = "dreadsteed undead glowing red eyes head mane",
	["ability_mount_pegasus"] = "blue horse flying flight",
	["ability_mount_pinktiger"] = "animal feline cat kitty furry creature beast head striped stripes snowy ice frost purple companion:winterspring_cub",
	["ability_mount_polarbear_black"] = "armored animal furry creature beast teeth anger angry fury furious rage raging aggression intimidating head blue",
	["ability_mount_polarbear_brown"] = "animal furry creature beast teeth anger angry fury furious rage raging aggression intimidating head mount:armored_brown_bear",
	["ability_mount_polarbear_white"] = "armored animal furry creature beast teeth anger angry fury furious rage raging aggression intimidating head",
	["ability_mount_raptor"] = "dinosaur animal creature beast reptile horn head green companion:obsidian_hatchling mount:emerald_raptor mount:swift_blue_raptor mount:swift_olive_raptor mount:swift_orange_raptor mount:turquoise_raptor mount:violet_raptor",
	["ability_mount_razorscale"] = "proto drake dragon northrend creature head blue",
	["ability_mount_reddrakemount"] = "alexstrasza dragon head",
	["ability_mount_redfrostwyrm_01"] = "glowing eyes creature horns dragon northrend head",
	["ability_mount_ridingelekk"] = "outland nagrand tusks trunk animal creature elephant head white gray grey",
	["ability_mount_ridingelekk_grey"] = "outland nagrand tusks trunk animal creature elephant head white gray",
	["ability_mount_ridingelekk_purple"] = "outland nagrand tusks trunk animal creature elephant head",
	["ability_mount_ridingelekkelite"] = "outland nagrand tusks trunk animal creature elephant head swift armored purple pink",
	["ability_mount_ridingelekkelite_blue"] = "outland nagrand tusks trunk animal creature elephant head swift armored",
	["ability_mount_ridingelekkelite_green"] = "outland nagrand tusks trunk animal creature elephant head swift armored",
	["ability_mount_ridingelekkelite_purple"] = "outland nagrand tusks trunk animal creature elephant head swift armored",
	["ability_mount_ridinghorse"] = "furry animal creature brown head",
	["ability_mount_rocketmount"] = "goblin engineering missile launching firing blastoff liftoff seat red",
	["ability_mount_rocketmount2"] = "goblin engineering shark missile face painted green silver",
	["ability_mount_rocketmountblue"] = "goblin engineering missile launching firing blastoff liftoff seat",
	["ability_mount_seahorse"] = "vashj'ir ocean swimming animal creature blue head mount:abyssal_seahorse",
	["ability_mount_snowygryphon"] = "alliance bird animal winged creature feathered feathers beak head flight flying ice icy cold frozen freezing frosty white",
	["ability_mount_spectralgryphon"] = "blue purple white ghostly ghastly spectre bird feathers head beak glowing eyes",
	["ability_mount_spectraltiger"] = "blue animal cat kitty feline furry creature beast ghost spirit apparition undead striped stripes",
	["ability_mount_spectralwyvern"] = "blue white orange ghostly ghastly spectre head lion mane glowing eyes",
	["ability_mount_swiftgreenwindrider"] = "wyvern horde flying flight animal creature armored fast head mount:swift_green_wind_rider",
	["ability_mount_swiftpurplewindrider"] = "wyvern horde flying flight animal creature fast head mount:armored_blue_wind_rider mount:swift_purple_wind_rider",
	["ability_mount_swiftredwindrider"] = "wyvern horde flying flight animal creature armored fast head mount:swift_red_wind_rider",
	["ability_mount_swiftyellowwindrider"] = "wyvern horde flying flight animal creature armored fast head golden mount:swift_yellow_wind_rider",
	["ability_mount_tawnywindrider"] = "wyvern horde flying flight furry animal creature head golden yellow mount:tawny_wind_rider",
	["ability_mount_twilightdrakemount_black"] = "flying flight armored green",
	["ability_mount_twilightdrakemount_blue"] = "flying flight armored",
	["ability_mount_twilightdrakemount_bronze"] = "flying flight armored yellow blue",
	["ability_mount_twilightdrakemount_green"] = "flying flight armored purple",
	["ability_mount_twilightdrakemount_red"] = "flying flight armored yellow",
	["ability_mount_tyraelmount"] = "blue horse armored plate steel metal head spiritual ghostly ghastly ethereal mount:tyrael's_charger",
	["ability_mount_undeadhorse"] = "skeleton demon head creature animal bones corpse talent:on_a_pale_horse(death_knight) mount:black_skeletal_horse mount:blue_skeletal_horse mount:brown_skeletal_horse mount:green_skeletal_warhorse mount:ochre_skeletal_warhorse mount:purple_skeletal_warhorse mount:red_skeletal_horse",
	["ability_mount_warhippogryph"] = "green alliance night elf flying flight firelands mount:flameward_hippogryph",
	["ability_mount_whitedirewolf"] = "canine dog worg animal furry creature beast teeth fangs growling snarling intimidating pet head baring mount:dire_wolf mount:swift_gray_wolf mount:swift_timber_wolf",
	["ability_mount_whitetiger"] = "animal feline cat kitty furry creature beast head striped stripes ice icy cold frozen freezing frosty snowy spell:aspect_of_the_pack(hunter)",
	["ability_mount_wyvern_01"] = "wind rider horde flying flight animal creature armored swift fast head",
	["ability_paladin_artofwar"] = "yellow light power divine holy magic spell circle aura talent:the_art_of_war(paladin)",
	["ability_paladin_beaconoflight"] = "beam magic holy power divine healing restoration prayer yellow talent:beacon_of_light(paladin)",
	["ability_paladin_blessedhands"] = "yellow power holy divine magic healing restoration talent:acts_of_sacrifice(paladin) mastery:hand_of_light(paladin)",
	["ability_paladin_blessedmending"] = "hands light beam prayer holy power magic healing restoration talent:sacred_shield(paladin) talent:rapid_renewal(priest)",
	["ability_paladin_conviction"] = "golden yellow armor helmet defense protection talent:conviction(paladin)",
	["ability_paladin_divinestorm"] = "glowing yellow golden metal sword blade weapon power holy shining shine shiny radiating radiance swirly enchanted enchantment spiral talent:divine_storm(paladin)",
	["ability_paladin_enlightenedjudgements"] = "silver hammer mace weapon shiny talent:enlightened_judgements(paladin)",
	["ability_paladin_gaurdedbythelight"] = "golen yellow holy divine healing restoration prayer shield armor defense protection blocking magic talent:guarded_by_the_light(paladin)",
	["ability_paladin_hammeroftherighteous"] = "silver golden yellow stone mace weapon light holy power magic spell enchanted enchantment divine talent:hammer_of_the_righteous(paladin)",
	["ability_paladin_infusionoflight"] = "holy magic dust yellow golden power spell healing restoration talent:infusion_of_light(paladin) talent:divine_touch(priest)",
	["ability_paladin_judgementblue"] = "shiny silver hammer mace weapon steel metal smashing striking attacking motion movement talent:improved_judgement(paladin)",
	["ability_paladin_judgementofthepure"] = "yellow golden hammer light holy divine weapon talent:judgements_of_the_pure(paladin)",
	["ability_paladin_judgementofthewise"] = "blue hammer light holy divine weapon talent:communion(paladin) talent:judgements_of_the_wise(paladin) talent:judgements_of_the_bold(paladin)",
	["ability_paladin_judgementred"] = "shiny silver hammer mace weapon steel metal smashing striking attacking motion movement talent:long_arm_of_the_law(paladin)",
	["ability_paladin_judgementsofthejust"] = "yellow golden seal sigil emblem steel metal hammer mace weapon light holy divine power talent:judgements_of_the_just(paladin)",
	["ability_paladin_protectoroftheinnocent"] = "golden hammer mace weapon purple yellow talent:protector_of_the_innocent(paladin)",
	["ability_paladin_righteousvengeance"] = "yellow holy power magic blessed talent:inquiry_of_faith(paladin)",
	["ability_paladin_sacredcleansing"] = "healing touch light holy power magic restoration yellow golden talent:sacred_cleansing(paladin)",
	["ability_paladin_sanctifiedwrath"] = "red golden yellow hammer mace weapon talent:sanctified_wrath(paladin)",
	["ability_paladin_sheathoflight"] = "golden metal sword blade weapon yellow holy power divine talent:sheath_of_light(paladin)",
	["ability_paladin_shieldofthetemplar"] = "armor defense blocking barrier magic spell light golden yellow divine power enchanted enchantment tab:protection(paladin) talent:shield_of_the_templar(paladin)",
	["ability_paladin_shieldofvengeance"] = "armor defense protection blocking golden purple yellow talent:shield_of_the_righteous(paladin) talent:vengeance(warrior) talent:vengeance(paladin) talent:vengeance(death_knight) talent:vengeance(druid)",
	["ability_paladin_swiftretribution"] = "enchanted enchantment steel metal sword blade weapon purple light divine holy magic power",
	["ability_paladin_touchedbylight"] = "bubble armor yellow purple golden power spell magic defense talent:touched_by_the_light(paladin)",
	["ability_parry"] = "silver steel metal swords blades weapons daggers knives knife clash battle duel attack blue passive:parry(warrior) passive:parry(paladin) passive:parry(hunter) passive:parry(rogue) passive:parry(death_knight)",
	["ability_physical_taunt"] = "mouth teeth fangs anger angry fury furious rage raging aggression bite intimidate intimidating red spell:beast_lore(hunter) spell:growl(druid) pet_command:growl(hunter)",
	["ability_piercedamage"] = "silver arrowhead weapon tip point shoot",
	["ability_poisonarrow"] = "toxic arrowhead tip point venom green goo deadly weapon",
	["ability_poisons"] = "toxic arrowhead tip point venom green goo deadly weapon talent:improved_poisons(rogue)",
	["ability_poisonsting"] = "purple green caterpillar venomous poisonous bite worm deadly",
	["ability_priest_archangel"] = "golden yellow holy light power magic wings spirit dying dead revive healing restoration talent:archangel(priest)",
	["ability_priest_atonement"] = "armor yellow talent:atonement(priest)",
	["ability_priest_bindingprayers"] = "purple book reading praying talent:revelations(priest)",
	["ability_priest_darkness"] = "shadowy unholy cloaked hidden mysterious pale face purple shadows rogue evil talent:darkness(priest)",
	["ability_priest_evangelism"] = "yellow golden purple hammer mace weapon gemmed power magic spell enchanted enchantment holy light",
	["ability_priest_focusedwill"] = "prayer hands red blue willpower light magic talent:focused_will(priest)",
	["ability_priest_heavanlyvoice"] = "blue summoned demonic creature horns singing yellow head succubus talent:heavenly_voice(priest)",
	["ability_priest_reflectiveshield"] = "golden yellow armor defense protection blocking purple beam spell power light holy reflected reflecting magic talent:reflective_shield(priest)",
	["ability_priest_shadowyapparition"] = "unholy figure glowing red eyes purple cloaked evil talent:shadowy_apparition(priest)",
	["ability_priest_silence"] = "shadow unholy purple face mask green eyes magic spell power talent:silence(priest)",
	["ability_priest_soulwarding"] = "golden yellow holy shield armor defense protection blocking winged wings flying flight power radiance radiant healing restoration talent:soul_warding(priest)",
	["ability_racial_aberration"] = "green broken ripped skull undead disease corpse plague magic spell power scourge",
	["ability_racial_avatar"] = "dwarf yelling blue white shouting spell:berserker_stance(warrior) talent:aggression(rogue)",
	["ability_racial_bearform"] = "blue outline silhouette transformation pawprint animal creature footprint furry beast nature magic power tab:feral(druid) spell:bear_form(druid) tab:feral_combat(druid)",
	["ability_racial_bestdealsanywhere"] = "green money dollar signs symbols cash gold banker auctioneer sales vendor treasure racial_passive:best_deals_anywhere(goblin)",
	["ability_racial_betterlivingthroughchemistry"] = "green vial potion science scientific purple radiance radiant brilliance discovery learning racial_passive:better_living_through_chemistry(goblin)",
	["ability_racial_bloodrage"] = "red roar shouting storm giant anger angry fury furious raging aggression intimidation yelling",
	["ability_racial_cannibalize"] = "red ghoul teeth eating diseased gums scourge corpse talent:primal_fury(druid) racial:cannibalize(undead) passive:savage_defense(druid) mastery:savage_defender(druid)",
	["ability_racial_darkflight"] = "foot paw running dashing walking claws purple black furry animal creature stepping racial:darkflight(worgen)",
	["ability_racial_flayer"] = "brown claw hand reaching grasping",
	["ability_racial_packhobgoblin"] = "golden yellow money cash bank treasure chest treasury racial:pack_hobgoblin(goblin)",
	["ability_racial_rocketbarrage"] = "red blue missile bomb goblin engineering weapon",
	["ability_racial_rocketjump"] = "engineering boots flying flight boost blast outline silhouette red racial:rocket_jump(goblin)",
	["ability_racial_runningwild"] = "wolf canine dog animal furry creature beast fleeing outline blue black silhouette racial:running_wild(worgen)",
	["ability_racial_shadowmeld"] = "purple face racial_passive:quickness(night_elf)",
	["ability_racial_timeismoney"] = "white purple golden yellow clock cash pocketwatch racial_passive:time_is_money(goblin)",
	["ability_racial_twoforms"] = "purple brown black transformation worgen switch human magic spell power",
	["ability_racial_ultravision"] = "purple green heat centaur cenarius magic spell power racial_passive:elusiveness(night_elf)",
	["ability_racial_viciousness"] = "black pink worgen glowing eyes wolf canine dog animal furry creature beast face head",
	["ability_repair"] = "silver hammer mace weapon nail hard work pounding repairing fixing mending building constructing carpentry tools",
	["ability_rewindtime"] = "orange undo gears revert reset reverse clockwork machine mechanical cogs turning spinning",
	["ability_rhyolith_immolation"] = "fire fiery burning hot heat red orange magma lava liquid core",
	["ability_rhyolith_lavapool"] = "fire fiery burning hot heat red orange magma liquid volcano mountain surface",
	["ability_rhyolith_magmaflow_wave"] = "fire fiery burning hot heat red orange",
	["ability_rhyolith_magmaflow_whole"] = "fire fiery burning hot heat red orange lava liquid pool volcano mountain flowing",
	["ability_rhyolith_volcano"] = "fire fiery burning hot heat red orange magma lava liquid pool mountain erupting",
	["ability_rogue_ambush"] = "silver steel metal dagger blade weapon knife sword stab red orange spell:heroic_strike(warrior) spell:ambush(rogue) talent:improved_ambush(rogue)",
	["ability_rogue_blackjack"] = "mace weapon spikes blood bashing gold talent:blackjack(rogue)",
	["ability_rogue_bladetwisting"] = "silver steel metal dagger weapon knife sword spinning twirling rotating talent:blade_twisting(rogue)",
	["ability_rogue_bloodsplatter"] = "spattering piercing puncturing wounding stabbing knife silver steel metal dagger blade weapon fist red talent:opportunity(rogue)",
	["ability_rogue_bloodyeye"] = "eyeball wounded stabbed gash scarred talent:scent_of_blood(death_knight)",
	["ability_rogue_cheatdeath"] = "silver steel metal sword blade weapon lucky break green missed boots legs between talent:cheat_death(rogue)",
	["ability_rogue_combatexpertise"] = "target throwing weapon knife silver steel metal dagger blade bullseye hit aim precision marksmanship",
	["ability_rogue_combatexpertisetga"] = "target throwing weapon knife silver steel metal dagger blade bullseye hit aim precision marksmanship",
	["ability_rogue_combatreadiness"] = "golden metal yellow swords blades weapons daggers knives knife shield armor defense protection blocking spell:combat_readiness(rogue)",
	["ability_rogue_cuttothechase"] = "weapon knife poison toxic silver steel metal dagger blade blood green swing strike deadly talent:cut_to_the_chase(rogue)",
	["ability_rogue_deadenednerves"] = "green brain nervous system connections tree talent:deadened_nerves(rogue)",
	["ability_rogue_deadliness"] = "red cloaked shadowy shadowed unholy figure glowing eyes knife silver steel metal dagger blade weapon stab assassinate assassination evil talent:vendetta(rogue)",
	["ability_rogue_deadlybrew"] = "silver steel metal poison toxic daggers blades weapons knives knife swords double two green talent:deadly_brew(rogue)",
	["ability_rogue_deadlymomentum"] = "purple flying skull teeth head moving undead evil magic spell power scourge corpse talent:deadly_momentum(rogue)",
	["ability_rogue_deviouspoisons"] = "deadly toxic pool skull undead glowing eyes green evil scourge corpse",
	["ability_rogue_dirtydeeds"] = "glowing red eyes black shadowy unholy figure cloaked hidden shadowed knife silver steel metal dagger blade weapon teeth evil grin",
	["ability_rogue_disembowel"] = "green silver poison toxic guts steel metal sword blade weapon dagger knife stabbed spell:envenom(rogue)",
	["ability_rogue_disguise"] = "white porcelain mask false hidden identity secret facade deception deceipt",
	["ability_rogue_dismantle"] = "yellow brown golden metal steel sword blade weapon shield armor defense protection blocking light spell:dismantle(rogue)",
	["ability_rogue_distract"] = "bomb fuse tossed thrown weapon explosives spell:distract(rogue) purple",
	["ability_rogue_dualweild"] = "poison toxic knives knife green goo double two",
	["ability_rogue_energeticrecovery"] = "hooded cloaked shadowy unholy figure energy green yellow power magic light spell",
	["ability_rogue_envelopingshadows"] = "unholy monsters demons creatures purple faces evil talent:enveloping_shadows(rogue)",
	["ability_rogue_eviscerate"] = "silver steel metal man threatened execution sword blade weapon talent:cruelty(warrior) tab:assassination(rogue) spell:eviscerate(rogue) talent:coup_de_grace(rogue)",
	["ability_rogue_fanofknives"] = "silver steel metal thrown throwing purple daggers blades weapons knife swords array multiple spell:fan_of_knives(rogue)",
	["ability_rogue_feigndeath"] = "blue-green cyan skull and crossbones jolly roger undeath undead evil cursed deadly poisonous toxic corpse spell:feign_death(hunter) talent:survival_tactics(hunter) talent:vile_poisons(rogue)",
	["ability_rogue_feint"] = "silver steel metal shadows blue sword blade weapon dagger knife spell:disengage(hunter) spell:feint(rogue)",
	["ability_rogue_findweakness"] = "green targeting reticle spot beast demonic creature talent:find_weakness(rogue)",
	["ability_rogue_fleetfooted"] = "boot grass running ground walking fast speedy swift green brown",
	["ability_rogue_focusedattacks"] = "dagger blade weapon knife purple steel metal sword",
	["ability_rogue_garrote"] = "barbed wire fence bloody barbs stained red spell:garrote(rogue)",
	["ability_rogue_honoramongstthieves"] = "triangle steel metal swords blades weapons yellow daggers knives knife hands pact partners friends talent:honor_among_thieves(rogue)",
	["ability_rogue_hungerforblood"] = "silver green orcish licking steel metal dagger blade weapon knife sword bloody mouth yellow thirst guts talent:taste_for_blood(warrior)",
	["ability_rogue_improvedrecuperate"] = "green hooded cloaked shadowy unholy figure evil glowing eyes light power magic spell talent:improved_recuperate(rogue)",
	["ability_rogue_imrovedrecuperate"] = "blue green man naked bare chest light power magic spell recovery restoration healing",
	["ability_rogue_kidneyshot"] = "bare fist knuckles impact blow punch blood red clenched power spell:kidney_shot(rogue)",
	["ability_rogue_masterofsubtlety"] = "purple cloaked shadowy unholy figure evil warlock contemplating thinking hiding hidden sneaking talent:paralysis(priest) talent:master_of_subtlety(rogue)",
	["ability_rogue_murderspree"] = "silver steel metal swords blades weapons daggers knives knife red yellow orange mask talent:killing_spree(rogue)",
	["ability_rogue_nervesofsteel"] = "hardened purple brain connected connections",
	["ability_rogue_preparation"] = "blue war paint man face fingers talent:preparation(rogue)",
	["ability_rogue_preyontheweak"] = "blue hand suffocation strangulation strangle reaching snake viper fangs tongue venomous python talent:bandit's_guile(rogue)",
	["ability_rogue_quickrecovery"] = "green surfing back on his feet getting up recovering swift fast bounce rebound talent:quickening(rogue)",
	["ability_rogue_recuperate"] = "bloody arm gushing wounded blue scarred scratched muscles clenched fist knuckles spell:recuperate(rogue)",
	["ability_rogue_redirect"] = "missile knife bouncing ricocheting blade silver steel metal dagger weapon throwing thrown fired orange fiery burning hot heat spell:redirect(rogue)",
	["ability_rogue_reinforcedleather"] = "silver brown mace weapon nail carpentry hitting hammering smashing impact fixing repairing maintaining building constructing tools talent:reinforced_leather(rogue)",
	["ability_rogue_restlessblades"] = "silver steel metal daggers weapons knives knife swords talent:restless_blades(rogue)",
	["ability_rogue_rupture"] = "black red pierce puncture wound stab knife blade fist weapon knuckles tear rip spell:rupture(rogue)",
	["ability_rogue_ruthlessness"] = "blood wound spattered",
	["ability_rogue_sanguinaryvein"] = "blood vessels veins arteries red purple blue talent:sanguinary_vein(rogue)",
	["ability_rogue_sealfate"] = "scythe red silver blade farming tool weapon",
	["ability_rogue_shadowdance"] = "shadows unholy demons demonic creatures blue red black ghosts spirits apparitions dancing flying floating evil talent:shadow_dance(rogue)",
	["ability_rogue_shadowstep"] = "red purple blue shadowy unholy cloaked figure moving sneaking hiding hidden evil mourning veiled black talent:shadowstep(rogue)",
	["ability_rogue_shadowstrikes"] = "blue outlines silhouettes swords blades weapons daggers knives knife crossed conflicting conflicted battle attack talent:mutilate(rogue)",
	["ability_rogue_sinistercalling"] = "blue red orange fire fiery burning hot heat flames flaming blazing scorching searing face glowing eyes evil demonic creature power talent:assassin's_resolve(rogue) talent:sinister_calling(rogue)",
	["ability_rogue_slaughterfromtheshadows"] = "assassination assassinate bloody silver steel metal sword blade weapon dagger knife sneaking shadowy unholy figure yellow red evil black talent:slaughter_from_the_shadows(rogue)",
	["ability_rogue_slicedice"] = "silver red orange yellow attack swing cleave steel metal sword blade weapon dagger knife trailing glowing talent:sweeping_strikes(warrior) spell:slice_and_dice(rogue) talent:improved_slice_and_dice(rogue)",
	["ability_rogue_smoke"] = "hidden obscured vision sight cloud dust powder pellet explosives spell:smoke_bomb(rogue)",
	["ability_rogue_sprint"] = "swift fast flying boots heel winged orange red dash running shoes spell:intercept(warrior) spell:sprint(rogue) talent:improved_sprint(rogue)",
	["ability_rogue_stayofexecution"] = "purple yellow masked cloaked figure evil leader signal hooded sentence wrath criminal crime talent:seal_fate(rogue)",
	["ability_rogue_sturdyrecuperate"] = "green outline silhouette person light power radiance radiant glowing healing restoration magic spell talent:energetic_recovery(rogue)",
	["ability_rogue_surpriseattack"] = "silver ambush stab steel metal sword blade weapon dagger knife sneak from behind head green person man",
	["ability_rogue_throwingspecialization"] = "yellow seeds daggers thrown weapons blades knives knife light talent:throwing_specialization(rogue)",
	["ability_rogue_tricksofthetrade"] = "pocket swiss army utility knifes tools goo green shiny metal steel sharp spell:tricks_of_the_trade(rogue)",
	["ability_rogue_trip"] = "falling tripping running chain booby trap boot foot yellow gray grey impact stumble stumbling spell:wing_clip(hunter) racial:escape_artist(gnome)",
	["ability_rogue_turnthetables"] = "steel metal swords blades weapons clashing battle battling yellow swinging moving motion strike striking counterattack surprise",
	["ability_rogue_unfairadvantage"] = "strike weapon purple pink sneak attack",
	["ability_rogue_vendetta"] = "red skull glowing green eyes evil demonic creature undead poison toxic deadly disease plague scourge corpse head face talent:scarlet_fever(death_knight)",
	["ability_rogue_venomouswounds"] = "green poison toxic goo liquid gash scar scratch infected disease talent:venomous_wounds(rogue)",
	["ability_rogue_vigor"] = "light yellow purple cloaked figure hooded shadowy unholy evil glowing eyes",
	["ability_rogue_waylay"] = "silver fire fiery burning hot heat flames flaming blazing scorching searing forging forged steel metal sword blade weapon dagger knife yellow orange red talent:waylay(rogue)",
	["ability_rogue_wrongfullyaccused"] = "sad unhappy cloaked hooded figure shadowy unholy misunderstood gray grey sentenced judged mourning loss",
	["ability_sap"] = "mace weapon spikes blood bashing silver spell:sap(rogue)",
	["ability_seal"] = "white black baby critter creature animal furry face pet_stance:passive(hunter)",
	["ability_searingarrow"] = "spearhead fire fiery burning hot heat flames flaming blazing scorching yellow orange weapon talent:impale(warrior)",
	["ability_shaman_cleansespirit"] = "black hand claw light power magic tauren spell:cleanse_spirit(shaman) talent:improved_cleanse_spirit(shaman) talent:nature's_cure(druid)",
	["ability_shaman_heroism"] = "red battleaxe blade weapon gemmed elegant swinging moving motion arm hand",
	["ability_shaman_lavalash"] = "hammer mace weapon fire fiery burning hot heat flames flaming blazing scorching searing ice icy cold frozen freezing frosty elements elemental smashing swinging moving motion nature's power magic enchanted enchantment red yellow orange blue talent:lava_lash(shaman)",
	["ability_shaman_stormstrike"] = "blue silver steel metal mace weapon striking swinging moving motion lightning thunder nature's power enchanted enchantment spell magic elemental talent:stormstrike(shaman)",
	["ability_shaman_watershield"] = "blue ice icy cold frozen freezing frosty bubbles sea ocean liquid barrier armor defense protection magic ward absorb absorption elemental power spell:water_shield(shaman) talent:resurgence(shaman)",
	["ability_shockwave"] = "fire fiery burning hot heat flames flaming blazing scorching searing battleaxe blade weapon yellow orange red spell:hamstring(warrior) talent:improved_hamstring(warrior)",
	["ability_shootwand"] = "weapon ranged tip spear arrowhead glowing enchanted enchantment magic power light diamond gemstone spell arcane ice icy cold frozen freezing frosty white blue",
	["ability_smash"] = "brown tree log hammer mace weapon striking smashing hitting blow impact swinging moving motion talent:pulverize(druid)",
	["ability_spy"] = "brown silver map x marks the spot steel metal dagger blade weapon knife sword trails parchment paper papyrus writing battle plan strategy passive:detect_traps(rogue)",
	["ability_stealth"] = "cloaked hooded assassination assassinate hiding hidden green blue leaves face evil tab:subtlety(rogue) spell:stealth(rogue) talent:nightstalker(rogue)",
	["ability_steelmelee"] = "silver metal sword blade weapon dagger knife",
	["ability_suffocate"] = "blue pink drowning asphyxiation suffocation bulging eyes bubbles sea ocean fatigue",
	["ability_tetanus"] = "red orange goo infection disease wound spill liquid",
	["ability_theblackarrow"] = "tip arrowhead point weapon spearhead purple talent:silencing_shot(hunter)",
	["ability_throw"] = "silver throwing knife steel metal dagger blade weapon purple spell:throw(warrior) spell:throw(rogue)",
	["ability_thunderbolt"] = "paladin thrown weapon thor's hammer mace lightning smash power enchanted enchantment gray grey blue talent:concussion_blow(warrior)",
	["ability_thunderclap"] = "humanoid smashing striking impacting hitting thor's hammer mace weapon lightning power magic enchanted enchantment blow swinging moving motion hand arm wristband gray grey blue",
	["ability_toughness"] = "blue outline silhouette hulk muscles strength strong power light impressive display spell:rallying_cry(warrior)",
	["ability_townwatch"] = "portal valley mountain scenery background landscape daytime trees circle sky globe vision sight telescope scrying green blue white",
	["ability_tracking"] = "black red animal tracks bear furry creature beast wolf canine dog worg pawprints footprints pet_command:follow(hunter)",
	["ability_trueshot"] = "arrowhead tip spearhead white talent:trueshot_aura(hunter)",
	["ability_upgrademoonglaive"] = "thrown weapon spikes spinning purple spell:multi-shot(hunter) talent:blade_barrier(death_knight)",
	["ability_vanish"] = "ghost released spirit apparition glowing eyes wisp shadow unholy aura grey gray smoke powder cloud spell:vanish(rogue)",
	["ability_vehicle_demolisherflamecatapult"] = "red yellow orange fiery burning hot heat flames flaming blazing scorching searing iron metal cannonball stone bullet fireball ammunition ammo weapon",
	["ability_vehicle_demolisherram"] = "red orange battering spikes smashing siege weapon",
	["ability_vehicle_electrocharge"] = "blue lightning magic spell power awesome thunder electricity sparks electrocution crackle crackling striking hitting talent:feedback(shaman)",
	["ability_vehicle_launchplayer"] = "leap flying flight person man sword shield fired launched thrown tossed blue outline silhouette flinged",
	["ability_vehicle_liquidpyrite"] = "fire fiery burning hot heat flames flaming blazing scorching searing wooden barrel ammunition ammo explosives bursting exploding blowing up yellow orange red",
	["ability_vehicle_liquidpyrite_blue"] = "fire fiery burning hot heat flames flaming blazing scorching searing wooden barrel ammunition ammo explosives bursting exploding blowing up purple",
	["ability_vehicle_loadselfcatapult"] = "red brown ammunition ammo loading putting place placing siege weapon launch fire throw toss fling",
	["ability_vehicle_oiljets"] = "blob goo black silver engineering liquid",
	["ability_vehicle_plaguebarrel"] = "liquid green goo wooden disease",
	["ability_vehicle_playerloaded"] = "green brown launch fire toss fling catapult siege weapon",
	["ability_vehicle_powertowheels"] = "red siege weapon battering ram spikes smashing engineering machine",
	["ability_vehicle_reloadammo"] = "black iron metal cannonball ammunition gunpowder packing stick",
	["ability_vehicle_rocketboost"] = "red motorcycle bike goblin engineering riding seat machine",
	["ability_vehicle_shellshieldgenerator"] = "honeycomb hexagon yellow barrier armor defense protection magic spell light power cell wall technology bubble",
	["ability_vehicle_siegeenginecannon"] = "cannonball fired firing launching launched blast iron metal power explosives exploding",
	["ability_vehicle_siegeenginecharge"] = "red weapon knock down walls ram smash battering engineering machine",
	["ability_vehicle_siegeengineram"] = "silver machine engineering battering parts bolts",
	["ability_vehicle_sonicshockwave"] = "golden yellow blast burst explosion magic spell radiance radiant powerful holy restoration sunlight healing talent:solar_beam(druid)",
	["ability_warlock_ancientgrimoire"] = "pink purple green bookmark tome gemmed elegant fancy pages talent:ancient_grimoire(warlock)",
	["ability_warlock_avoidance"] = "red green purple blue summoned demonic felguard creature blade weapon head evasion dodge swift fast movement",
	["ability_warlock_backdraft"] = "demonic power magic hand fire fiery burning hot heat flames flaming blazing scorching searing swirly yellow orange red undead undeath corpse spiral talent:backdraft(warlock)",
	["ability_warlock_baneofhavoc"] = "red skull demonic creature undead glowing eyes power magic undeath evil head scourge corpse talent:bane_of_havoc(warlock)",
	["ability_warlock_burningembers"] = "blazing fireballs fiery hot heat flames flaming scorching searing comets meteors coals red orange magic spell power talent:burning_embers(warlock)",
	["ability_warlock_chaosbolt"] = "poison toxic creature monster worm demonic evil teeth green terrifying beast head talent:chaos_bolt(warlock)",
	["ability_warlock_cremation"] = "fire fiery burning hot heat flames flaming blazing scorching searing red skeleton skeletal skull undead undeath corpse funeral ceremony bones talent:cremation(warlock)",
	["ability_warlock_darkarts"] = "witch doctor skull staff purple blue demonic evil hex jinx curse talent:dark_arts(warlock)",
	["ability_warlock_demonicempowerment"] = "fire fiery burning hot heat flames flaming blazing scorching searing yellow red orange monster beast creature evil glowing head talent:demonic_empowerment(warlock)",
	["ability_warlock_demonicpower"] = "green summoned evil monster creature beast winged wings purple glowing shadow unholy fel magic",
	["ability_warlock_empoweredimp"] = "fire fiery burning hot heat flames flaming blazing scorching searing summoned demonic creature evil beast chaotic chaos yellow orange talent:empowered_imp(warlock)",
	["ability_warlock_eradication"] = "purple skull white undeath undead anger angry fury furious rage raging aggression teeth glowing eyes power magic demonic creature evil shadow unholy head jinxed cursed scourge corpse talent:eradication(warlock)",
	["ability_warlock_everlastingaffliction"] = "purple swirly fire fiery burning hot heat flames flaming blazing scorching searing shadow unholy magic spell talent:everlasting_affliction(warlock) mastery:potent_afflictions(warlock)",
	["ability_warlock_fireandbrimstone"] = "fiery burning hot heat flames flaming blazing scorching searing orange yellow skull demonic creature undeath undead evil power magic shadow unholy head scourge corpse talent:fire_and_brimstone(warlock)",
	["ability_warlock_haunt"] = "purple green skull demonic creature undeath undead powerful fel magic light shadow unholy evil head scourge corpse talent:haunt(warlock)",
	["ability_warlock_impoweredimp"] = "summoned demonic creature glowing green eyes fel magic shadow unholy evil chaotic chaos teeth horns head empowered",
	["ability_warlock_improveddemonictactics"] = "red glowing skull head undeath undead horns creature evil spell shadow unholy powerful scourge corpse",
	["ability_warlock_improvedsoulleech"] = "demonic creature glowing eyes evil shadow unholy fear terror mouth scream horror purple insanity anger angry fury furious rage raging aggression head fierce cursed jinxed magic spell power",
	["ability_warlock_inferno"] = "fiery burning hot heat flames flaming blazing scorching searing yellow orange waves raging swirly swirls firestorm magic spell power talent:inferno(warlock)",
	["ability_warlock_jinx"] = "souls purple spirits dead death sad anguish agony hell outlines silhouettes shadows unholy fire fiery burning hot heat flames flaming blazing scorching searing tortured corrupted jinxed cursed evil magic spell power talent:jinx(warlock)",
	["ability_warlock_moltencore"] = "fire fiery burning hot heat flames flaming blazing scorching searing yellow orange red rock melting glowing embers coals center talent:molten_core(warlock)",
	["ability_warlock_shadowflame"] = "unholy purple skull undead undeath breath dragon drake head spit venom poison toxic curse evil magic power scourge corpse spell:shadowflame(warlock)",
	["ability_warlock_soulsiphon"] = "purple undeath undead spirit glowing eyes skull swirly spiral magic spell power scourge corpse talent:soul_siphon(warlock)",
	["ability_warlock_soulswap"] = "shadow unholy demonic creature evil tortured corrupted purple dead death spirit head pain agony magic spell power talent:soul_swap(warlock)",
	["ability_warlock_whiplash"] = "bullwhip hand purple torture weapon",
	["ability_warrior_battleshout"] = "head shouting anger angry fury furious rage raging aggression intimidation pain agony vigorous roar orange purple spell:battle_shout(warrior)",
	["ability_warrior_bladestorm"] = "silver red orange purple steel metal swords weapons ground array multiple talent:bladestorm(warrior)",
	["ability_warrior_bloodbath"] = "silver bloody red steel metal sword blade weapon tip point dagger knife",
	["ability_warrior_bloodfrenzy"] = "bloody fist clenched red punching power strength strong wounded bleeding knuckles talent:blood_frenzy(warrior)",
	["ability_warrior_bloodnova"] = "blast burst explosion bloody red orange wound",
	["ability_warrior_bloodsurge"] = "bloody arm wounded cut scratched fist clenched blue scarred orcish talent:bloodsurge(warrior)",
	["ability_warrior_bullrush"] = "tauren horned horns furry animal creature beast cow nosering glowing red eyes hair strong strength head face anger angry fury furious rage raging aggression talent:juggernaut(warrior)",
	["ability_warrior_challange"] = "silver crossed steel metal swords blades weapons daggers knives knife battle red orange conflicting conflicted spell:retaliation(warrior) talent:counterattack(hunter)",
	["ability_warrior_charge"] = "silver red steel metal sword blade weapon dagger knife stab puncture pierce thrust forward into spell:charge(warrior)",
	["ability_warrior_cleave"] = "silver green steel metal battleaxe blade weapon swinging moving motion striking cleaving spell:cleave(warrior)",
	["ability_warrior_colossussmash"] = "broken bloody shield armor defense protection blocking yellow golden silver steel metal defend smashed destroyed cracked spell:colossus_smash(warrior)",
	["ability_warrior_commandingshout"] = "night elf female woman girl screaming shouting yelling terrified horrified anger angry fury furious rage raging aggression white hair purple old aged highborne talent:rude_interruption(warrior)",
	["ability_warrior_criticalblock"] = "yellow golden steel metal shield armor defense protection blocking defend mastery:critical_block(warrior)",
	["ability_warrior_decisivestrike"] = "black silver purple spiked mace ball weapon swinging moving motion striking steel sphere spell:slam(warrior) talent:improved_slam(warrior) talent:relentless_strikes(rogue)",
	["ability_warrior_defensivestance"] = "silver steel metal shield armor defense blocking defend riveted rivets bolts radiance blue radiant tab:protection(warrior) spell:defensive_stance(warrior)",
	["ability_warrior_devastate"] = "silver punch warped bloody fist clenched red steel metal sword blade weapon dagger knife power strength strong blow impact knuckles spell:victory_rush(warrior) talent:impending_victory(warrior)",
	["ability_warrior_disarm"] = "silver brown hand taking take steel metal sword blade weapon dagger knife stealing overpowering spell:disarm(warrior)",
	["ability_warrior_endlessrage"] = "orcish green angry furious raging aggression glowing red eyes teeth mouth bloodlust shouting yelling nosering mastery:unshackled_fury(warrior) talent:anger_management(warrior)",
	["ability_warrior_focusedrage"] = "red eye anger angry fury furious raging aggression sight vision precision accuracy aim marksmanship spell:enraged_regeneration(warrior) talent:termination(hunter)",
	["ability_warrior_furiousresolve"] = "green yellow orange fire fiery burning hot heat flames flaming blazing scorching searing orcish red eyes anger angry fury rage raging aggression talent:furious_attacks(warrior)",
	["ability_warrior_improveddisciplines"] = "silver steel metal armor helmet defense protection glowing red eyes horns horned talent:sudden_death(warrior)",
	["ability_warrior_incite"] = "golden yellow metal glowing light power magic enchanted enchantment sword blade weapon gemmed steel talent:incite(warrior)",
	["ability_warrior_innerrage"] = "holy light power magic winged wings helmet armor defense protection red yellow orange spell anger angry tab:fury(warrior) talent:seals_of_command(paladin)",
	["ability_warrior_intensifyrage"] = "muscles naked bare chest man red glowing impressive workout bodybuilding anger angry fury furious raging aggression talent:abomination's_might(death_knight)",
	["ability_warrior_intervene"] = "silver intercepted dagger blade weapon knife steel metal sword blocked prevented stopped plate armored strike swinging striking moving motion",
	["ability_warrior_offensivestance"] = "silver spikey metal steel maces crossed attack conflicting conflicted red weapons spell:battle_stance(warrior)",
	["ability_warrior_punishingblow"] = "red orange yellow dagger weapon knife steel metal sword swinging striking strike attacking glowing moving motion talent:blade_flurry(rogue)",
	["ability_warrior_rallyingcry"] = "shouting yelling roaring booming voice head mouth blue brown spell:commanding_shout(warrior)",
	["ability_warrior_rampage"] = "red anger angry fury furious rage raging aggression bloody wounded dying exploding mouth shouting yelling man orcish talent:rampage(warrior)",
	["ability_warrior_revenge"] = "brown white eye sight vision precision marksmanship aim anger angry fury furious rage raging aggression spell:revenge(warrior) talent:improved_revenge(warrior) talent:vitality(rogue)",
	["ability_warrior_riposte"] = "black blue stabbing ice spearhead magic frost crystaline shield spell:expose_armor(rogue) talent:improved_expose_armor(rogue)",
	["ability_warrior_safeguard"] = "golden yellow shield armor defense protection blocking metal blue glowing enchanted enchantment riveted rivets bolts talent:safeguard(warrior)",
	["ability_warrior_savageblow"] = "silver blue melee weapon battleaxe blade steel striking swinging moving motion tab:arms(warrior) talent:mortal_strike(warrior)",
	["ability_warrior_secondwind"] = "clenched fist red power strength strong punching blow knuckles",
	["ability_warrior_shatteringthrow"] = "silver ice icy cold frozen freezing frosty steel metal sword blade weapon shield barrier armor glowing enchanted enchantment light thrown dagger knife blue spell:shattering_throw(warrior)",
	["ability_warrior_shieldbash"] = "golden yellow silver orange armor defense protection blocking steel metal strike defending interrupting holding",
	["ability_warrior_shieldbreak"] = "red orange yellow silver broken breaking cracked cracking steel metal armor defense protection blocking exploding glowing defend",
	["ability_warrior_shieldguard"] = "brown blocking armor defense protection defending holding wooden protecting talent:shield_mastery(warrior)",
	["ability_warrior_shieldmastery"] = "silver steel metal riveted rivets armor defense protection blocking fire fiery burning hot flames flaming blazing scorching searing enchanted enchantment glowing heated red orange yellow molten defend",
	["ability_warrior_shieldreflection"] = "silver reflecting beam light reflected steel metal armor defense protection blocking defend spell:spell_reflection(warrior)",
	["ability_warrior_shieldwall"] = "wooden emblem purple blue moving motion armor defending defense blocking protection spell:shield_wall(warrior)",
	["ability_warrior_shockwave"] = "silver steel metal sword blade weapon blue glowing golden blast burst power magic yellow impact smashed shattered disenchanting disenchanted enchantment lightning thunder talent:shockwave(warrior)",
	["ability_warrior_stalwartprotector"] = "silver steel metal sword blade weapon plate armor helmet defense protection glowing blue enchanted enchantment power lightning thunder",
	["ability_warrior_strengthofarms"] = "orcish strong muscles bodybuilding yellow green clenched fist punching knuckles",
	["ability_warrior_sunder"] = "broken silver steel metal sword blade weapon dagger knife destroyed busted shattered sundered smashed brown spell:sunder_armor(warrior)",
	["ability_warrior_swordandboard"] = "silver steel metal blade weapon attached to shield armor defense protection blocking blue glowing enchanted enchantment talent:sword_and_board(warrior)",
	["ability_warrior_throwdown"] = "head hitting ground falling tripping pinned impacting thrown human red orange yellow",
	["ability_warrior_throwdown_2"] = "head hitting ground falling tripping pinned impacting thrown night elf green purple red orange",
	["ability_warrior_titansgrip"] = "gray grey silver red orange clenched fist punching fire fiery burning hot heat flames flaming blazing scorching searing stone metal steel power magic might holding clenching enchanted enchantment knuckles talent:titan's_grip(warrior)",
	["ability_warrior_trauma"] = "red silver bloody spikey ball spikes metal steel impacting hitting wounding gushing talent:wrecking_crew(warrior)",
	["ability_warrior_unrelentingassault"] = "silver glowing fire fiery burning hot heat flames flaming blazing scorching searing steel metal sword blade weapon helmet armor defense protection yellow orange talent:war_academy(warrior)",
	["ability_warrior_victoryrush"] = "yellow fire fiery burning hot heat flames flaming blazing scorching searing light holy power magic enchanted enchantment defense defending pushing through blocking protected protection armor shielded silhouette outline bubble spell:intervene(warrior)",
	["ability_warrior_vigilance"] = "silver steel metal sword blade weapon shield armor defense protection blocking defending golden yellow talent:vigilance(warrior)",
	["ability_warrior_warbringer"] = "silver fire fiery burning hot heat flames flaming blazing scorching searing sword blade weapon forging dagger knife steel metal blacksmithing forged enchanted enchantment power magic talent:warbringer(warrior)",
	["ability_warrior_warcry"] = "orcish screaming crying shouting yelling tusks teeth mouth head bearded red green earring spell:demoralizing_shout(warrior) racial_passive:command(orc)",
	["ability_warrior_weaponmastery"] = "silver steel metal sword blade bloody motion moving swinging striking strike dagger knife red",
	["ability_warstomp"] = "brown black smash impacting hitting ground powerful strong strength horse clefthoof centaur racial:war_stomp(tauren)",
	["ability_whirlwind"] = "silver blue steel metal sword blade weapon dagger knife golden yellow ring swinging striking motion moving circle path spell:whirlwind(warrior) spell:deterrence(hunter)",
	["ability_wintergrasp_rank1"] = "medal metal honor place number ribbon steel platinum silver blue one first 1st",
	["ability_wintergrasp_rank2"] = "medal metal honor place number ribbon steel platinum silver purple two second 2nd",
	["ability_wintergrasp_rank3"] = "medal metal honor place number ribbon steel platinum silver red pink three third 3rd",
	["ability_worgen_darkflight"] = "foot paw claws white wolf canine dog animal furry creature beast stepping",
	["inv_alchemy_enchantedvial"] = "talent:toxicology(hunter)",
	["inv_ammo_arrow_02"] = "companion:peddlefeet",
	["inv_axe_01"] = "spell:strike(warrior)",
	["inv_axe_02"] = "racial_passive:axe_specialization(orc)",
	["inv_axe_06"] = "mastery:executioner(rogue)",
	["inv_axe_09"] = "talent:two-handed_weapon_specialization(warrior)",
	["inv_axe_10"] = "passive:weapon_skills(death_knight)",
	["inv_axe_66"] = "spell:heroic_throw(warrior) talent:gag_order(warrior)",
	["inv_axe_68"] = "talent:butchery(death_knight)",
	["inv_axe_96"] = "spell:necrotic_strike(death_knight)",
	["inv_bone_skull_04"] = "spell:skull_bash(druid)",
	["inv_box_birdcage_01"] = "companion:miniwing",
	["inv_box_petcarrier_01"] = "companion:calico_cat companion:worg_pup companion:stinker",
	["inv_chaos_orb"] = "mastery:shadow_orb_power(priest)",
	["inv_chest_chain_06"] = "passive:armor_skills(hunter)",
	["inv_chest_chain_11"] = "passive:mail_specialization(hunter) passive:mail_specialization(shaman)",
	["inv_chest_chain_12"] = "passive:armor_skills(shaman)",
	["inv_chest_chain_15"] = "passive:armor_skills(death_knight)",
	["inv_chest_cloth_23"] = "passive:armor_skills(mage)",
	["inv_chest_cloth_24"] = "passive:armor_skills(warlock)",
	["inv_chest_cloth_50"] = "passive:armor_skills(priest)",
	["inv_chest_leather_03"] = "passive:leather_specialization(rogue)",
	["inv_chest_leather_06"] = "passive:leather_specialization(druid)",
	["inv_chest_leather_07"] = "passive:armor_skills(druid)",
	["inv_chest_leather_09"] = "passive:armor_skills(rogue)",
	["inv_chest_plate04"] = "passive:armor_skills(warrior)",
	["inv_chest_plate12"] = "passive:plate_specialization(warrior) passive:plate_specialization(paladin) passive:plate_specialization(death_knight)",
	["inv_chest_plate15"] = "passive:armor_skills(paladin)",
	["inv_crate_02"] = "companion:creepy_crate",
	["inv_crate_03"] = "companion:speedy",
	["inv_drink_13"] = "companion:wolpertinger",
	["inv_drink_19"] = "companion:snarly",
	["inv_enchant_disenchant"] = "professions:disenchant(enchanting)",
	["inv_enchant_essenceeternallarge"] = "talent:spirit_of_redemption(priest) racial_passive:expansive_mind(gnome)",
	["inv_enchant_essencemagiclarge"] = "passive:wizardry(mage)",
	["inv_enchant_essencenetherlarge"] = "passive:nethermancy(warlock)",
	["inv_enchant_shardbrilliantsmall"] = "racial_passive:the_human_spirit(human)",
	["inv_enchant_shardglimmeringlarge"] = "racial_passive:arcane_affinity(blood_elf)",
	["inv_fabric_soulcloth"] = "professions:northern_cloth_scavenging(tailoring)",
	["inv_feather_01"] = "spell:safe_fall(rogue) passive:safe_fall(rogue) passive:feline_grace(druid)",
	["inv_gauntlets_04"] = "spell:pummel(warrior)",
	["inv_gizmo_rocketlauncher"] = "racial:rocket_barrage(goblin)",
	["inv_hammer_03"] = "passive:weapon_skills(paladin)",
	["inv_hammer_04"] = "spell:hammer_of_wrath(paladin) talent:two-handed_weapon_specialization(paladin)",
	["inv_hammer_05"] = "racial_passive:mace_specialization(dwarf) racial_passive:mace_specialization(human)",
	["inv_helmet_06"] = "talent:battle_trance(warrior)",
	["inv_helmet_21"] = "racial_passive:heroic_presence(draenei) talent:sentinel(warrior)",
	["inv_helmet_23"] = "racial_passive:hardiness(orc)",
	["inv_helmet_74"] = "talent:grand_crusader(paladin)",
	["inv_helmet_96"] = "spell:word_of_glory(paladin)",
	["inv_holiday_christmas_present_03"] = "companion:father_winter's_helper",
	["inv_inscription_pigment_bug06"] = "companion:tiny_flamefly",
	["inv_inscription_tradeskill01"] = "professions:inscription",
	["inv_mace_03"] = "passive:weapon_skills(priest)",
	["inv_mace_12"] = "passive:weapon_skills(shaman)",
	["inv_mace_46"] = "talent:seals_of_the_pure(paladin)",
	["inv_mace_62"] = "talent:throwdown(warrior)",
	["inv_mace_82"] = "talent:wrath_of_the_lightbringer(paladin)",
	["inv_misc_armorkit_17"] = "professions:leatherworking",
	["inv_misc_babyarmadillopet"] = "companion:armadillo_pup",
	["inv_misc_bag_11"] = "spell:pick_pocket(rogue)",
	["inv_misc_bandage_05"] = "talent:field_dressing(warrior)",
	["inv_misc_bearcubbrown"] = "companion:hyjal_bear_cub",
	["inv_misc_bomb_05"] = "talent:t.n.t.(hunter)",
	["inv_misc_bone_01"] = "companion:perky_pug",
	["inv_misc_bone_taurenskull_01"] = "spell:skull_bash(druid)",
	["inv_misc_book_07"] = "talent:tome_of_light(priest)",
	["inv_misc_fish_14"] = "companion:magical_crawdad",
	["inv_misc_fish_turtle_02"] = "mount:sea_turtle",
	["inv_misc_flower_01"] = "racial_passive:cultivation(tauren)",
	["inv_misc_flower_04"] = "companion:crimson_lasher",
	["inv_misc_food_134_meat"] = "talent:blood_in_the_water(druid)",
	["inv_misc_food_15"] = "professions:cooking",
	["inv_misc_food_54"] = "companion:spring_rabbit",
	["inv_misc_food_59"] = "companion:sinister_squashling",
	["inv_misc_gear_01"] = "racial_passive:engineering_specialization(gnome)",
	["inv_misc_gem_02"] = "professions:jewelcrafting",
	["inv_misc_gem_bloodgem_01"] = "professions:prospecting(jewelcrafting)",
	["inv_misc_gem_emerald_01"] = "talent:improved_mana_gem(mage)",
	["inv_misc_gem_sapphire_01"] = "mastery:frozen_heart(death_knight)",
	["inv_misc_gem_sapphire_02"] = "spell:conjure_mana_gem(mage)",
	["inv_misc_head_clockworkgnome_01"] = "companion:clockwork_gnome",
	["inv_misc_head_dragon_01"] = "talent:dragon's_breath(mage)",
	["inv_misc_head_tiger_01"] = "animal feline cat kitty furry creature beast mount striped stripes white fangs teeth",
	["inv_misc_herb_felblossom"] = "spell:lifebloom(druid)",
	["inv_misc_herb_talandrasrose"] = "talent:efflorescence(druid)",
	["inv_misc_horn_02"] = "spell:horn_of_winter(death_knight)",
	["inv_misc_idol_02"] = "racial_passive:da_voodoo_shuffle(troll)",
	["inv_misc_key_03"] = "mount:goblin_trike",
	["inv_misc_key_04"] = "mount:goblin_turbo-trike",
	["inv_misc_map08"] = "racial_passive:explorer(dwarf)",
	["inv_misc_monsterclaw_03"] = "talent:frenzy(hunter) spell:swipe(druid)",
	["inv_misc_monsterclaw_05"] = "mastery:razor_claws(druid)",
	["inv_misc_note_02"] = "racial_passive:diplomacy(human)",
	["inv_misc_note_05"] = "racial_passive:languages(all)",
	["inv_misc_orb_04"] = "talent:harnessed_shadows(priest) mount:corrupted_fire_hawk",
	["inv_misc_organ_01"] = "professions:master_of_anatomy(skinning)",
	["inv_misc_pelt_bear_03"] = "talent:thick_hide(druid)",
	["inv_misc_pelt_bear_ruin_02"] = "racial_passive:beast_slaying(troll)",
	["inv_misc_pelt_wolf_01"] = "professions:skinning",
	["inv_misc_penguinpet"] = "companion:mr._chilly",
	["inv_misc_petdragonwhelptarecgosa"] = "companion:lil'_tarecgosa",
	["inv_misc_qirajicrystal_01"] = "mount:yellow_qiraji_battle_tank",
	["inv_misc_qirajicrystal_03"] = "mount:green_qiraji_battle_tank",
	["inv_misc_qirajicrystal_04"] = "mount:blue_qiraji_battle_tank",
	["inv_misc_questionmark"] = "unknown",
	["inv_misc_quiver_06"] = "talent:artisan_quiver(hunter)",
	["inv_misc_rune_10"] = "passive:runic_empowerment(death_knight)",
	["inv_misc_sandbox_spectraltiger_01"] = "animal cat kitty feline furry creature beast ghost spirit apparition undead mount striped stripes",
	["inv_misc_seagullpet_01"] = "companion:rustberg_gull",
	["inv_misc_shovel_01"] = "professions:survey(archaeology)",
	["inv_misc_slime_01"] = "companion:toxic_wasteling",
	["inv_misc_stonedragonorange"] = "mount:sandstone_drake",
	["inv_misc_stormdragongreen"] = "mount:drake_of_the_west_wind",
	["inv_mount_darkphoenixa"] = "mount:dark_phoenix",
	["inv_mount_hordescorpiong"] = "mount:kor'kron_annihilator",
	["inv_mount_spectralwolf"] = "mount:spectral_wolf",
	["inv_musket_03"] = "racial_passive:gun_specialization(dwarf)",
	["inv_pet_babyblizzardbear"] = "companion:baby_blizzard_bear",
	["inv_pet_cockroach"] = "companion:cockroach",
	["inv_pet_egbert"] = "companion:egbert",
	["inv_pet_nurturedpenguinegg"] = "companion:pengu",
	["inv_pet_scorchedstone"] = "companion:searing_scorchling",
	["inv_potion_33"] = "companion:spirit_of_summer",
	["inv_qirajidol_sun"] = "talent:daybreak(paladin)",
	["inv_relics_idolofrejuvenation"] = "talent:swiftmend(druid)",
	["inv_relics_libramofhope"] = "talent:rule_of_law(paladin)",
	["inv_relics_totemoflife"] = "professions:transmutation_master(alchemy)",
	["inv_scroll_11"] = "passive:flight_master's_license(all)",
	["inv_shield_01"] = "talent:heavy_repercussions(warrior)",
	["inv_shield_05"] = "talent:shield_slam(warrior)",
	["inv_shield_06"] = "talent:shield_specialization(warrior)",
	["inv_shoulder_36"] = "talent:bladed_armor(death_knight)",
	["inv_shoulder_37"] = "spell:righteous_defense(paladin)",
	["inv_spear_02"] = "talent:wyvern_sting(hunter)",
	["inv_spear_04"] = "spell:healing_stream_totem(shaman)",
	["inv_spear_07"] = "talent:aimed_shot(hunter)",
	["inv_staff_01"] = "talent:nature's_majesty(druid)",
	["inv_staff_10"] = "passive:weapon_skills(mage)",
	["inv_staff_15"] = "talent:hungering_cold(death_knight)",
	["inv_staff_21"] = "passive:weapon_skills(druid)",
	["inv_staff_90"] = "talent:fury_of_stormrage(druid)",
	["inv_stone_04"] = "spell:create_healthstone(warlock)",
	["inv_summerfest_firespirit"] = "talent:hand_of_gul'dan(warlock)",
	["inv_sword_04"] = "spell:attack(warrior)",
	["inv_sword_07"] = "talent:dancing_rune_weapon(death_knight)",
	["inv_sword_11"] = "talent:devastate(warrior)",
	["inv_sword_112"] = "talent:merciless_combat(death_knight)",
	["inv_sword_120"] = "talent:might_of_the_frozen_wastes(death_knight)",
	["inv_sword_122"] = "talent:killing_machine(death_knight)",
	["inv_sword_136"] = "talent:sanctity_of_battle(paladin)",
	["inv_sword_17"] = "talent:serrated_blades(rogue)",
	["inv_sword_27"] = "passive:weapon_skills(warrior)",
	["inv_sword_48"] = "spell:execute(warrior) talent:executioner(warrior)",
	["inv_sword_61"] = "spell:festering_strike(death_knight)",
	["inv_sword_62"] = "spell:empower_rune_weapon(death_knight)",
	["inv_sword_86"] = "talent:die_by_the_sword(warrior)",
	["inv_sword_97"] = "talent:revealing_strike(rogue)",
	["inv_thanksgiving_turkey"] = "companion:plump_turkey",
	["inv_throwingaxe_03"] = "racial_passive:throwing_specialization(troll)",
	["inv_throwingknife_02"] = "passive:weapon_skills(rogue)",
	["inv_throwingknife_04"] = "spell:shiv(rogue)",
	["inv_throwingknife_06"] = "spell:deadly_throw(rogue)",
	["inv_torch_thrown"] = "talent:eternal_glory(paladin)",
	["inv_wand_11"] = "passive:weapon_skills(warlock)",
	["inv_weapon_bow_02"] = "passive:weapon_skills(hunter)",
	["inv_weapon_bow_12"] = "racial_passive:bow_specialization(troll)",
	["inv_weapon_halberd14"] = "talent:rage_of_rivendare(death_knight)",
	["inv_weapon_hand_09"] = "passive:runic_focus(death_knight)",
	["inv_weapon_hand_18"] = "talent:annihilation(death_knight)",
	["inv_weapon_shortblade_05"] = "racial_passive:shortblade_specialization(gnome)",
	["inv_weapon_shortblade_15"] = "mastery:main_gauche(rogue)",
	["inv_weapon_shortblade_38"] = "talent:combat_potency(rogue)",
	["inv_weapon_shortblade_40"] = "talent:heart_strike(death_knight)",
	["inv_weapon_shortblade_79"] = "talent:blood_of_the_north(death_knight)",
	["inv_weapon_shortblade_99"] = "talent:mirrored_blades(hunter)",
	["spell_arcane_arcane01"] = "whirlwind magic swirly winds windy gusts gusty snowflakes icy ice cold frozen freezing frosty shiny sparkles light blue wizard mage talent:runic_power_mastery(death_knight) spell:soulshatter(warlock)",
	["spell_arcane_arcane02"] = "magic power flows flowing river stream shiny sparkles light blue wizard spell:spellsteal(mage)",
	["spell_arcane_arcane03"] = "purple shiny sparkles magic power lightbeams blast burst ray wizard mage talent:genesis(druid) talent:starsurge(druid)",
	["spell_arcane_arcane04"] = "blast burst power magic purple explosion point spot star implosion supernova wizard mage",
	["spell_arcane_arcanepotency"] = "wizard power conjuring ball blue purple hands holding magic talent:arcane_potency(mage)",
	["spell_arcane_arcaneresilience"] = "blue purple magical shield barrier armor defense protection ward riveted rivets ethereal wizard's mage's",
	["spell_arcane_arcanetactics"] = "purple spears people glowing magical enchanted enchantment talent:arcane_tactics(mage)",
	["spell_arcane_arcanetorrent"] = "wizard mage magic power blast burst falling stars shooting comet meteors cosmos cosmic purple sky",
	["spell_arcane_blast"] = "wizard burst explosion outward circle magic purple blue spell:arcane_blast(mage) talent:nether_vortex(mage)",
	["spell_arcane_blink"] = "shiny eye magic wizard purple shining tear teleport displacement head spell:distracting_shot(hunter) spell:blink(mage) talent:improved_blink(mage)",
	["spell_arcane_focusedpower"] = "mind controlled telepathy telepathic anguish anger angry migraine headache tormented blue monk bald hands magic talent:torment_the_weak(mage)",
	["spell_arcane_invocation"] = "blast burst powerful beam blue purple circles light magic talent:invocation(mage)",
	["spell_arcane_manatap"] = "hand touch light blue cyan power magic wizard absorption absorb mastery:mana_adept(mage)",
	["spell_arcane_massdispel"] = "circles swirly swirls magic sparkly sparkles purple wizard spell:mass_dispel(priest) spell:ritual_of_refreshment(mage)",
	["spell_arcane_mindmastery"] = "pink control telepathy telepathic power magic anguish pain migraine headache torment talent:state_of_mind(priest) talent:enlightenment(priest)",
	["spell_arcane_portaldalaran"] = "gateway major city town circle twisting nether swirly swirls magic teleportation purple blue northrend spell:portal:_dalaran(mage)",
	["spell_arcane_portaldarnassus"] = "gateway major city town circle twisting nether swirly swirls magic teleportation purple kalimdor spell:portal:_darnassus(mage)",
	["spell_arcane_portalexodar"] = "gateway major city town circle twisting nether swirly swirls magic teleportation purple azuremyst isle kalimdor spell:portal:_exodar(mage)",
	["spell_arcane_portalironforge"] = "gateway major city town circle twisting nether swirly swirls magic teleportation light blue cyan dun morogh eastern kingdoms spell:portal:_ironforge(mage)",
	["spell_arcane_portalorgrimmar"] = "gateway major city town circle twisting nether swirly swirls magic teleportation orange durotar kalimdor spell:portal:_orgrimmar(mage)",
	["spell_arcane_portalshattrath"] = "gateway major city town circle twisting nether swirly swirls magic teleportation blue-green cyan terokkar forest outland spell:portal:_shattrath(mage)",
	["spell_arcane_portalsilvermoon"] = "gateway major city town circle twisting nether swirly swirls magic teleportation red eversong woods eastern kingdoms spell:portal:_silvermoon(mage)",
	["spell_arcane_portalstonard"] = "gateway major city town circle twisting nether swirly swirls magic teleportation light green swamp of sorrows eastern kingdoms spell:portal:_stonard(mage)",
	["spell_arcane_portalstormwind"] = "gateway major city town circle twisting nether swirly swirls magic teleportation blue elwynn forest eastern kingdoms spell:portal:_stormwind(mage)",
	["spell_arcane_portaltheramore"] = "gateway major city town circle twisting nether swirly swirls magic teleportation yellow dustwallow marsh kalimdor spell:portal:_theramore(mage)",
	["spell_arcane_portalthunderbluff"] = "gateway major city town circle twisting nether swirly swirls magic teleportation cyan light blue mulgore kalimdor spell:portal:_thunder_bluff(mage)",
	["spell_arcane_portaltolbarad"] = "gateway major city town circle twisting nether swirly swirls magic teleportation red eastern kingdoms spell:portal:_tol_barad(mage)",
	["spell_arcane_portalundercity"] = "gateway major town circle twisting nether swirly swirls magic teleportation green ruins of lordaeron tirisfal glades eastern kingdoms spell:portal:_undercity(mage)",
	["spell_arcane_prismaticcloak"] = "shadowy unholy cloaked hooded figure purple outlined silhouette glowing eyes evil magic power spirit phantom ghost apparition talent:prismatic_cloak(mage)",
	["spell_arcane_rune"] = "purple magic of runic power symbol mage blast burst explosion letter",
	["spell_arcane_starfire"] = "blue purple rain falling stars blazing burning fiery hot heat comets meteors sky bolts missiles nukes magic spells power spell:starfire(druid)",
	["spell_arcane_studentofmagic"] = "blue red hands holding wizard power stars talent:focus_magic(mage)",
	["spell_arcane_teleportdalaran"] = "portal gateway major city town twisting nether magic teleportation purple blue northrend spell:teleport:_dalaran(mage)",
	["spell_arcane_teleportdarnassus"] = "portal gateway major city town twisting nether magic teleportation purple kalimdor spell:teleport:_darnassus(mage)",
	["spell_arcane_teleportexodar"] = "portal gateway major city town twisting nether magic teleportation purple blue azuremyst isle kalimdor spell:teleport:_exodar(mage)",
	["spell_arcane_teleportironforge"] = "portal gateway major city town twisting nether magic teleportation blue icy snowy frozen ice cold freezing frosty dun morogh eastern kingdoms spell:teleport:_ironforge(mage)",
	["spell_arcane_teleportmoonglade"] = "portal gateway twisting nether magic teleportation purple structure moonwell kalimdor spell:teleport:_moonglade(druid)",
	["spell_arcane_teleportorgrimmar"] = "portal gateway major city town twisting nether magic teleportation orange durotar kalimdor spell:teleport:_orgrimmar(mage)",
	["spell_arcane_teleportshattrath"] = "portal gateway major city town twisting nether magic teleportation light blue green cyan terokkar forest outland spell:teleport:_shattrath(mage)",
	["spell_arcane_teleportsilvermoon"] = "portal gateway major city town twisting nether magic teleportation red eversong woods eastern kingdoms spell:teleport:_silvermoon(mage)",
	["spell_arcane_teleportstonard"] = "portal gateway major city town twisting nether magic teleportation green forest swamp of sorrows eastern kingdoms spell:teleport:_stonard(mage)",
	["spell_arcane_teleportstormwind"] = "portal gateway major city town twisting nether magic teleportation blue green elwynn forest eastern kingdoms spell:teleport:_stormwind(mage)",
	["spell_arcane_teleporttheramore"] = "portal gateway major city town twisting nether magic teleportation orange blue dustwallow marsh kalimdor spell:teleport:_theramore(mage)",
	["spell_arcane_teleportthunderbluff"] = "portal gateway major city town twisting nether magic teleportation light blue cyan mulgore kalimdor spell:teleport:_thunder_bluff(mage)",
	["spell_arcane_teleporttolbarad"] = "portal gateway major city town twisting nether magic teleportation red eastern kingdoms spell:teleport:_tol_barad(mage)",
	["spell_arcane_teleportundercity"] = "portal gateway major town twisting nether magic teleportation green purple ruins of lordaeron tirisfal glades eastern kingdoms spell:death_gate(death_knight) spell:teleport:_undercity(mage)",
	["spell_brokenheart"] = "heartbreak ripped torn apart tear cracked destroyed red yellow pink",
	["spell_burningsoul"] = "yellow orange man on fire fiery hot heat flames flaming blazing scorching searing outline silhouette dust magic talent:burning_soul(mage)",
	["spell_chargenegative"] = "red pink minus - charged lightning thunder zap electricity thaddius crackle crackling",
	["spell_chargepositive"] = "blue cyan plus + charged lightning thunder zap electricity thaddius crackle crackling",
	["spell_deathknight_antimagiczone"] = "lightning thunder zapping deflection reflection bubble shield defense defend protection barrier blue crackle crackling striking hitting electricity natural power talent:anti-magic_zone(death_knight)",
	["spell_deathknight_armyofthedead"] = "purple zombies undead demons shadow unholy magic necromancy ghouls reanimation raise raising evil scourge corpses spell:army_of_the_dead(death_knight)",
	["spell_deathknight_bladedarmor"] = "glowing enchanted enchantment helmet defense protection head gear plate steel metal red orange blades",
	["spell_deathknight_bloodboil"] = "liquid lava boiling steaming hot heated boiled bubbles red magic surface spell:blood_boil(death_knight) talent:crimson_scourge(death_knight) talent:endless_carnage(druid)",
	["spell_deathknight_bloodplague"] = "pestilence purple bloody bleeding shadow unholy magic hand arm passive:blood_plague(death_knight)",
	["spell_deathknight_bloodpresence"] = "skull teeth undead undeath demonic creature evil glowing eyes necromancy magic power head red bloody scourge corpse tab:blood(death_knight) spell:blood_presence(death_knight) talent:improved_blood_presence(death_knight)",
	["spell_deathknight_bloodtap"] = "hand holding clutching heart red draining magic power spell:blood_tap(death_knight) talent:improved_blood_tap(death_knight) talent:blood_rites(death_knight)",
	["spell_deathknight_butcher"] = "silver battleaxe blade weapon steel metal bloody wounding striking moving motion",
	["spell_deathknight_butcher2"] = "silver battleaxe blade weapon steel metal bloody wounding striking moving motion spell:death_strike(death_knight) talent:improved_death_strike(death_knight)",
	["spell_deathknight_classicon"] = "silver steel metal battleaxe blade weapon elegant skull emblem glowing blue spell:obliterate(death_knight)",
	["spell_deathknight_darkconviction"] = "swirly circles enchanted enchantment sword blade weapon dagger knife white aura spell:rune_strike(death_knight)",
	["spell_deathknight_deathstrike"] = "hand holding swinging steel metal sword blade weapon glowing enchanted enchantment gemmed plated armor glove attacking red spell:blood_strike(death_knight) mastery:blood_shield(death_knight)",
	["spell_deathknight_empowerruneblade"] = "glowing magical battleaxe weapon skull emblem edge lightning thunder powerful enchanted enchantment green spell:plague_strike(death_knight)",
	["spell_deathknight_empowerruneblade2"] = "glowing magical battleaxe weapon skull emblem edge lightning thunder powerful enchanted enchantment blue talent:frost_strike(death_knight)",
	["spell_deathknight_explode_ghoul"] = "exploding flying eyeball thrown exploded green goo liquid bursting gross",
	["spell_deathknight_frostfever"] = "snowflake forehead man ice icy cold frozen freezing frosty blue lightning thunder power magic passive:frost_fever(death_knight)",
	["spell_deathknight_frostpresence"] = "skull teeth undead undeath demonic creature evil glowing eyes necromancy magic power head blue icy ice cold frozen freezing frosty scourge corpse tab:frost(death_knight) spell:frost_presence(death_knight) talent:improved_frost_presence(death_knight)",
	["spell_deathknight_frozenruneweapon"] = "silver glowing blue sword blade elegant dagger knife ice icy cold freezing frosty aura enchanted enchantment steel metal spell:runeforging(death_knight)",
	["spell_deathknight_gnaw_ghoul"] = "red white bloody teeth mouth gross undead undeath necromancy gnawing gnashing scourge corpse",
	["spell_deathknight_iceboundfortitude"] = "naked man blue power aura glowing muscles bodybuilding icy cold frozen freezing frosty magic enchanted enchantment spell:icebound_fortitude(death_knight)",
	["spell_deathknight_icetouch"] = "power clenched fist punching cold frozen freezing frosty sparkles sparkly magic enchanted enchantment blue knuckles spell:icy_touch(death_knight)",
	["spell_deathknight_icytalons"] = "ice cold frozen freezing frosty icicles bird animal winged creature feathered feathers claws foot blue white talent:improved_icy_talons(death_knight) talent:icy_talons(death_knight)",
	["spell_deathknight_mindfreeze"] = "blue ice icy cold frozen freezing frosty brain icicles magic power spell:mind_freeze(death_knight)",
	["spell_deathknight_pathoffrost"] = "ice icy cold frozen freezing frosty cracked footprint walking on water blue magic power spell:path_of_frost(death_knight)",
	["spell_deathknight_plaguestrike"] = "hand holding swinging steel metal sword blade weapon glowing enchanted enchantment gemmed plated armor glove attacking green",
	["spell_deathknight_runetap"] = "red steel metal x marks the spot map of power symbol cross talent:rune_tap(death_knight)",
	["spell_deathknight_scourgestrike"] = "hand holding swinging steel metal sword blade weapon glowing enchanted enchantment gemmed plated armor glove attacking purple talent:scourge_strike(death_knight)",
	["spell_deathknight_spelldeflection"] = "silver sword blade weapon steel metal reflecting reflection deflecting magic protection defense defensive bounced bouncing",
	["spell_deathknight_strangulate"] = "purple shadowy ghostly apparition hands reaching grabbing spirit demonic creature evil outline silhouette magic power spell:death_grip(death_knight) talent:unholy_command(death_knight)",
	["spell_deathknight_subversion"] = "silver skull undead undeath demonic creature evil sword blade weapon steel metal scourge corpse face",
	["spell_deathknight_summondeathcharger"] = "horse steed swift glowing blue steel mount:acherus_deathcharger",
	["spell_deathknight_thrash_ghoul"] = "green hand scratching claws fingernails glowing diseased zombie clawing",
	["spell_deathknight_unholypresence"] = "skull teeth undead undeath demonic creature evil glowing eyes necromancy magic power head green diseased poison toxic scourge corpse tab:unholy(death_knight) spell:unholy_presence(death_knight) talent:improved_unholy_presence(death_knight)",
	["spell_deathknight_vendetta"] = "red silver plate armor steel metal blood liquid",
	["spell_deathvortex"] = "green skull undeath undead demonic creature evil plague poison toxic deadly glowing eyes spiral swirly scourge corpse head spell:outbreak(death_knight)",
	["spell_druid_feralchargecat"] = "red orange brown kitty feline animal furry creature beast horns glowing eyes anger angry fury furious rage raging aggression roaring charging running snarling head talent:stampede(druid)",
	["spell_druid_stamedingroar"] = "yellow brown bear animal furry creature beast roaring anger angry fury furious rage raging aggression noisy noise snarling growling head spell:stampeding_roar(druid)",
	["spell_druid_stampedingroar_cat"] = "wolf canine dog worg animal furry creature beast kitty feline gray grey yellow red orange snarling growling anger angry fury furious rage raging aggression intimidating intimidation roaring baring teeth head spell:stampeding_roar(druid)",
	["spell_druid_thrash"] = "bear animal furry creature beast claws slashing scratching mauling brown paw spell:thrash(druid)",
	["spell_druid_wildmushroom"] = "toadstool green white fungus fungi poisonous toxic",
	["spell_festergutgas"] = "green yellow poisonous toxic cloud fumes pestilence",
	["spell_fire_bluecano"] = "ice icy cold freezing frosty snowy volcano magma lava flow mountain fiery burning hot heat flames flaming blazing scorching searing magic talent:frozen_power(shaman)",
	["spell_fire_bluefire"] = "ice icy cold frozen freezing frosty fiery burning hot heat flames flaming blazing scorching searing magic conjured candlelight ethereal spirit ghost wisp apparition talent:frost_specialization(mage)",
	["spell_fire_bluefirenova"] = "ice icy cold frozen freezing frosty circle ball sphere light bubbles magic power",
	["spell_fire_bluefireward"] = "ice icy cold frozen freezing frosty fiery burning hot heat flames flaming blazing scorching searing water magic barrier shield armor defense protection light elemental",
	["spell_fire_blueflamebolt"] = "ice icy cold frozen freezing frosty fiery burning hot heat flames flaming blazing scorching searing missile nuke magic power fireball water light",
	["spell_fire_blueflamebreath"] = "ice icy cold frozen freezing frosty teeth beam light magic blast burst fiery burning hot heat flames flaming blazing scorching searing",
	["spell_fire_blueflamering"] = "ice icy cold frozen freezing frosty nova explosion blast burst circle magic wave area fiery burning hot heat flames flaming blazing scorching searing",
	["spell_fire_blueflamestrike"] = "ice icy cold frozen freezing frosty fiery burning hot heat flaming blazing scorching searing bolt missile nuke magic power ball impact blast burst explosion wave area",
	["spell_fire_bluehellfire"] = "ice icy cold frozen freezing frosty crack tear rift chasm winds sundered magic",
	["spell_fire_blueimmolation"] = "ice icy cold frozen freezing frosty hand undeath undead fiery burning hot heat flames flaming blazing scorching searing magic ashen charred fingers claws corpse",
	["spell_fire_bluepyroblast"] = "ice icy cold frozen freezing frosty fiery burning hot heat flames flaming blazing scorching searing fireball bolt missile nuke magic power comet meteor falling sky",
	["spell_fire_bluerainoffire"] = "ice icy cold frozen freezing frosty fiery burning hot heat flames flaming blazing scorching searing falling meteors comets fireballs firebolts sky magic missiles nukes",
	["spell_fire_burningspeed"] = "red yellow orange running boots fiery hot heat flames flaming scorching searing increase magic talent:blazing_speed(mage)",
	["spell_fire_burnout"] = "red yellow orange fiery burning hot heat flames flaming blazing scorching searing magic talent:pyromaniac(mage) spell:incinerate(warlock)",
	["spell_fire_elemental_totem"] = "red yellow orange fiery burning hot heat flames flaming blazing scorching searing power magic summoned creature demon spell:fire_elemental_totem(shaman)",
	["spell_fire_elementaldevastation"] = "white light holy power destruction bomb explosion blowing up magic talent:elemental_devastation(shaman)",
	["spell_fire_enchantweapon"] = "orange glowing battleaxe blade enchanted enchantment",
	["spell_fire_felcano"] = "green felfire demonic power volcano magma lava flow mountain fiery burning hot heat flames flaming blazing scorching searing magic",
	["spell_fire_felfire"] = "green demonic power fiery burning hot heat flames flaming blazing scorching searing magic conjured candlelight ethereal spirit ghost wisp apparition",
	["spell_fire_felfirenova"] = "green demonic power circle ball sphere light bubbles magic spell:fel_flame(warlock)",
	["spell_fire_felfireward"] = "green demonic power fiery burning hot heat flames flaming blazing scorching searing magic barrier shield armor defense protection light elemental talent:nether_ward(warlock)",
	["spell_fire_felflamebolt"] = "green felfire demonic power fiery burning hot heat flames flaming blazing scorching searing missile nuke magic fireball water light",
	["spell_fire_felflamebreath"] = "green felfire demonic power teeth beam light magic blast burst fiery burning hot heat flames flaming blazing scorching searing",
	["spell_fire_felflamering"] = "green felfire nova demonic power explosion blast burst circle magic wave area fiery burning hot heat flames flaming blazing scorching searing",
	["spell_fire_felflamestrike"] = "green felfire demonic power fiery burning hot heat flaming blazing scorching searing bolt missile nuke magic ball impact blast burst explosion wave area",
	["spell_fire_felhellfire"] = "green felfire demonic power crack tear rift chasm winds sundered magic",
	["spell_fire_felimmolation"] = "green felfire demonic power hand undeath undead fiery burning hot heat flames flaming blazing scorching searing magic ashen charred fingers claws corpse",
	["spell_fire_felpyroblast"] = "green felfire demonic power fiery burning hot heat flames flaming blazing scorching searing fireball bolt missile nuke magic comet meteor falling sky",
	["spell_fire_felrainoffire"] = "green felfire demonic power fiery burning hot heat flames flaming blazing scorching searing falling meteors comets fireballs firebolts sky magic missiles nukes",
	["spell_fire_fire"] = "yellow orange fiery burning hot heat flames flaming blazing scorching searing magic conjured candlelight ethereal spirit ghost wisp apparition talent:aftermath(warlock) talent:fire_specialization(mage) professions:cooking_fire",
	["spell_fire_firearmor"] = "golden yellow steel metal defense protection blocking barrier magic fiery burning hot heat red orange talent:molten_shields(mage)",
	["spell_fire_fireball"] = "red orange yellow fiery burning hot heat flames flaming blazing scorching searing bolt magic nuke missile talent:concussion(shaman) spell:fire_blast(mage) talent:improved_fire_blast(mage) talent:conflagrate(warlock)",
	["spell_fire_fireball02"] = "red orange yellow fiery burning hot heat flames flaming blazing scorching searing bolt magic nuke missile spell:soul_fire(warlock) talent:decimation(warlock) talent:improved_soul_fire(warlock) talent:pyroblast(mage)",
	["spell_fire_firebolt"] = "red orange yellow fireball fiery burning hot heat flames flaming blazing scorching searing magic nuke missile",
	["spell_fire_firebolt02"] = "red orange yellow fireball fiery burning hot heat flames flaming blazing scorching searing magic nuke missile tab:fire(mage)",
	["spell_fire_flameblades"] = "fiery burning hot heat flames flaming blazing scorching searing forging forged dagger weapon knife steel metal red yellow orange magic power professions:smelting(mining)",
	["spell_fire_flamebolt"] = "red orange yellow fiery burning hot heat flames flaming blazing scorching searing magic nuke missile spell:fireball(mage)",
	["spell_fire_flameshock"] = "silhouette outline yellow red orange fiery burning hot heat flaming blazing scorching searing magic power spell:immolation_trap(hunter) spell:flame_shock(shaman)",
	["spell_fire_flametounge"] = "red orange yellow silver mace hammer steel metal fiery burning hot heat flames flaming blazing scorching searing enchanted enchantment glowing talent:elemental_weapons(shaman)",
	["spell_fire_flare"] = "red orange yellow fiery burning hot heat flames flaming blazing scorching searing bolts missiles nukes magic spells power fireball firebolt comet meteor sky stars starry night spell:flare(hunter)",
	["spell_fire_frostresistancetotem"] = "blue ice icy cold frozen freezing frosty scepter weapon staff wand ranged snowflake magic power radiance radiant",
	["spell_fire_immolation"] = "yellow orange hand undeath undead fiery burning hot heat flames flaming blazing scorching searing magic ashen charred fingers claws corpse talent:call_of_flame(shaman) talent:fire_power(mage) spell:immolate(warlock) talent:improved_immolate(warlock)",
	["spell_fire_incinerate"] = "yellow orange fiery burning hot heat flames flaming blazing scorching searing man soul anger angry fury furious rage raging aggression shouting yelling tortured magic power talent:ignite(mage) spell:hellfire(warlock)",
	["spell_fire_lavaspawn"] = "yellow red orange fiery burning hot heat flames flaming blazing scorching searing magma face crooked twisted smile demonic elemental magic power evil",
	["spell_fire_masterofelements"] = "blue red yellow purple orange fiery burning hot heat flames flaming blazing scorching searing missiles nukes bolts fireballs explosion bursting blowing up magic spells elemental talent:master_of_elements(mage)",
	["spell_fire_meteorstorm"] = "yellow orange red fiery burning hot heat flames flaming blazing scorching searing rain falling comets fireballs firebolts sky magic missiles nukes talent:impact(mage) talent:cataclysm(warlock)",
	["spell_fire_moltenblood"] = "yellow orange red lava magma cracks cracked ground earth burning hot heat magic power talent:molten_fury(mage) mastery:fiery_apocalypse(warlock)",
	["spell_fire_playingwithfire"] = "yellow orange red fiery burning hot heat flames flaming blazing scorching searing hand magic wizard mage talent:backlash(warlock)",
	["spell_fire_ragnaros_lavabolt"] = "yellow orange magma fiery burning hot heat flames flaming blazing scorching searing bolts missiles nukes magic spells power fireballs earth ground",
	["spell_fire_ragnaros_molteninferno"] = "yellow orange magma lava fiery burning hot heat flames flaming blazing scorching searing fireball sphere of earth ground magic power",
	["spell_fire_ragnaros_splittingblow"] = "sulfuras hand of hammer mace weapon fiery burning hot heat flames flaming blazing scorching searing yellow orange red firelord",
	["spell_fire_ragnaros_supernova"] = "yellow orange firelord bursting exploding blasting light power magic fiery burning hot heat flames flaming blazing scorching searing",
	["spell_fire_rune"] = "red yellow orange fiery burning hot heat of power symbol magic talent:cauterize(mage)",
	["spell_fire_sealoffire"] = "yellow orange fiery burning hot heat flames flaming blazing scorching searing rune power symbols emblem sigil magic spell:resistance_aura(paladin) talent:combustion(mage)",
	["spell_fire_searingtotem"] = "yellow orange red fiery burning hot heat flaming blazing scorching wand weapon ranged arrowhead tip point shoot spell:searing_totem(shaman) talent:searing_flames(shaman)",
	["spell_fire_selfdestruct"] = "yellow orange fiery burning hot heat flaming blazing scorching searing powerful explosion bomb blast burst ashen charred death dying magic spell:explosive_trap(hunter) spell:magma_totem(shaman) spell:flamestrike(mage) talent:improved_flamestrike(mage) talent:emberstorm(warlock) mastery:flashburn(mage)",
	["spell_fire_soulburn"] = "yellow orange red fiery burning hot heat flames flaming blazing scorching talons claws hand beam of light magic power spell:scorch(mage) talent:improved_scorch(mage) spell:searing_pain(warlock) talent:improved_searing_pain(warlock)",
	["spell_fire_sunkey"] = "yellow unlocks",
	["spell_fire_totemofwrath"] = "red yellow orange mask face crooked twisted smile glowing eyes fiery burning hot heat flames flaming blazing scorching searing magic power talent:totemic_wrath(shaman)",
	["spell_fire_twilightcano"] = "purple volcano magma lava flow mountain fiery burning hot heat flames flaming blazing scorching searing magic power",
	["spell_fire_twilightfire"] = "purple fiery burning hot heat flames flaming blazing scorching searing magic conjured candlelight ethereal spirit ghost wisp apparition talent:arcane_specialization(mage)",
	["spell_fire_twilightfireward"] = "purple fiery burning hot heat flames flaming blazing scorching searing magic barrier shield armor defense protection elemental spell:mage_ward(mage)",
	["spell_fire_twilightflamebolt"] = "purple fiery burning hot heat flames flaming blazing scorching searing missile nuke magic power fireball water",
	["spell_fire_twilightflamebreath"] = "purple teeth beam magic blast burst fiery burning hot heat flames flaming blazing scorching searing",
	["spell_fire_twilightflamestrike"] = "purple fiery burning hot heat flaming blazing scorching searing bolt missile nuke magic power ball impact blast burst explosion wave area",
	["spell_fire_twilighthellfire"] = "purple crack tear rift chasm winds sundered magic",
	["spell_fire_twilightimmolation"] = "purple hand undeath undead fiery burning hot heat flames flaming blazing scorching searing magic ashen charred fingers claws corpse talent:demonic_knowledge(warlock)",
	["spell_fire_twilightnova"] = "purple circle ball sphere bubbles magic power",
	["spell_fire_twilightpyroblast"] = "purple fiery burning hot heat flames flaming blazing scorching searing fireball bolt missile nuke magic power comet meteor falling sky",
	["spell_fire_twilightrainoffire"] = "purple fiery burning hot heat flames flaming blazing scorching searing falling meteors comets fireballs firebolts sky magic missiles nukes",
	["spell_fire_volcano"] = "red yellow orange mountain molten lava magma flowing liquid ash falling fiery burning hot heat flames flaming blazing scorching searing magic power talent:elemental_fury(shaman)",
	["spell_fire_windsofwoe"] = "sky dark clouds windy gusty gusts orange sunlight sunset pain suffering magic power",
	["spell_firefrost orb"] = "fiery burning hot heat flames flaming blazing scorching searing ice icy cold frozen freezing frosty conflicting elements red yellow orange blue magic power talent:frostfire_orb(mage)",
	["spell_fireresistancetotem_01"] = "blue yellow orange red fiery burning hot heat flames flaming blazing scorching searing ice icy cold frozen freezing frosty conflicting elements wand weapon ranged magic power spell:elemental_resistance_totem(shaman)",
	["spell_frost_arcticwinds"] = "blue ice icy frozen freezing frosty windy gusts gusty magic power burst talent:howling_blast(death_knight) talent:enduring_winter(mage) passive:cold_weather_flying mastery:essence_of_the_viper(hunter)",
	["spell_frost_chainsofice"] = "purple icy cold frozen frosty glowing enchanted enchantment links magic power spell:freezing_trap(hunter) spell:chains_of_ice(death_knight)",
	["spell_frost_chillingarmor"] = "blue ice icy cold frozen freezing frosty barrier shield defense protection magic lightbeams radiant radiance elemental",
	["spell_frost_chillingblast"] = "blue snowy ice icy cold frozen freezing frosty lightbeam radiance radiant magic power burst",
	["spell_frost_chillingbolt"] = "purple missile nuke magic power talent:early_frost(mage)",
	["spell_frost_coldhearted"] = "blue ice frozen freezing frosty pillar magic power talent:icy_veins(mage)",
	["spell_frost_fireresistancetotem"] = "red yellow orange fiery burning hot heat flames flaming blazing scorching searing wand weapon ranged",
	["spell_frost_freezingbreath"] = "blue icy cold frozen frosty nova blast burst shards icicles magic power spell:ice_trap(hunter) talent:rime(death_knight)",
	["spell_frost_frost"] = "blue icy cold frozen freezing frosty magic power spell:ice_block(mage)",
	["spell_frost_frostarmor"] = "light blue cyan ice icy cold frozen freezing frosty skull skeleton skeletal evil demonic creature undead undeath necromancy magic power scourge bones head corpse mastery:frostburn(mage)",
	["spell_frost_frostarmor02"] = "blue ice icy cold frozen freezing frosty lightning thunder barrier shield defense protection magic radiant radiance elemental spell:frost_armor(mage)",
	["spell_frost_frostblast"] = "blue icy cold frozen freezing frosty lightbeam radiance radiant magic power burst spell:ice_lance(mage)",
	["spell_frost_frostbolt"] = "blue icy cold frozen freezing frosty missile nuke magic power shards sharp flying talent:piercing_ice(mage)",
	["spell_frost_frostbolt02"] = "blue ice icy cold frozen freezing frosty missile nuke magic power spell:frostbolt_of_ages(mage) tab:frost(mage) spell:frostbolt(mage)",
	["spell_frost_frostbrand"] = "blue silver steel metal mace weapon hammer",
	["spell_frost_frostnova"] = "blue ice icy cold frozen freezing frosty blast burst breath shards icicles magic power spell:frost_nova(mage)",
	["spell_frost_frostshock"] = "blue ice icy cold frozen freezing frosty snowflake light radiant radiance magic power talent:chill_of_the_grave(death_knight) spell:frost_shock(shaman) talent:shatter(mage)",
	["spell_frost_frostward"] = "blue ice icy cold frozen freezing frosty snowflake lightbeams radiant radiance magic power talent:reverberation(shaman)",
	["spell_frost_frozencore"] = "blue ice icy cold freezing frosty ball glowing pillar orb sphere magic power",
	["spell_frost_glacier"] = "blue ice icy frozen freezing frosty wave magic sharp shards freeze spell:cone_of_cold(mage) talent:improved_cone_of_cold(mage)",
	["spell_frost_ice shards"] = "blue icy cold frozen freezing frosty magic sharp freeze bolt missile nuke power talent:ice_shards(mage)",
	["spell_frost_iceclaw"] = "light blue white polar bear animal furry creature beast icy cold frozen freezing frosty claws paw hand scratching mauling attacking",
	["spell_frost_icefloes"] = "blue icy cold frozen freezing frosty flowing water iceberg river sea ocean magic power talent:ice_floes(mage)",
	["spell_frost_iceshard"] = "blue purple icy cold frozen freezing frosty bolt missile nuke magic power point tip sharp dagger blade weapon knife enchanted enchantment icicle",
	["spell_frost_iceshock"] = "blue light icy cold frozen freezing frosty cloud dust powder magic fire fiery burning hot heat flames flaming blazing scorching searing ethereal spirit ghost wisp apparition spell:counterspell(mage) talent:improved_counterspell(mage)",
	["spell_frost_icestorm"] = "blue icy cold frozen freezing frosty shards bolts missiles nukes magic spells power flying falling spell:blizzard(mage) spell:blizzard(warlock)",
	["spell_frost_manaburn"] = "blue ice icy cold frozen freezing frosty fingers hand holding clutching light point spot magic fingernails claws",
	["spell_frost_manarecharge"] = "blue ice cold frozen freezing frosty water bubbles glowing light power arm hand river ocean sea magic talent:icy_reach(death_knight) talent:tidal_focus(shaman) talent:reactive_barrier(mage)",
	["spell_frost_piercing chill"] = "blue ice icy cold frozen freezing frosty bolt missile nuke magic power shards comet meteor impacting falling hitting talent:piercing_chill(mage)",
	["spell_frost_ring of frost"] = "blue ice icy cold frozen freezing frosty circle snowflakes light magic power spell:ring_of_frost(mage)",
	["spell_frost_stun"] = "blue swirly vortex portal maelstrom magic power spiraling spell:concussive_shot(hunter)",
	["spell_frost_summonwaterelemental"] = "blue wave skull ocean sea liquid summoned creature magic power talent:mana_tide_totem(shaman) talent:improved_freeze(mage)",
	["spell_frost_summonwaterelemental_2"] = "blue liquid summoned creature magic power talent:summon_water_elemental(mage)",
	["spell_frost_windwalkon"] = "white gray grey clouds windy gusty circle winds gusts cold aura magic power talent:inner_focus(priest) spell:water_walking(shaman)",
	["spell_frost_wisp"] = "blue ice icy cold frozen freezing frosty cloud dust powder ethereal spirit ghost apparition magic power talent:chilblains(death_knight) talent:permafrost(mage)",
	["spell_frost_wizardmark"] = "blue rune of power symbol eyeball emblem vision sight magic sigil seal talent:cold_snap(mage) racial_passive:frost_resistance(dwarf) talent:purification(shaman)",
	["spell_frostfire orb"] = "blue red orange yellow fiery burning hot heat flames flaming blazing scorching searing ice icy cold frozen freezing frosty bolt missile nuke magic power",
	["spell_frostresistancetotem_01"] = "blue yellow orange fire fiery burning hot heat flames flaming blazing scorching searing ice icy cold frozen freezing frosty bolt missile nuke magic power flamethrower shattered shards wand weapon ranged",
	["spell_holiday_tow_spicecloud"] = "red toxic poison disease dust powder magic power",
	["spell_holy_absolution"] = "runes of power symbols designs emblem brown winged wings restoration magic sigil seal mastery:illuminated_healing(paladin) talent:absolution(priest)",
	["spell_holy_arcaneintellect"] = "mage wizard's brilliance increase blue eyeball sight vision magic power",
	["spell_holy_ardentdefender"] = "golden yellow silver steel metal shield armor defense protection blocking helmet plate talent:ardent_defender(paladin)",
	["spell_holy_ashestoashes"] = "yellow brown crumbling clay golem man person ashen dead death charred talent:last_stand(warrior) talent:strength_of_soul(priest)",
	["spell_holy_aspiration"] = "yellow golden power glowing radiant radiance magic healing restoration aura spell:divine_plea(paladin) mastery:echo_of_light(priest)",
	["spell_holy_auramastery"] = "yellow golden man person radiant radiance divine power magic barrier shield armor defense protection blocking enchanted enchantment healing restoration talent:aura_mastery(paladin)",
	["spell_holy_auraoflight"] = "purple hammer mace weapon glowing radiant radiance enchanted enchantment lightbeams tab:retribution(paladin) spell:retribution_aura(paladin)",
	["spell_holy_avengersshield"] = "yellow golden steel metal armor defense protection blocking barrier magic radiant radiance enchanted enchantment glowing divine power healing restoration talent:avenger's_shield(paladin)",
	["spell_holy_avenginewrath"] = "yellow golden hammer mace weapon enchanted enchantment radiant radiance divine power magic spell:avenging_wrath(paladin) talent:paragon_of_virtue(paladin)",
	["spell_holy_blessedlife"] = "yellow eyeball vision sight hands holding granting giving power magic talent:blessed_life(paladin)",
	["spell_holy_blessedrecovery"] = "wings divine power glowing blue yellow man person naked bare chest magic healing restoration",
	["spell_holy_blessedresillience"] = "sword blade weapon seal emblem yellow red orange golden radiant radiance enchanted enchantment divine power circle lightbeams aura healing restoration magic sigil talent:blessed_resilience(priest)",
	["spell_holy_blessingofagility"] = "cat kitty feline animal furry creature beast pawprint yellow outline silhouette magic power talent:heart_of_the_wild(druid)",
	["spell_holy_blessingofprotection"] = "armor defense blocking barrier magic divine power yellow golden talent:holy_shield(paladin)",
	["spell_holy_blessingofstamina"] = "yellow tauren bull horned horns furry animal creature beast cow silhouette outline strong strength magic power head talent:furor(druid)",
	["spell_holy_blessingofstrength"] = "purple outlines silhouettes swords blades weapons crossed conflicting conflicted attack battle magic power talent:reckoning(paladin)",
	["spell_holy_blindingheal"] = "yellow arm hand reaching grabbing divine power healing restoration head human magic talent:divinity(paladin) spell:binding_heal(priest)",
	["spell_holy_borrowedtime"] = "golden yellow chronos watch clock speed tempo fast slowed stopped halted warped magic power talent:borrowed_time(priest)",
	["spell_holy_championsbond"] = "blue silver helmet armor defense protection plate steel metal horns horned radiant radiance enchanted enchantment magic power passive:mastery",
	["spell_holy_championsgrace"] = "silver yellow golden helmet armor defense protection plate steel metal horns horned enchanted enchantment magic power talent:walk_in_the_light(paladin)",
	["spell_holy_chastise"] = "divine power radiant radiance yellow human hand lightbeams healing restoration magic talent:holy_word:_chastise(priest)",
	["spell_holy_circleofrenewal"] = "area orange yellow glowing sparkles sparkly radiant radiance lightwell lightbeams divine power restoration magic aura talent:circle_of_healing(priest)",
	["spell_holy_consumemagic"] = "black purple absorption absorbing mana consuming wizard mage shadowy unholy figure hooded cloaked evil spell:dark_simulacrum(death_knight)",
	["spell_holy_crusade"] = "golden yellow divine power sunset sunlight dusty misty radiant radiance glowing noble cause nobility human people strength strong purpose resolve healing restoration magic talent:crusade(paladin)",
	["spell_holy_crusaderaura"] = "golden yellow protection barrier light divine power magic cross healing restoration spell:crusader_aura(paladin)",
	["spell_holy_crusaderstrike"] = "yellow golden sword blade weapon enchanted enchantment glowing radiant radiance sunlight sunbeams lightbeams shiny shining healing restoration magic power spell:crusader_strike(paladin)",
	["spell_holy_devineaegis"] = "yellow light power casting magic praying prayer barrier shield armor defense protection bubble healing restoration talent:divine_aegis(priest)",
	["spell_holy_devotion"] = "purple radiant radiance fist enchanted enchantment punching clenched clenching powerful magic glowing plate armor steel metal circles lightbeams knuckles aura talent:toughness(warrior) talent:toughness(paladin) talent:toughness(death_knight) talent:toughness(shaman)",
	["spell_holy_devotionaura"] = "silver blue golden steel metal shield armor defense protection blocking barrier magic radiant radiance lightbeams power enchanted enchantment circles spell:devotion_aura(paladin)",
	["spell_holy_dispelmagic"] = "swirly purple bolts missiles nukes spells power arcane spell:dispel_magic(priest)",
	["spell_holy_divinehymn"] = "song yellow golden power musical notes flats winged harp wings flying magical melody tune bard healing restoration spell:divine_hymn(priest)",
	["spell_holy_divineillumination"] = "yellow golden power lightbeams shooting from eyes sight vision clarity posession spiritual magic devotion healing restoration talent:divine_favor(paladin) talent:evangelism(priest)",
	["spell_holy_divineintervention"] = "glowing yellow golden hammer mace weapon hand holding swinging attacking enchanted enchantment radiant radiance power magic talent:sacred_duty(paladin)",
	["spell_holy_divineprotection"] = "yellow golden power barrier shield armor defense magic radiant radiance enchanted enchantment fist seal emblem sigil clenched clenching circles aura restoration healing bubble knuckles spell:divine_protection(paladin)",
	["spell_holy_divineprovidence"] = "yellow golden x crossed lightbeams sparkles sparkly healing restoration power magic",
	["spell_holy_divinepurpose"] = "power yellow golden pink sunbeams sunlight lightbeams noble cause nobility human lifting hammer mace weapon person radiant radiance magic viking vrykul strength strong resolve healing restoration talent:divine_purpose(paladin)",
	["spell_holy_divineshield"] = "yellow golden pink barrier armor defense protection magic radiant radiance enchanted enchantment seal emblem sigil glowing lightbeams healing restoration spell:divine_shield(paladin)",
	["spell_holy_divinespirit"] = "blue yellow naked human bare chest muscles enchanted enchantment glowing lightbeams magic power radiant radiance healing restoration",
	["spell_holy_dizzy"] = "yellow confusion magic stars squiggles bird swirly knocked out unconscious confused crazy",
	["spell_holy_elunesgrace"] = "crescent sky stars forest mists nighttime black blue dark moonlight moonlit scenery landscape background",
	["spell_holy_empowerchampion"] = "silver red yellow enchanted enchantment plate armor steel metal helmet defense protection glowing radiant radiance lightbeams horns horned magic",
	["spell_holy_excorcism"] = "golden yellow skeleton skeletal skull dust sands dissolving fading eroding magic divine power bones spell:fear_ward(priest)",
	["spell_holy_excorcism_02"] = "yellow orange fire fiery burning hot heat flames flaming blazing scorching searing melting skeleton skeletal skull ashen ashes charred charring magic undeath undead scourge bones corpse burst spell:exorcism(paladin) talent:denounce(paladin) talent:blast_wave(mage)",
	["spell_holy_eyeforaneye"] = "silver steel metal hammer mace weapon sword blade crossed conflicting conflicted smashing breaking cracking intercepting talent:eye_for_an_eye(paladin)",
	["spell_holy_fanaticism"] = "glowing yellow orange golden power magic divine lightbeams radiant radiance person human silhouette outline stylized healing restoration talent:holy_concentration(priest)",
	["spell_holy_fistofjustice"] = "blue brown enchanted enchantment weapon knuckles clenched punching radiant radiance glowing light",
	["spell_holy_flashheal"] = "golden yellow divine power magic casting hand healing restoration lightbeams radiant radiance bright spell:flash_of_light(paladin) spell:flash_heal(priest)",
	["spell_holy_greaterblessingofkings"] = "blue golden yellow enchanted enchantment fist weapon knuckles clenched punching radiant radiance glowing light spell:blessing_of_might(paladin)",
	["spell_holy_greaterblessingoflight"] = "glowing golden yellow divine power magic radiant radiance seal emblem sigil symbol barrier shield armor defense protection shiny sparkly sparkles bright lightbeams healing restoration",
	["spell_holy_greaterblessingofsalvation"] = "purple pink golden yellow hands praying seal emblem sigil prayer circle healing restoration aura magic power",
	["spell_holy_greaterblessingofsanctuary"] = "blue barrier shield armor defense protection magic lightbeams radiant radiance divine power enchanted enchantment glowing healing restoration",
	["spell_holy_greaterblessingofwisdom"] = "cross seal emblem sigil radiant radiance glowing lightbeams purple silver copper healing restoration magic power",
	["spell_holy_greaterheal"] = "blue restoration lightbeam hand arm casting magic divine spell:greater_heal(priest) talent:empowered_healing(priest)",
	["spell_holy_guardianspirit"] = "spiritual healer wings winged archangel hooded cloaked divine messenger blue healing magic power restoration tab:holy(priest) talent:guardian_spirit(priest)",
	["spell_holy_harmundeadaura"] = "yellow golden skull glowing radiant radiance evil undeath divine power magic circles scourge corpse",
	["spell_holy_heal"] = "yellow golden healing restoration magic power divine hand arm casting glowing radiant radiance",
	["spell_holy_heal02"] = "yellow golden healing restoration magic power divine hand arm casting glowing radiant radiance",
	["spell_holy_healingaura"] = "yellow golden magic power lightbeams radiant radiance hand arm circles divine priest restoration spell:seal_of_insight(paladin) talent:arbiter_of_the_light(paladin)",
	["spell_holy_healingfocus"] = "yellow lightning bolt thunder eyeball magic powerful restoration",
	["spell_holy_heroism"] = "yellow golden pink steel metal armor helmet defense protection chestplate warrior divine noble cause nobility power strength strong purpose resolve spell:guardian_of_ancient_kings(paladin)",
	["spell_holy_holybolt"] = "power magic divine lightbeams healing restoration yellow golden radiant radiance tab:holy(paladin) spell:holy_light(paladin) talent:blazing_light(paladin)",
	["spell_holy_holyguidance"] = "yellow golden plate armor steel metal helmet defense protection cross divine power restoration healing radiant radiance lightbeams glowing sunbeams sunlight prayer magic talent:last_word(paladin)",
	["spell_holy_holynova"] = "yellow golden healing divine power magic blast burst explosion restoration staff human bright lightbeams radiant radiance enchanted enchantment spell:holy_nova(priest)",
	["spell_holy_holyprotection"] = "red yellow golden healing power magic seal emblem sigil symbol glowing lightbeams radiant radiance restoration talent:renewed_hope(priest) racial:gift_of_the_naaru(draenei) mastery:divine_bulwark(paladin)",
	["spell_holy_holysmite"] = "yellow golden orange lightbeams radiant radiance magic divine power sunlight blast burst spell:smite(priest)",
	["spell_holy_hopeandgrace"] = "blue magic divine power winged seal emblem sigil radiant radiance lightbeams circle aura healing restoration talent:grace(priest)",
	["spell_holy_impholyconcentration"] = "golden yellow magic divine power lightbeams radiant radiance aura human outline silhouette restoration talent:spiritual_healing(priest)",
	["spell_holy_improvedresistanceauras"] = "blue cyan magic divine power radiant radiance lightbeams steel metal barrier shield armor defense protection healing restoration",
	["spell_holy_innerfire"] = "yellow golden fiery burning hot heat flames flaming blazing scorching searing magic divine power circle aura spell:consecration(paladin) talent:hallowed_ground(paladin) spell:inner_fire(priest) talent:inner_sanctum(priest)",
	["spell_holy_lastingdefense"] = "yellow golden silver orange steel metal armor protection blocking shields clock watch time fast slowed stopped halted warped",
	["spell_holy_layonhands"] = "white yellow golden magic divine power light glowing radiant radiance healing restoration holding giving granting spell:lay_on_hands(paladin) spell:levitate(priest) talent:inspiration(priest)",
	["spell_holy_lesserheal"] = "purple magic divine power lightbeam restoration healing hand giving granting spell:heal(priest)",
	["spell_holy_lesserheal02"] = "purple magic divine power lightbeam restoration healing hand giving granting",
	["spell_holy_lightsgrace"] = "yellow golden healing restoration magic divine power radiant radiance lightbeams altar prayer blast burst explosion enchanted enchantment",
	["spell_holy_magicalsentry"] = "blue eyeball wizard's intellect increase tab:arcane(mage) spell:arcane_brilliance(mage)",
	["spell_holy_mindsooth"] = "purple lightning thunder bolt eyeball magic arcane power spell:concentration_aura(paladin) spell:mind_soothe(priest)",
	["spell_holy_mindvision"] = "yellow purple red magic divine power sunlight sunbeams lightbeams radiant radiance glowing sky spell:mind_vision(priest)",
	["spell_holy_nullifydisease"] = "blue cyan skull undead undeath lightning thunder destroyed vaporized nullified glowing magic power scourge corpse spell:cure_disease(priest)",
	["spell_holy_painsupression"] = "grey gray teeth mouth agony torture anguish face human talent:pain_suppression(priest)",
	["spell_holy_penance"] = "yellow blue bolt missile nuke magic power divine healing restoration talent:penance(priest)",
	["spell_holy_persecution"] = "confusion magic stars squiggles bird swirly knocked out unconscious dizzy confused crazy yellow power glowing",
	["spell_holy_persuitofjustice"] = "blue white staff weapon scepter ruler ruling glowing enchanted enchantment talent:pursuit_of_justice(paladin)",
	["spell_holy_power"] = "silver helmet armor defense protection steel metal plate divine magic glowing white eyes bearded dwarf paladin light",
	["spell_holy_powerinfusion"] = "yellow divine anger angry fury furious rage raging aggression powerful glowing enchanted enchantment magic talent:power_infusion(priest)",
	["spell_holy_powerwordbarrier"] = "yellow golden magic healing restoration glowing radiant radiance enchanted enchantment shield armor defense protection bubble lightbeams talent:divine_guardian(paladin) talent:power_word:_barrier(priest)",
	["spell_holy_powerwordshield"] = "golden yellow barrier armor defense protection magic blocking divine healing restoration lightbeams glowing enchanted enchantment radiant radiance tab:discipline(priest) spell:power_word:_shield(priest) talent:improved_power_word:_shield(priest) mastery:shield_discipline(priest)",
	["spell_holy_prayeroffortitude"] = "green glowing seal emblem sigil symbol magic divine power healing restoration lightbeams radiant radiance diamond",
	["spell_holy_prayerofhealing"] = "blue sky soldiers silver plate armor steel metal spears weapons helmets defense protection plume glowing restoration enchanted enchantment radiant radiance talent:repentance(paladin)",
	["spell_holy_prayerofhealing02"] = "glowing golden yellow divine power magic radiant radiance seal emblem sigil symbol barrier shield armor defense protection shiny sparkly sparkles bright lightbeams restoration spell:prayer_of_healing(priest)",
	["spell_holy_prayerofmendingtga"] = "golden yellow magic divine power healing restoration hands praying emblem sigil seal spell:prayer_of_mending(priest)",
	["spell_holy_prayerofshadowprotection"] = "purple magic defense demons summoned demonic creatures seal emblem sigil shadowy unholy figures voidwalkers runes symbols evil spell:shadow_protection(priest) talent:sin_and_punishment(priest)",
	["spell_holy_prayerofspirit"] = "blue yellow magic divine power glowing radiant radiance men human naked bare chests muscles",
	["spell_holy_proclaimchampion"] = "silver blue yellow plate armor steel metal helmet defense protection divine power magic radiant radiance lightbeam glowing enchanted enchantment horned horns",
	["spell_holy_proclaimchampion_02"] = "silver purple yellow plate armor steel metal helmet defense protection divine power magic lightbeam glowing radiant radiance enchanted enchantment horned horns talent:zealotry(paladin)",
	["spell_holy_pureofheart"] = "golden yellow casting magic divine power healing restoration glowing radiant radiance lightbeams point holidng conjuring hands center core",
	["spell_holy_purify"] = "golden yellow magic divine power healing restoration hand glowing radiant radiance lightbeam casting bright spell:cleanse(paladin)",
	["spell_holy_purifyingpower"] = "golden yellow magic divine healing restoration purification spell:holy_wrath(paladin)",
	["spell_holy_rapture"] = "white magic divine power healing restoration bright light halo angel spirit night elf gray grey radiant radiance glowing head face talent:rapture(priest)",
	["spell_holy_rebuke"] = "yellow golden magic divine power restoration healing hand arm clenched closed fist punch glowing radiant radiance knuckles spell:rebuke(paladin)",
	["spell_holy_redemption"] = "silver blood plate armor steel metal gloves wounded power divine magic restoration healing glowing radiant radiance light casting giving life bringing back restoring",
	["spell_holy_removecurse"] = "purple red cursed sword blade weapon steel metal magic decurse purify restore cleanse cleansing spell:remove_corruption(druid)",
	["spell_holy_renew"] = "green magic casting divine power restoration healing hand arm glowing radiant radiance spell:renew(priest) talent:improved_renew(priest)",
	["spell_holy_restoration"] = "yellow pink magic blast burst divine power healing lightbeams glowing radiant radiance talent:desperate_prayer(priest)",
	["spell_holy_resurrection"] = "blue silver blood plate armor steel metal gloves wounded power divine magic restoration healing glowing radiant radiance light casting giving life bringing back restoring spell:redemption(paladin) spell:resurrection(priest)",
	["spell_holy_retribution"] = "yellow golden sands skulls skeletons skeletal dust erosion ashes fading away eroding exorcism magic power bones spirits ghosts apparitions",
	["spell_holy_retributionaura"] = "red silver steel metal sword blade weapon glowing enchanted enchantment radiant radiance circles power magic",
	["spell_holy_revivechampion"] = "yellow gray grey silver helmet armor defense protection plate steel metal horns horned divine power magic lightbeams radiant radiance enchanted enchantment glowing faded fallen dead",
	["spell_holy_righteousfury"] = "yellow golden shiny silver hammer mace weapon steel metal smashing striking attacking motion movement spell:judgement(paladin)",
	["spell_holy_righteousnessaura"] = "blue silver steel metal sword blade weapon glowing enchanted enchantment radiant radiance circles power magic spell:seal_of_righteousness(paladin)",
	["spell_holy_rune"] = "yellow golden magic divine power glowing radiant radiance enchanted enchantment symbol healing restoration talent:selfless_healer(paladin)",
	["spell_holy_sealofblood"] = "silver red orange yellow sigil emblem symbol swords blades weapons steel metal crossed glowing enchanted enchantment radiant radiance magic power",
	["spell_holy_sealoffury"] = "red yellow orange golden metal black winged sword blade weapon sigil emblem symbol glowing enchanted enchantment radiant radiance magic power spell:righteous_fury(paladin)",
	["spell_holy_sealofmight"] = "golden yellow thor's mace weapon lightning bolts thunder enchanted enchantment glowing sigil emblem symbol magic power spell:hammer_of_justice(paladin) talent:improved_hammer_of_justice(paladin)",
	["spell_holy_sealofprotection"] = "silver grey gray sigil emblem symbol golden yellow crown feathers purple royalty magic power spell:hand_of_protection(paladin) talent:guardian's_favor(paladin)",
	["spell_holy_sealofrighteousness"] = "green sigil emblem symbol winged wings skull undeath undead mouth glowing enchanted enchantment radiant radiance poison toxic disease scourge teeth magic power corpse",
	["spell_holy_sealofsacrifice"] = "blood drop red symbol emblem tear liquid circle spell:hand_of_sacrifice(paladin) professions:first_aid",
	["spell_holy_sealofsalvation"] = "golden yellow magic divine power prayer praying hands circle emblem sigil aura symbol healing restoration spell:hand_of_salvation(paladin)",
	["spell_holy_sealofvalor"] = "red orange symbol emblem sigil sword blade weapon glowing enchanted enchantment magic spell:hand_of_freedom(paladin)",
	["spell_holy_sealofvengeance"] = "yellow golden steel metal daggers blades weapons knives knife crossed conflicting conflicted battle attack emblem sigil symbol magic power spell:seal_of_truth(paladin) talent:twin_disciplines(priest)",
	["spell_holy_sealofwisdom"] = "cross circle gold emblem sigil symbol healing restoration magic divine power aura",
	["spell_holy_sealofwrath"] = "circle golden yellow plate armor steel metal fist clenched resolve purpose determination determined emblem sigil symbol healing restoration magic power knuckles aura spell:seal_of_justice(paladin) talent:divine_fury(priest)",
	["spell_holy_searinglight"] = "yellow golden touch magic divine power glowing radiant radiance healing restoration spell:holy_fire(priest) talent:holy_shock(paladin)",
	["spell_holy_searinglightpriest"] = "yellow golden magic divine power radiant radiance lightbeams glowing reaching out touch grasping holding blocking burning cleansing purifying purging sunlight",
	["spell_holy_senseundead"] = "blue floating flying skulls undeath magic enchanted enchantment shadow demonic creatures fel power necromancy glowing eyes unholy evil scourge corpses spirits ghosts apparitions heads",
	["spell_holy_serendipity"] = "swirly swirls blue yellow lightbeams radiant radiance glowing lightwells magic divine power talent:serendipity(priest)",
	["spell_holy_silence"] = "pink red face lipstick kissing hushing hushed silencing silenced kept quiet duress human female",
	["spell_holy_spellwarding"] = "blue yellow shadowy unholy figure silhouette outline casting magic power evil divine meditiation healing restoration",
	["spell_holy_spiritualguidence"] = "yellow golden magic divine power healing restoration meditation monk third eyes glowing radiant radiance human face head meditating passive:mysticism(priest)",
	["spell_holy_stoicism"] = "blue stone gray grey hand finger pointing magic talent:vampiric_touch(priest)",
	["spell_holy_summonchampion"] = "blue silver plate armor steel metal helmet defense protection horned horns radiant radiance glowing lightbeams emblem sigil seal symbol magic power strength",
	["spell_holy_summonlightwell"] = "yellow golden summoning healing restoration magic divine power glowing radiant radiance lightbeams sparks runes runic of circle burst blast point spot aura talent:lightwell(priest)",
	["spell_holy_surgeoflight"] = "yellow pink healing restoration magic power lightbeams sunlight sunrise sunset human person standing radiant radiance glowing burst blast spell:divine_light(paladin) talent:surge_of_light(priest)",
	["spell_holy_symbolofhope"] = "gray grey red stone statue flowers roses petals icon deity hero human person spell:hymn_of_hope(priest) talent:body_and_soul(priest)",
	["spell_holy_testoffaith"] = "yellow golden magic prayer divine power healing restoration lightbeams sunlight morning praying hands together head female human person talent:test_of_faith(priest)",
	["spell_holy_turnundead"] = "green skeleton skeletal skull glowing demonic creature undeath eyes mouth corrupted fel magic unholy power scourge bones corpse spell:turn_evil(paladin)",
	["spell_holy_unyieldingfaith"] = "marked cross symbol yellow divine power magic fingers lightbeams radiant radiance glowing healing restoration spell:hand_of_reckoning(paladin)",
	["spell_holy_vindication"] = "golden red yellow orange fire fiery burning hot heat flames flaming blazing scorching searing plate armor steel metal gloves gauntlets first knuckles glowing impact divine power magic strength strong talent:vindication(paladin)",
	["spell_holy_weaponmastery"] = "yellow golden metal swords blades weapons crossed conflicting conflicted battle attack glowing enchanted enchantment radiant radiance light divine power magic",
	["spell_holy_wordfortitude"] = "glowing seal emblem sigil symbol magic divine healing restoration lightbeams radiant radiance diamond blue white spell:power_word:_fortitude(priest)",
	["spell_ice_lament"] = "blue-green cyan skull skeleton skeletal face glowing eyes shield armor defense protection magic icy frozen freezing frosty bones talent:cold_blood(rogue) talent:ice_barrier(mage)",
	["spell_ice_magicdamage"] = "blue icy cold frozen freezing frosty bolt missile nuke power fire fiery burning hot heat flames flaming blazing scorching searing flying",
	["spell_ice_rune"] = "blue icy cold frozen freezing frosty of power symbol glowing radiant radiance magic lightbeams 1 letter snowflakes snowing snowy blast burst explosion",
	["spell_lfieblood"] = "green plant healing restoration nature natural magic herbalism herbs bubbles lifeblood nurturing nurture glowing",
	["spell_lifegivingseed"] = "green plant healing restoration nature natural magic herbalism herbs seedling sapling budding emerging nurturing nurture glowing",
	["spell_lifegivingspeed"] = "foot human ankle fast speedy rushed rushing running dashing quick green glowing nature magic power increased talent:ancestral_swiftness(shaman)",
	["spell_lightning_lightningbolt01"] = "purple blue nature magic power crackle crackling thunderbolt jagged thunderstorm stormy cloudy clouds sky heavens electricity natural talent:telluric_currents(shaman)",
	["spell_mage_curtainoffrost"] = "blue apron snowflakes shroud veil mystery ice icy cold frozen freezing frosty clothing magic power",
	["spell_mage_flameorb"] = "yellow orange fire fiery burning hot heat flames flaming blazing scorching searing circle radiant radiance glowing magic power sun blast burst sphere spell:flame_orb(mage)",
	["spell_magearmor"] = "blue mage's wizard's robe clothing fire fiery burning hot heat flames flaming blazing scorching searing ethereal arcane magic conjured protection defense defensive spell:mage_armor(mage)",
	["spell_magic_featherfall"] = "yellow orange purple slowfall levitation gravity wind flying floating falling drifting away animal winged creature feathered feathers bird's plucked spell:slow_fall(mage)",
	["spell_magic_greaterblessingofkings"] = "blue golden yellow glowing radiant radiance plate armor steel metal helmet defense protection lightbeams spell:blessing_of_kings(paladin)",
	["spell_magic_lesserinvisibilty"] = "blue bald human head duplicates copies person clones cloned copied duplicated replicated replication figures images deception illusion arcane talent:elusiveness(rogue) spell:fade(priest) talent:veiled_shadows(priest) spell:mirror_image(mage)",
	["spell_magic_magearmor"] = "silver blue glowing radiant radiance plate steel metal helmet defense protection lightbeams",
	["spell_magic_managain"] = "blue stars wisps specks dots dust particles spring regeneration healing restoration holy power shiny sparkly sparkles spots points lights radiant radiance enchanted enchantment magical",
	["spell_magic_polymorphchicken"] = "white critter farm animal creature feathers feathered head beak companion:ancona_chicken",
	["spell_magic_polymorphpig"] = "brown gray grey farm animal hog tusks head creature spell:polymorph:_pig(mage)",
	["spell_magic_polymorphrabbit"] = "blue white furry creature animal critter bunny easter noblegarden head tongue sticking out lightning thunderbolt bulging eyes striking hitting spell:polymorph:_rabbit(mage)",
	["spell_misc_conjuremanajewel"] = "blue white shiny gemstone diamond sparkly sparkles reflections reflective sharp racial_passive:gemcutting(draenei)",
	["spell_misc_drink"] = "silver steel metal mug mead root beer handle lid cup liquid alcoholic booze dwarven stout",
	["spell_misc_emotionafraid"] = "purple frowning scared unsure nervous emoticon food buff face human mask",
	["spell_misc_emotionangry"] = "red anger fury furious rage raging aggression frowning emoticon food buff face human mask",
	["spell_misc_emotionhappy"] = "yellow pleased pleasant smiling grinning smile joyful emoticon food buff face human mask",
	["spell_misc_emotionsad"] = "blue pouting frowning unhappy displeased disappointed emoticon food buff face human mask",
	["spell_misc_food"] = "orange yellow swiss cheese with holes wedge slice triangle snack buff",
	["spell_misc_hellifrepvpcombatmorale"] = "red arrows up diagonal circle battle plan map directions directional boosted high lifted fireworks aura magic power",
	["spell_misc_hellifrepvphonorholdfavor"] = "blue kingdom of lordaeron symbol emblem sigil seal banner alliance warship boat mast flag moon",
	["spell_misc_hellifrepvpthrallmarfavor"] = "red orgrimmar symbol emblem sigil seal banner horde warship boat mast flag moon",
	["spell_misc_warsongbrutal"] = "yellow green torn flag destroyed desecrated desecration ripped banner warship mast boat",
	["spell_misc_warsongfocus"] = "red torn flag destroyed desecrated desecration ripped banner warship mast boat talent:veteran_of_the_third_war(death_knight)",
	["spell_nature_abolishmagic"] = "wisp blue-green cyan blast burst explosion glowing power lightbeams radiant radiance talent:starlight_wrath(druid)",
	["spell_nature_acid_01"] = "blue water liquid poison toxic disease erosion corrosion goo magic power",
	["spell_nature_agitatingtotem"] = "red skull bones weapon stick bloody voodoo talent:totemic_reach(shaman)",
	["spell_nature_ancestralguardian"] = "yellow orange red tauren bull horned horns furry animal creature beast anger angry fury furious raging aggression intimidating grunting baring teeth mouth head magic power spell:berserker_rage(warrior)",
	["spell_nature_astralrecal"] = "purple portal swirly spiraling tunnel teleportation wormhole glowing magic power vortex maelstrom spell:astral_recall(shaman)",
	["spell_nature_astralrecalgroup"] = "purple portal swirly spiraling tunnel teleportation wormhole glowing magic power vortex maelstrom sparks sparkly sparkles lights radiant radiance talent:acuity(shaman)",
	["spell_nature_bloodlust"] = "red golden yellow bloody shield armor defense protection blocking face skull spell:bloodlust(shaman) talent:bloodthirst(warrior)",
	["spell_nature_brilliance"] = "scepter staff weapon wand ranged blue ice icy cold frozen freezing frosty magic glowing radiant radiance lightbeams shard tip point spell:totem_of_tranquil_mind(shaman)",
	["spell_nature_callstorm"] = "thrall warchief orcish calling summoning lightning thunderbolt gray grey green blue skies thunderstorm clouds cloudy bleak magic power crackle crackling natural talent:rolling_thunder(shaman)",
	["spell_nature_chainlightning"] = "blue orcish hand summoning calling thunderbolt magic power spell:chain_lightning(shaman)",
	["spell_nature_corrosivebreath"] = "magic green poison toxic disease liquid goo snot mucus gross felblood venom spit saliva deadly",
	["spell_nature_crystalball"] = "light blue cyan orb globe sphere water liquid container seer magical future vision insight prediction bauble passive:omen_of_clarity(druid)",
	["spell_nature_cyclone"] = "gray grey windy gusts gusty winds leaves tornado torrential blowing hurling carrying lifting destroying tearing ripping magic powerful destructive force natural storm whirlwind swirly spell:wind_shear(shaman) spell:hurricane(druid)",
	["spell_nature_diseasecleansingtotem"] = "purple green shaman skull purifying shadow unholy magic glowing evil wand weapon ranged",
	["spell_nature_drowsy"] = "purple warlock hand casting shadow unholy magic glowing power light demonic evil stuck leaves tree wooden encased trapped transformed transformation spell:tranquilizing_shot(hunter)",
	["spell_nature_dryaddispelmagic"] = "yellow orange brown green leaves thorns vines log stick totem fire fiery burning hot heat flames flaming blazing scorching searing dispelling undoing removing cleansing natural spells wand weapon ranged",
	["spell_nature_earthbind"] = "blue grey gray storm gusty winds windy gusts tornado vortex natural powerful destruction destructive force whirlwind swirly magic spell:cyclone(druid)",
	["spell_nature_earthbindtotem"] = "golden yellow clenched fist green glowing radiant radiance magical powerful knuckles wand weapon ranged strong spell:strength_of_earth_totem(shaman)",
	["spell_nature_earthelemental_totem"] = "brown ground conjured summoned magic strength strong powerful defense stones skin rocks spell:earth_elemental_totem(shaman) talent:earthen_power(shaman) companion:pebble",
	["spell_nature_earthquake"] = "brown ground sundering magic powerful explosion blast burst volcano lava magma fire fiery burning hot heat light mountain",
	["spell_nature_earthshock"] = "yellow brown mountains scenery landcape earthquake magic power spell:earth_shock(shaman)",
	["spell_nature_elementalabsorption"] = "gray grey hands holding clutching summoning absorbing taking red blue green take combined combining elements earth magical powers fire ice frost colorful light glowing clouds talent:seasoned_winds(shaman)",
	["spell_nature_elementalprecision_1"] = "red blue green take combined combining elements earth magical powers ice frost colorful light glowing clouds fireworks explosion blast burst talent:elemental_precision(shaman)",
	["spell_nature_elementalprecision_2"] = "red blue green take combined combining earth magical powers fire ice frost colorful light glowing clouds yellow orange hands conjuring summoning releasing gasses poisons toxins toxic mastery:enhanced_elements(shaman)",
	["spell_nature_elementalshields"] = "green sun circle felfireball fiery burning hot heat flames flaming blazing scorching searing barrier armor defense protection magic poison toxic disease demonic power planet eclipse sphere",
	["spell_nature_enchantarmor"] = "silver glowing blue steel metal helmet defense protection talent:tactical_mastery(warrior) talent:presence_of_mind(mage) passive:stance_mastery(warrior)",
	["spell_nature_eyeofthestorm"] = "blue gray grey hurricane clouds whirlwind cyclone tornado center middle swirly torrential windy gusts gusty winds magic power",
	["spell_nature_faeriefire"] = "purple warlock hand casting shadow unholy magic glowing power light demonic evil spell:faerie_fire(druid) spell:faerie_fire_(feral)(druid)",
	["spell_nature_farsight"] = "orange vision portal seer magic spell:far_sight(shaman)",
	["spell_nature_focusedmind"] = "glowing green eyes human face raised eyebrow emerald evil deception cunning sneaky driven",
	["spell_nature_forceofnature"] = "glowing light blue cyan animal creature bird winged feathered feathers beak silhouette outline magic power head talent:moonkin_form(druid)",
	["spell_nature_giftofthewaterspirit"] = "outline silhouette eagle light blue cyan emblem sigil seal bird animal winged creature feathered feathers wings restoration magic power spell:healing_rain(shaman) talent:soothing_rains(shaman)",
	["spell_nature_giftofthewild"] = "purple circle magic power pawprints animals creatures pact union bond connection",
	["spell_nature_groundingtotem"] = "purple chains ethereal ghostly ghastly white imprisonment bindings shackles shackled imprisoned bound shadow magic power glowing light radiant radiance spell:grounding_totem(shaman)",
	["spell_nature_guardianward"] = "orange viper cobra fangs teeth venomous poisonous toxic deadly bite mouth animal creature reptile magic glowing striking strike head spell:flametongue_totem(shaman) companion:albino_snake companion:black_kingsnake companion:brown_snake companion:crimson_snake",
	["spell_nature_healingtouch"] = "blue green fallen leaf water ice icy cold frozen freezing frosty magic power glowing life tab:restoration(druid) spell:healing_touch(druid) talent:naturalist(druid) mastery:deep_healing(shaman)",
	["spell_nature_healingwavegreater"] = "green blue orcish hand water liquid magic power restoration reaching casting spell:chain_heal(shaman)",
	["spell_nature_healingwavelesser"] = "green purple orcish hand water liquid magic power restoration reaching casting spell:greater_healing_wave(shaman)",
	["spell_nature_healingway"] = "green orcish hand holding conjuring yellow ball of light magic power restoration casting spell:healing_surge(shaman) mastery:harmony(druid)",
	["spell_nature_insectswarm"] = "green grasshopper bugs winged wings red eyes swarming group flying flight locusts army six legs magic power spell:insect_swarm(druid)",
	["spell_nature_invisibilitytotem"] = "blue staff weapon lightbeams glowing radiant radiance magical power arcane",
	["spell_nature_invisibilty"] = "bald human head pink deception mirror images swiftness speed increased fast illusion magic arcane conjured shadow talent:lightning_reflexes(rogue)",
	["spell_nature_lightning"] = "blue magic powerful thunderbolt natural crackle crackling jagged electricity tab:elemental_combat(shaman) spell:lightning_bolt(shaman) tab:elemental(shaman) talent:arcane_power(mage) spell:innervate(druid)",
	["spell_nature_lightningbolt"] = "green blue orcish hand summoning calling chain thunderbolt magic power shaman",
	["spell_nature_lightningoverload"] = "blue magic arcane power natural hands fingers thunderbolt crackle crackling striking hitting electricity mastery:elemental_overload(shaman)",
	["spell_nature_lightningshield"] = "purple thunder barrier armor defense protection magic blocking black obsidian power talent:sanctuary(paladin) tab:enhancement(shaman) spell:lightning_shield(shaman) talent:improved_shields(shaman)",
	["spell_nature_magicimmunity"] = "green orcish hand water liquid power reaching casting tab:restoration(shaman) spell:healing_wave(shaman)",
	["spell_nature_manaregentotem"] = "purple shining lightbeams radiant radiance power arcane regeneration healing restoration eyeball stick magic spell:mana_spring_totem(shaman)",
	["spell_nature_massteleport"] = "yellow pink silhouettes outlines warriors enchanted enchantment glowing teleportation displacement black swords blades weapons plate armor steel metal magic power",
	["spell_nature_mentalquickness"] = "green brain speedy fast agility running dashing smart intelligent talent:mental_quickness(shaman)",
	["spell_nature_mirrorimage"] = "green orcish shadow tusks teeth deception conjured illusion magic",
	["spell_nature_moonglow"] = "purple starlight moonlight starfire moonbeams blast burst comet shooting meteor rocket launch sky magic power talent:totemic_focus(shaman) talent:moonfury(druid)",
	["spell_nature_moonkey"] = "silver unlocks spell:pick_lock(rogue)",
	["spell_nature_natureblessing"] = "blue-green leaf fallen magic natural healing restoration talent:nature's_blessing(shaman)",
	["spell_nature_natureguardian"] = "blue starry sky landscape scenery background silhouette shadows tree branches leaves stars starlight shining sparkling shiny sparkly nighttime talent:nature's_guardian(shaman)",
	["spell_nature_natureresistancetotem"] = "green magic scepter weapon staff wand ranged leaves",
	["spell_nature_naturesblessing"] = "brown stump wooden tree bark talent:nature's_grace(druid)",
	["spell_nature_natureswrath"] = "light blue cyan talons claws bird animal winged creature feathered feathers glowing enchanted enchantment foot spell:nature's_grasp(druid)",
	["spell_nature_naturetouchdecay"] = "brown wood bark tree branch bough stick leaves dead dying barren decaying natural",
	["spell_nature_naturetouchgrow"] = "brown wood bark tree branch bough stick leaves green growing life berries natural professions:herb_gathering(herbalism)",
	["spell_nature_nullifydisease"] = "green purple skull undeath undead plague poison toxic deadly head glowing enchanted enchantment magic power scourge corpse",
	["spell_nature_nullifypoison"] = "green black spike claw toxic venom glowing lightbeams radiant radiance enchanted enchantment magic power",
	["spell_nature_nullifypoison_02"] = "green black spike claw toxic venom glowing leaves lightbeams radiant radiance magic power",
	["spell_nature_nullward"] = "purple glowing enchanted enchantment mask tiki face brown red bones totem stick",
	["spell_nature_poisoncleansingtotem"] = "green snake viper venomous poisonous toxic king cobra fangs mouth teeth animal creature magic power wand weapon ranged head",
	["spell_nature_polymorph"] = "sheep furry critter creature head animal white grass eating gnawing spell:polymorph(mage) talent:improved_polymorph(mage)",
	["spell_nature_polymorph_cow"] = "furry creature critter animal black white grass eating gnawing head",
	["spell_nature_preservation"] = "purple leaf star green magic power glowing enchanted enchantment healing restoration life",
	["spell_nature_protectionformnature"] = "green leaf magic life growing enchanted enchantment circles aura spell:aspect_of_the_wild(hunter)",
	["spell_nature_purge"] = "lightning thunder striking strike purple blue black shadowy figure radiant radiance natural power magic destruction talent:booming_voice(warrior) spell:purge(shaman) spell:evocation(mage)",
	["spell_nature_ravenform"] = "green talons claws foot bird animal winged creature feathered feathers outline silhouette magic power spell:aspect_of_the_hawk(hunter) talent:nature's_swiftness(shaman) talent:nature's_swiftness(druid)",
	["spell_nature_regenerate"] = "green blue hand life healing restoration magic power glowing enchanted enchantment radiant radiance spell:ancestral_spirit(shaman) racial_passive:regeneration(troll)",
	["spell_nature_regeneration"] = "purple pawprint creature animal black outline silhouette magic power spell:mark_of_the_wild(druid)",
	["spell_nature_regeneration_02"] = "green life magic tranquility healing restoration sparkles sparkly blue eyeball talent:cleansing_waters(shaman)",
	["spell_nature_reincarnation"] = "red orange tauren bull horned horns furry animal creature beast anger angry fury furious rage raging aggression shouting yelling intimidating mouth spell:taunt(warrior) spell:rebirth(druid)",
	["spell_nature_rejuvenation"] = "purple leaf magic power glowing enchanted enchantment healing restoration life spell:rejuvenation(druid) talent:improved_rejuvenation(druid)",
	["spell_nature_removecurse"] = "purple green rune symbol radiant radiance lightbeams hand grasping clutching fingers shadow unholy magic evil power fel spell:remove_curse(mage) talent:impending_doom(warlock)",
	["spell_nature_removedisease"] = "green purple skull glowing enchanted enchantment magic undead undeath poison toxic plague deadly head power scourge corpse",
	["spell_nature_resistmagic"] = "green orcish hand water liquid power healing restoration reaching casting",
	["spell_nature_resistnature"] = "green leaf magic power glowing enchanted enchantment healing restoration life spell:regrowth(druid) talent:nature's_bounty(druid)",
	["spell_nature_riptide"] = "blue turbulent waves water liquid sea ocean stormy elements elemental natural magic power surface talent:riptide(shaman)",
	["spell_nature_rockbiter"] = "green mace weapon enchanted enchantment spikes spiked spiky swinging moving motion striking strike attacking",
	["spell_nature_rune"] = "light green glowing enchanted enchantment symbol magic power healing restoration radiant radiance talent:ancestral_resolve(shaman)",
	["spell_nature_sentinal"] = "blue black sky moonlight owl creature animal feathered feathers bird winged hawk guardian nighttime watching looking cliff silhouette shadowy shadows figure outline talent:moonglow(druid)",
	["spell_nature_shamanrage"] = "red silhouette outline anger angry fury furious raging aggression berserked glowing radiant radiance warrior horned horns spell:dark_command(death_knight) talent:shamanistic_rage(shaman)",
	["spell_nature_skinofearth"] = "green brown magic glowing enchanted enchantment radiant radiance plates armor plated defense protection blocking barrier talent:earth_shield(shaman)",
	["spell_nature_sleep"] = "pink human sleeping eyes closed napping dozing off unconsciousness dead death eyebrows eyelids spell:hibernate(druid) talent:meditation(paladin) talent:meditation(priest) talent:meditation(shaman) talent:meditation(druid)",
	["spell_nature_slow"] = "red orange golden yellow glowing fire fiery burning hot heated enchanted enchantment radiant radiance forged forging magic power spell:shackle_undead(priest) talent:slow(mage)",
	["spell_nature_slowingtotem"] = "green wand weapon ranged glowing radiant radiance enchanted enchantment skull horns horned sparkly sparkles magic power spell:wrath_of_air_totem(shaman)",
	["spell_nature_slowpoison"] = "purple toxic needle point sharp tip blade dagger weapon knife",
	["spell_nature_spiritarmor"] = "green silver magic shield defense protection blocking riveted eagle creature flying animal winged wings feathered feathers talent:elemental_warding(shaman) racial_passive:nature_resistance(tauren) racial_passive:nature_resistance(night_elf) talent:gift_of_nature(druid)",
	["spell_nature_spiritwolf"] = "canine dog worg animal furry creature beast purple teeth snarling fangs head spell:dismiss_pet(hunter) spell:ghost_wolf(shaman) talent:feral_swiftness(druid)",
	["spell_nature_starfall"] = "purple bolt nuke magic power spell:arcane_missiles(mage) talent:improved_arcane_missiles(mage) tab:balance(druid) spell:moonfire(druid)",
	["spell_nature_stoneclawtotem"] = "red yellow orange furry animal creature claws paw hand wooden wand weapon ranged green glowing radiant radiance fire fiery burning hot heat magic power spell:stoneclaw_totem(shaman) spell:barkskin(druid)",
	["spell_nature_stoneskintotem"] = "purple arcane rune symbol obelisk obsidian glowing radiant radiance metal point tip pyramid lightning magic power spell:stoneskin_totem(shaman)",
	["spell_nature_stormreach"] = "blue lightning thunderbolt jagged natural magic power impacting hitting striking crackle crackling electricity talent:elemental_reach(shaman)",
	["spell_nature_stranglevines"] = "green brown entangled hand arm fist trapped magic knuckles talent:entrapment(hunter) talent:earth's_grasp(shaman) spell:entangling_roots(druid)",
	["spell_nature_strength"] = "pink human muscles arm flexing strong power bodybuilding fist hand naked",
	["spell_nature_strengthofearthtotem02"] = "gray grey blue stone rock chains chained glowing radiant radiance enchanted enchantment magic strong powerful spell:earthbind_totem(shaman)",
	["spell_nature_swiftness"] = "blue passive:artisan_riding passive:master_riding passive:apprentice_riding passive:journeyman_riding passive:expert_riding",
	["spell_nature_thorns"] = "green brown vines roots sharp spikes spiky magic power growing spell:thorns(druid)",
	["spell_nature_thunderclap"] = "orcish smashing striking impacting hitting thor's hammer mace weapon lightning power magic enchanted enchantment blow swinging moving motion hand arm wristband gray grey blue spell:thunder_clap(warrior)",
	["spell_nature_timestop"] = "orange golden yellow pocketwatch clock hands chronos fast slowed stopped halted tempo speed rate magic power fire fiery burning hot heat flames flaming blazing scorching searing pet_command:stay(hunter)",
	["spell_nature_tranquility"] = "blue sky landscape scenery background daytime clouds lightning thunder water liquid reflections surface lake sea ocean ripples waves spell:tranquility(druid)",
	["spell_nature_tremortotem"] = "yellow gray grey hammer mace weapon glowing enchanted enchantment golden stone symbol emblem rune of power spell:tremor_totem(shaman)",
	["spell_nature_undyingstrength"] = "green orcish hand leather armor wristband holding clutching grasping weapon fist steel metal sword blade spear polearm glowing enchanted enchantment strong talent:ancestral_healing(shaman)",
	["spell_nature_unleashedrage"] = "yellow orange fire fiery burning hot heat flames flaming blazing scorching searing anger angry fury furious raging aggression sword blade weapon outline silhouette magic power talent:unleashed_rage(shaman)",
	["spell_nature_unrelentingstorm"] = "blue lightning thunderbolt magic power shockwave crater ocean sea liquid water splash tsunami tidal impact blast burst explosion spikes spiky bear trap striking hitting electricity natural surface talent:fulmination(shaman)",
	["spell_nature_unyeildingstamina"] = "yellow bull horned horns furry animal creature beast cow silhouette outline strong strength magic power head talent:leader_of_the_pack(druid) racial_passive:endurance(tauren)",
	["spell_nature_web"] = "purple glowing enchanted enchantment natural spider's silk mesh grid",
	["spell_nature_windfury"] = "blue purple yellow wand weapon ranged glowing radiant radiance light magic power casting spell:windfury_totem(shaman)",
	["spell_nature_wispheal"] = "blue yellow orange lightning thunderbolt impacting hitting striking jagged electricity natural magic power crackle crackling talent:elemental_mastery(shaman) talent:critical_mass(mage)",
	["spell_nature_wispsplode"] = "blue exploding blasting supernova shockwave circle power magic starlight flare implosion point burst spot spell:arcane_explosion(mage) talent:improved_arcane_explosion(mage) talent:natural_shapeshifter(druid) racial_passive:wisp_spirit(night_elf) racial_passive:arcane_resistance(gnome)",
	["spell_nature_wispsplodegreen"] = "arcane explosion exploding blasting supernova shockwave circle power magic starlight flare implosion point burst talent:spark_of_life(shaman) professions:lifeblood(herbalism)",
	["spell_nature_wrathofair_totem"] = "blue runes symbols flames fire magic power",
	["spell_nature_wrathv2"] = "magic bolt missile nuke power ball light glowing dust sun rays sand spark spell:wrath(druid)",
	["spell_paladin_clarityofpurpose"] = "golden yellow lightbeams radiant radiance glowing enchanted enchantment holy magic divine power armor steel metal chestplate defense protection shoulders human healing restoration talent:clarity_of_purpose(paladin)",
	["spell_paladin_divinecircle"] = "golden yellow radiant glowing bright lightbeams book reading pages paper magic power knowledge intellect aura spot point enlightenment spell:holy_radiance(paladin)",
	["spell_paladin_inquisition"] = "golden yellow lightbeams arrows pointing upward outlines silhouettes toward sky sunlight holy magic divine power raise lift tall figures radiant radiance spell:inquisition(paladin)",
	["spell_paladin_lightofdawn"] = "yellow golden fire fiery burning hot heat flames flaming blazing scorching searing holy magic divine power lightbeams bright intense circles aura sunlight sunrise radiant radiance healing restoration talent:light_of_dawn(paladin)",
	["spell_paladin_templarsverdict"] = "yellow silver gray grey steel metal hammer mace weapon rune of power symbol glowing circles lines wrapped entangled enchanted enchantment aura magic talent:templar's_verdict(paladin)",
	["spell_priest_chakra"] = "red yellow golden cross symbol emblem sigil seal holy divine magic power radiant radiance enchanted enchantment lightbeams circles aura healing restoration talent:chakra(priest)",
	["spell_priest_mindspike"] = "purple shadow magical wand weapon ranged glowing enchanted enchantment diamond cloudy liquid gemstone spear light striking thrusting spell:mind_spike(priest)",
	["spell_priest_shadoworbs"] = "purple magic circle sphere power talent:shadow_orbs(priest)",
	["spell_shadow_abominationexplosion"] = "red bloody vomiting dying zombie undead undeath unholy poisoned toxic diseased plagued teeth mouth head evil scourge corpse spell:corruption(warlock) talent:improved_corruption(warlock)",
	["spell_shadow_animatedead"] = "green moonlight hand reaching raised fingers clutching grasping undead undeath unholy zombie raising white nighttime midnight necromancy magic glowing enchanted enchantment evil scourge corpse spell:raise_dead(death_knight) talent:master_of_ghouls(death_knight)",
	["spell_shadow_antimagicshell"] = "green rune of power symbol emblem 999 666 unlucky unholy hex voodoo demonic evil superstition superstitious squiggles lines glowing spell:anti-magic_shell(death_knight) talent:magic_suppression(death_knight) racial_passive:arcane_resistance(blood_elf)",
	["spell_shadow_antishadow"] = "purple magic protection defense summoned demonic creature seal emblem sigil shadowy figure unholy voidwalker runes symbols evil spell:shadow_ward(warlock) racial_passive:aberration(worgen)",
	["spell_shadow_auraofdarkness"] = "whites green eyeballs glowing eyes flaming demonic creatures evil scary scared haunted nervous ghosts demons apparitions fearful terrified terror horror horrified afraid the unholy spell:bane_of_doom(warlock)",
	["spell_shadow_blackplague"] = "purple floating flying skulls undeath magic enchanted enchantment demonic creatures fel power necromancy glowing eyes unholy evil undead scourge corpses spirits ghosts apparitions heads",
	["spell_shadow_bloodboil"] = "red boiling liquid bubbles surface pool unholy evil",
	["spell_shadow_brainwash"] = "purple knowledge intellect internal organ memory mind control noggin noodle magic power",
	["spell_shadow_burningspirit"] = "black purple hawk eagle bird animal winged creature feathered feathers flight flying head wings tail beak unholy magic power nature natural evil talent:virulence(death_knight) spell:life_tap(warlock) talent:improved_life_tap(warlock) passive:avoidance(hunter)",
	["spell_shadow_callofbone"] = "yellow white bones skulls totems voodoo unholy evil",
	["spell_shadow_carrionswarm"] = "blue white moths bugs swarming insects flying group flight unholy",
	["spell_shadow_charm"] = "purple magic power glowing eyes demonic creature evil smile grin face shadowy figure unholy raised eyebrows vision sight racial:every_man_for_himself(human)",
	["spell_shadow_chilltouch"] = "purple hand casting unholy magic bones arm undead undeath ghoul apparition skeleton skeletal claws ghastly ghostly ethereal reaching grasping spirit scary haunting evil scourge corpse spell:curse_of_the_elements(warlock)",
	["spell_shadow_coneofsilence"] = "purple blue glowing ghoul unholy magic bright light x-ray xray medical teeth fangs skull skeleton skeletal undead undeath ethereal figure ghostly ghastly apparition spirit bones eye sockets mouth haunting scary evil scourge corpse",
	["spell_shadow_contagion"] = "blue white moths bugs swarming insects flying group flight talent:unholy_blight(death_knight)",
	["spell_shadow_corpseexplode"] = "red bloody skull skeleton skeletal undeath undead unholy exploding explosion blowing up body sticky liquid blast burst evil scourge bones",
	["spell_shadow_creepingplague"] = "yellow cliff rocks injury wound broken shattered torn ripped skin earth breaking down dissolved dissolving unholy",
	["spell_shadow_cripple"] = "green lightbeam of talons claws bird animal winged creature feathered feathers demonic glowing hand foot fingernails unholy nature magic power blast burst evil spell:banish(warlock)",
	["spell_shadow_curse"] = "purple red sword blade weapon cursed skull partitioned line division divided aura glowing enchanted enchantment unholy magic power",
	["spell_shadow_curseofachimonde"] = "blue arcane intellect brilliance lightning thunderbolts cursed crossed out canceled cancelled negated broken undone destroyed revoked glowing thunderstorm sky torn rift disenchanted unholy magic power",
	["spell_shadow_curseofmannoroth"] = "green silver golden glowing poison steel metal sword blade weapon crossed out cursed canceled cancelled destroyed broken undone negated revoked torn rift disenchanted unholy magic power spell:curse_of_weakness(warlock)",
	["spell_shadow_curseofsargeras"] = "yellow red orange silver lightning thunderbolts cursed crossed out canceled cancelled negated broken undone destroyed revoked glowing thunderstorm sky torn rift shield armor defense protection blocking barrier magic steel metal disenchanted unholy power spell:bane_of_agony(warlock) talent:doom_and_gloom(warlock)",
	["spell_shadow_curseoftounges"] = "yellow orange red summoned demonic fire fiery burning hot heat flames flaming blazing scorching searing creature imp cursed glowing mouth teeth eyes pointy pointed ears unholy evil magic power head face spell:curse_of_tongues(warlock)",
	["spell_shadow_darkritual"] = "blue ice icy cold frozen freezing frosty corpse hand lightbeam casting magic skeletal skeleton bones claws undead undeath demonic creature evil necromancy unholy",
	["spell_shadow_darksummoning"] = "silver glowing green undead undeath warriors skeletal army of the raised enchanted enchantment spears weapons plume helmets armor defense protection plate steel metal necromancy magic powerful unholy evil scourge corpses",
	["spell_shadow_deadofnight"] = "glowing green yellow moon white undead undeath raised necromancy enchanted enchantment hand reaching grasping magic powerful unholy evil scourge corpse spell:raise_ally(death_knight)",
	["spell_shadow_deathanddecay"] = "red rose flower herbalism mageroyal wilting decaying falling apart petals dropping green stem life dying withering rotting unholy spell:death_and_decay(death_knight) talent:morbidity(death_knight)",
	["spell_shadow_deathcoil"] = "green glowing skull skeleton skeletal demonic creature melting corpse undead undeath fire fiery burning hot heat flames flaming blazing scorching searing evil mouth eyes socket dying decaying unholy magic power scourge bones head spell:death_coil(death_knight) tab:affliction(warlock) spell:death_coil(warlock)",
	["spell_shadow_deathpact"] = "red orange yellow fist power strength fire fiery burning hot heat clenched glowing enchanted enchantment knuckles unholy magic strong talent:death_wish(warrior) spell:death_pact(death_knight) talent:bane(warlock)",
	["spell_shadow_deathscream"] = "red skull skeletal skeleton bloodlust bloody tusks teeth mouth open yelling screaming roaring intimidating anger angry fury furious rage raging aggression terrifying corpse undeath undead unholy evil scourge bones talent:piercing_howl(warrior) talent:murderous_intent(rogue) spell:howl_of_terror(warlock) talent:improved_howl_of_terror(warlock)",
	["spell_shadow_deathsembrace"] = "purple face banshee undeath undead spirit ghost apparition haunting phantom glowing eyes open mouth ethereal trapped rooted held place pale anger angry fury furious rage raging aggression unholy evil magic power scourge corpse talent:death's_embrace(warlock)",
	["spell_shadow_demonbreath"] = "white blue eyes bubbles liquid demonic creature evil magic power breating lurking monster unholy spell:water_breathing(shaman) spell:unending_breath(warlock) racial_passive:underwater_breathing(undead)",
	["spell_shadow_demonform"] = "purple demonic evil creature horned horns glowing eyes pointed ears fel magic power summoned unholy head talent:metamorphosis(warlock)",
	["spell_shadow_demoniccirclesummon"] = "green of power runes symbols ritual seance gathering spirits ghosts glowing lights ethereal essences summoning casting fel magic aura unholy evil spell:demonic_circle:_summon(warlock)",
	["spell_shadow_demoniccircleteleport"] = "green of power runes symbols ritual seance gathering spirits ghosts glowing lights ethereal essences summoning casting fel magic aura unholy evil spell:demonic_circle:_teleport(warlock)",
	["spell_shadow_demonicempathy"] = "cursed purple skull skeletal glowing eyes creature power magic undeath undead enchanted enchantment symbol emblem unholy evil scourge corpse head talent:death's_advance(death_knight)",
	["spell_shadow_demonicfortitude"] = "red yellow orange fire fiery burning hot heat flames flaming blazing scorching searing symbol emblem skull creature power magic glowing eyes enchanted enchantment undead undeath scythe unholy evil scourge corpse head spell:shadow_word:_death(priest)",
	["spell_shadow_demonicpact"] = "yellow orange red gray grey summoned creature felguard glowing green eyes fire fiery burning hot heat flames flaming blazing scorching searing helmet armor defense protection explosion blast burst mouth head horn magic power unholy evil talent:demonic_pact(warlock)",
	["spell_shadow_demonictactics"] = "purple red yellow creature fel shadowy magic power skull skeletal undead undeath mind deceit horns cracked unholy evil scourge head corpse talent:demonic_rebirth(warlock)",
	["spell_shadow_destructivesoul"] = "yellow red orange hands holding grasping casting summoning fire fiery burning hot heat magic power demonic destruction blast burst explosion unholy",
	["spell_shadow_detectinvisibility"] = "green black fel glowing lightbeams explosion blast burst magic power radiant radiance circle aura eye sight vision bubbles liquid racial_passive:shadow_resistance(draenei) racial_passive:shadow_resistance(undead)",
	["spell_shadow_detectlesserinvisibility"] = "blue-green cyan black arcane water liquid depth charge barrier armor defense protection magic ward glowing lightbeams explosion blast burst power radiant radiance circle aura eye sight vision bubbles spell:mana_shield(mage)",
	["spell_shadow_devouringplague"] = "purple demonic creature evil skull glowing eyes skeletal mouth open teeth breath undeath undead poison diseased pestilence unholy magic power scourge corpse head spell:devouring_plague(priest)",
	["spell_shadow_devouringplague."] = "purple demonic creature evil skull glowing eyes skeletal mouth open teeth breath undeath undead poison diseased pestilence unholy magic power scourge corpse head talent:improved_devouring_plague(priest)",
	["spell_shadow_dispersion"] = "purple arcane magic power remove curse disease poison purify cleanse sparkles sparkly swirly spiraling light fade fading disperse dispersing vortex talent:dispersion(priest)",
	["spell_shadow_enslavedemon"] = "blue cyan hand fingers magic fel power demonic evil sign runes of pale symbols unholy spell:enslave_demon(warlock) passive:control_demon(warlock)",
	["spell_shadow_evileye"] = "yellow white eyeball bloody demonic fel magic power unholy spell:eye_of_kilrogg(warlock)",
	["spell_shadow_felarmour"] = "green magic power demonic creature shield defense protection blocking barrier ward skull mouth breath skeletal undead undeath poison toxic plague pestilence disease unholy evil scourge corpse face spell:fel_armor(warlock)",
	["spell_shadow_felmending"] = "purple red shadowy hand reaching grasping demonic creature fingers evil claws magic power bubbles boiling liquid raise undeath undead risen unholy talent:fel_synergy(warlock)",
	["spell_shadow_fingerofdeath"] = "claws fingernails hand undead undeath green glowing enchanted enchantment magic power casting fel demonic creature evil pointing unholy",
	["spell_shadow_focusedpower"] = "blue light divided ripped magic fragmented splitting dividing fragmenting ripping shadowy figure arcane",
	["spell_shadow_fumble"] = "green silver brown hand grasping steel metal sword blade weapon plate armor glowing enchanted enchantment magic fel demonic power hilt unholy talent:initiative(rogue)",
	["spell_shadow_gathershadows"] = "purple fel demonic magic power skull skeletal ghostly ghastly apparitions ethereal spirits demons creatures gathering circling swirling swirly spiraling unholy evil vortex maelstrom spell:soul_link(warlock)",
	["spell_shadow_ghostkey"] = "purple unlocks",
	["spell_shadow_grimward"] = "white red skull shield armor defense protection blocking skeletal undeath undead sticks totem teeth eyes sockets unholy evil spell:disarm_trap(rogue) talent:curse_of_exhaustion(warlock)",
	["spell_shadow_haunting"] = "blue ethereal ghosts apparitions spirits undeath undead gathering dissolving dust melting exorcism floating skeletons skeletal mouths eyes sockets unholy evil magic bones power scourge corpses spell:drain_soul(warlock)",
	["spell_shadow_impphaseshift"] = "purple yellow glowing goblin summoned demonic creature fel magic power hands head ears mouth eyes fingernails fingers casting summoning unholy evil talent:master_summoner(warlock)",
	["spell_shadow_improvedvampiricembrace"] = "purple bloody hand symbol of power bloodlust ritualistic spattered spattering splattered splattering fingers glowing enchanted enchantment unholy magic",
	["spell_shadow_lastingaffliction"] = "green yellow golden melting pocketwatch clock acid dissolving goo bubbles metal corrosion time chronos speed tempo fast slowed stopped sped up destroyed destroying halted magic power talent:pandemic(warlock)",
	["spell_shadow_lastingafflictions"] = "green cyan turquoise pocketwatch clock fire fiery burning hot heat flames flaming blazing scorching searing steel metal time chronos speed tempo fast slowed stopped sped up halted magic power",
	["spell_shadow_lifedrain"] = "red dripping droplets drops falling raining dropping liquid unholy talent:hemorrhage(rogue) talent:vampiric_blood(death_knight) spell:health_funnel(warlock) talent:improved_health_funnel(warlock)",
	["spell_shadow_lifedrain02"] = "green glowing eyes mouth spirits ghosts ethereal posession posessed demonic creature evil exorcism human head fel magic power draining stealing sucking siphoning force unholy apparition spell:drain_life(warlock)",
	["spell_shadow_manaburn"] = "blue hand claws clutching casting magic power point spot star ball of light fingernails spell:mana_burn(priest) talent:elemental_focus(shaman) talent:arcane_concentration(mage)",
	["spell_shadow_manafeed"] = "purple blue glowing eyes face human blood elf shadows magic power star shine shiny shining sparkle sparkly sparkling head talent:mana_feed(warlock)",
	["spell_shadow_metamorphosis"] = "purple orange red yellow creature glowing fire fiery burning hot heat flames flaming blazing scorching searing eyes frowning fel magic power sight vision unholy evil head tab:demonology(warlock) talent:demonic_embrace(warlock)",
	["spell_shadow_mindbomb"] = "yellow metal shiny shining explosion explosives blast burst boom fuse lit fire fiery burning hot heat lightning electricity sparks ball round spherical sphere",
	["spell_shadow_mindflay"] = "purple face shadowy webbed exploding explosion mouth spattered spattering splattered splattering opened head unholy evil magic power",
	["spell_shadow_mindrot"] = "pink red tauren hand fingers holding clutching squeezing brain bloody internal organs guts unholy",
	["spell_shadow_mindshear"] = "purple eyebrows night elf fel demonic creature magic power shadowy figure unholy spell:mind_sear(priest)",
	["spell_shadow_mindsteal"] = "brown pink human blinded eyebrow lazy eyed scarred cut stabbed wounded injured face spell:blind(rogue)",
	["spell_shadow_mindtwisting"] = "purple magic power spiraling swirly swirls lightbeams radiant radiance glowing tunnel entrance vortex talent:twisted_faith(priest)",
	["spell_shadow_misery"] = "green hand migraine headache stressful agony pain helmet armor talent:masochism(priest)",
	["spell_shadow_nethercloak"] = "purple shadowy cloaked hooded figure evil demonic creature ghost spirit warlock vile unholy apparition spell:cloak_of_shadows(rogue)",
	["spell_shadow_netherprotection"] = "green red yellow orange fire fiery burning hot heat flames flaming blazing scorching searing nature magic power barrier shield armor defense talent:nether_protection(warlock)",
	["spell_shadow_nightofthedead"] = "green moonlight hand reaching raised fingers clutching grasping undead undeath unholy zombie raising ghoul white nighttime midnight necromancy magic glowing enchanted enchantment evil scourge corpse",
	["spell_shadow_painandsuffering"] = "purple face mouth agony terror fear horror night elf glowing green eyes eyebrows unholy talent:pain_and_suffering(priest)",
	["spell_shadow_painfulafflictions"] = "light blue-green cyan purple melting pocketwatch clock acid dissolving goo bubbles metal corrosion time chronos speed tempo fast slowed stopped sped up destroyed destroying halted magic power",
	["spell_shadow_painspike"] = "purple arrowhead weapon spearhead pierce piercing puncture puncturing magic power talent:black_arrow(hunter) talent:sudden_doom(death_knight)",
	["spell_shadow_plaguecloud"] = "green posion goo vomiting dying zombie undead undeath unholy poisoned toxic diseased plagued teeth mouth head evil scourge corpse spell:pestilence(death_knight) talent:contagion(death_knight)",
	["spell_shadow_possession"] = "purple white gray grey pale glowing eyes demonic creature fel evil power magic sight vision posessed ghost spirit undead undeath head unholy scourge corpse apparition talent:premeditation(rogue) spell:fear(warlock) talent:improved_fear(warlock)",
	["spell_shadow_psychichorrors"] = "purple white gray grey pale yellow glowing eyes ghoul corpse undeath undead raised risen forsaken scourge head mouth yelling shouting screaming anger angry fury furious rage raging aggression unholy evil talent:psychic_horror(priest)",
	["spell_shadow_psychicscream"] = "blue wind air magic shouting screaming yelling horrified terrified afraid swirls spirals mouth power unholy spell:psychic_scream(priest) talent:improved_psychic_scream(priest)",
	["spell_shadow_ragingscream"] = "purple red shield defense protection blocking barrier magic blood drip droplet skull teeth mouth undeath undead creature power unholy evil scourge corpse face spell:demon_armor(warlock) talent:demonic_aegis(warlock)",
	["spell_shadow_rainoffire"] = "yellow orange red fiery burning hot heat flames flaming blazing scorching searing bolts missiles nukes magic spells power raining sky falling bombardment array fireballs tab:destruction(warlock) spell:rain_of_fire(warlock)",
	["spell_shadow_raisedead"] = "white gray grey skeleton skeletal skull undeath evil demonic creature necromancy risen bones magic power unholy scourge corpse head talent:lichborne(death_knight) racial:will_of_the_forsaken(undead)",
	["spell_shadow_requiem"] = "green fel demonic creature magic power hand claws fingers reaching grasping undead undeath glowing raise risen unholy evil talent:shadow_infusion(death_knight) talent:siphon_life(warlock)",
	["spell_shadow_ritualofsacrifice"] = "purple gray grey silver magic power fel steel metal dagger blade weapon knife stabbing striking holding hand arm glowing enchanted enchantment unholy evil spell:sinister_strike(rogue) talent:improved_sinister_strike(rogue)",
	["spell_shadow_rune"] = "purple demonic magic power of symbol glowing enchanted enchantment talent:runic_corruption(death_knight)",
	["spell_shadow_sacrificialshield"] = "red yellow bloody x cross winged wings flight flying canceled cancelled undone revoked destroyed removed magic power divine unholy",
	["spell_shadow_scourgebuild"] = "blue pale gray grey silver hand arm fingernails holding ball of lightbeams point spot casting undead symbol emblem sigil seal flag unholy talent:shadowburn(warlock)",
	["spell_shadow_sealofkings"] = "blue purple runes power symbols circle ritual crown emblem sigil magic royal talent:aura_of_foreboding(warlock)",
	["spell_shadow_seedofdestruction"] = "green purple stone glowing enchanted enchantment plant sowing death destructive demonic fel magic power unholy spell:seed_of_corruption(warlock) talent:soulburn:_seed_of_corruption(warlock)",
	["spell_shadow_shadesofdarkness"] = "purple trees brought to life shadowy magic power outlines silhouettes glowing eyes humanoid figures arms limbs summoned demonic creatures evil felwood forest unholy corrupted apparitions spell:ritual_of_souls(warlock)",
	["spell_shadow_shadetruesight"] = "purple yellow floating flying skulls undeath magic enchanted enchantment demonic creatures fel power necromancy glowing eyes unholy evil undead scourge corpses spirits ghosts apparitions heads talent:reaping(death_knight)",
	["spell_shadow_shadowandflame"] = "yellow orange red fire fiery burning hot heat flames flaming blazing scorching searing mouth breathing glowing eyes shadowy shadows figure masked belching burping exhaling unholy evil magic power talent:shadow_and_flame(warlock)",
	["spell_shadow_shadowbolt"] = "purple green felfire missile nuke magic power demonic unholy spell:shadow_bolt(warlock)",
	["spell_shadow_shadowembrace"] = "blue hands arms light aura glowing magic power casting holding conjuring talent:shadow_embrace(warlock)",
	["spell_shadow_shadowfiend"] = "purple glowing claws arm bones fel magic power swiping striking blightbeast flesh monster creature mana regeneration restoration unholy spell:shadowfiend(priest) talent:desecration(death_knight)",
	["spell_shadow_shadowform"] = "purple green glowing eyes face head shadowy figure demonic summoned creature magic power enchanted enchantment aura unholy evil talent:shadowform(priest)",
	["spell_shadow_shadowfury"] = "purple magic power swirly spiraling spikes spiky bear trap impact explosion blast burst tidal wave tsunami crater ocean sea liquid water splash surface vortex maelstrom talent:shadowfury(warlock)",
	["spell_shadow_shadowmend"] = "purple magic power spiraling swirly spirals twisting snowing snowflakes snowy sparkly sparkles vortex",
	["spell_shadow_shadowpact"] = "purple brown fel demonic magic power voodoo doll hexed cursed straw scarecrow evil figure unholy mastery:master_demonologist(warlock)",
	["spell_shadow_shadowpower"] = "purple blue magic head mouth glowing eyes lightbeams enchanted enchantment vision sight deathly undead undeath corpse unholy evil scourge talent:shadow_power(priest)",
	["spell_shadow_shadowward"] = "pink purple skull shadowy magic power symbol shadows images deception illusion unholy spell:evasion(rogue)",
	["spell_shadow_shadowworddominate"] = "yellow purple orange spiraling eyeball face glowing empowered magic controlled vision sight hypnotism hypnotised unholy talent:adrenaline_rush(rogue) spell:mind_control(priest)",
	["spell_shadow_shadowwordpain"] = "red orange yellow skull power undeath undead fire fiery burning hot heat flames flaming blazing scorching searing unholy evil scourge corpse tab:shadow_magic(priest) spell:shadow_word:_pain(priest) tab:shadow(priest) talent:improved_shadow_word:_pain(priest) talent:epidemic(death_knight)",
	["spell_shadow_siphonmana"] = "blue glowing eyes mouth spirits ghosts ethereal posession posessed demonic creature evil exorcism human head fel magic power draining stealing sucking siphoning life force unholy apparition talent:mind_flay(priest)",
	["spell_shadow_skull"] = "purple shadowy evil green glowing eyes face demonic creature magic power unholy sockets mouth undeath undead scourge corpse talent:mind_melt(priest)",
	["spell_shadow_soothingkiss"] = "pink green female lipstick kisssing of death poisonous toxic succubus glowing breathing exhaling whispering mouth seduction sexy unholy evil magic power",
	["spell_shadow_soulgem"] = "purple orb shiny glowing ball sphere circle gemstone conjured magic power aura spell:create_soulstone(warlock)",
	["spell_shadow_soulleech"] = "red bloody vomiting puking guts pink coughing mouth face unholy magic power talent:blood_parasite(death_knight)",
	["spell_shadow_soulleech_1"] = "green unholy magic power swirly spiraling vortex maelstrom liquid water stormy",
	["spell_shadow_soulleech_2"] = "blue magic power swirly spiraling vortex maelstrom liquid water stormy",
	["spell_shadow_soulleech_3"] = "purple glowing green eyes fangs mouth teeth shadowy figure magic power corpse undeath undead spirit demonic fel creature unholy evil scourge head spell:strangulate(death_knight) talent:soul_leech(warlock)",
	["spell_shadow_spectralsight"] = "yellow purple orange spiraling eyeball face glowing empowered magic mind controlled vision hypnotism hypnotised unholy talent:shadow_mastery(warlock)",
	["spell_shadow_summonfelguard"] = "red demonic creature magic power summoned horn head unholy evil talent:summon_felguard(warlock)",
	["spell_shadow_summonfelhunter"] = "red bloody magic demonic creature summoned beast teeth mouth unholy evil head spell:summon_felhunter(warlock)",
	["spell_shadow_summonimp"] = "red yellow green goblin teeth tusks eyes pointy nose mouth open yelling shouting evil chaotic chaos fire fiery burning hot heat flames flaming blazing scorching searing demonic fel power magic summoned creature face unholy talent:blood_craze(warrior) spell:summon_imp(warlock)",
	["spell_shadow_summoninfernal"] = "green yellow summoned creature demonic fel magic power rocks rocky fire fiery burning hot heat flames flaming blazing scorching searing head stone unholy evil spell:summon_infernal(warlock)",
	["spell_shadow_summonsuccubus"] = "purple summoned creature demonic fel magic power seduction sexy female horned horns glowing yellow eyes lipstick unholy evil head face spell:summon_succubus(warlock)",
	["spell_shadow_summonvoidwalker"] = "purple glowing eyes face head shadowy figure demonic summoned creature magic power enchanted enchantment aura unholy evil spell:summon_voidwalker(warlock)",
	["spell_shadow_teleport"] = "blue magic spot point blast burst explosion starlight lightbeams implosion power radiant radiance racial:arcane_torrent(blood_elf)",
	["spell_shadow_twilight"] = "purple landscape scenery background sky nighttime trees mountains hills clouds stars moon dusk starlight talent:endless_winter(death_knight) spell:ritual_of_summoning(warlock) talent:nightfall(warlock)",
	["spell_shadow_twistedfaith"] = "purple blue magic power naked body humanoid glowing lightbeams radiant radiance ghost spirit phantom apparition talent:phantasm(priest)",
	["spell_shadow_unholyfrenzy"] = "corpse undead undeath evil scourge yellow purple orange spiraling eyeball face glowing empowered magic controlled vision sight hypnotism hypnotised talent:enrage(warrior) spell:mind_blast(priest) talent:improved_mind_blast(priest) talent:unholy_frenzy(death_knight)",
	["spell_shadow_unholystrength"] = "silver red orange steel metal gauntlet glove armor hand fingers defense protection enchanted enchantment racial:stoneform(dwarf) talent:unholy_might(death_knight)",
	["spell_shadow_unstableaffliction_1"] = "light blue-green cyan purple melting pocketwatch clock acid dissolving goo bubbles metal corrosion time chronos speed tempo fast slowed stopped sped up destroyed destroying halted magic power",
	["spell_shadow_unstableaffliction_2"] = "green yellow golden melting pocketwatch clock acid dissolving goo bubbles metal corrosion time chronos speed tempo fast slowed stopped sped up destroyed destroying halted magic power",
	["spell_shadow_unstableaffliction_3"] = "red yellow orange humanoid yelling shouting mouth screaming pain suffering agony impact face unholy evil magic power talent:unstable_affliction(warlock)",
	["spell_shadow_unstableafllictions"] = "afflictions green yellow golden melting pocketwatch clock acid dissolving goo bubbles metal corrosion time chronos speed tempo fast slowed stopped sped up destroyed destroying halted magic power",
	["spell_shadow_unsummonbuilding"] = "blue runes of power magic hand symbols gray grey pale unholy talent:vampiric_embrace(priest)",
	["spell_shadow_vampiricaura"] = "bloody tooth fang claw animal creature orange lightbeams dripping soaked tusk unholy spell:shred(druid)",
	["spell_shaman_ancestralawakening"] = "blue ethereal glowing ghost spirit ancestor naked phantom magic power light humanoid arms chest apparition talent:ancestral_awakening(shaman)",
	["spell_shaman_astralshift"] = "blue ethereal glowing tauren cow bull horned horns furry animal creature beast male nosering ghost spirit ancestor head phantom magic power light apparition",
	["spell_shaman_bindelemental"] = "purple green chained chains missile nuke magic power bound bindings felfire shadowbolt shards stopped prevented spell:bind_elemental(shaman)",
	["spell_shaman_blessingofeternals"] = "green healing restoration gift touch bright lightbeams radiant radiance enchanted enchantment aura circle female humanoid maiden glowing magic power life talent:blessing_of_the_eternals(shaman)",
	["spell_shaman_blessingoftheeternals"] = "blue healing restoration gift touch bright lightbeams radiant radiance enchanted enchantment aura circle female humanoid maiden glowing magic power life",
	["spell_shaman_convection"] = "green explosion blast burst boom lightbeams sparks nature magic power talent:convection(shaman)",
	["spell_shaman_dropall_01"] = "red totem brown wooden placed elemental magic power spell:call_of_the_elements(shaman)",
	["spell_shaman_dropall_02"] = "blue totem brown wooden placed elemental elements magic power spell:call_of_the_ancestors(shaman)",
	["spell_shaman_dropall_03"] = "purple totem brown wooden placed elemental elements magic power spell:call_of_the_spirits(shaman)",
	["spell_shaman_earthlivingweapon"] = "green silver nature natural steel metal growing life flowering blossoming blooming leaves vines entangling enchanted enchantment empowered sword blade dagger knife glowing magic",
	["spell_shaman_earthquake"] = "brown ground cracked torn asunder tear rift cracks jagged ripped apart open rocks rocky dirt soil shaking magic power talent:earthquake(shaman)",
	["spell_shaman_elementaloath"] = "blue lightbeams glowing ritual cloaked hooded shadowy figures gathered gathering spirits ghosts apparitions phantoms robes magic powerful unholy evil talent:elemental_oath(shaman)",
	["spell_shaman_feralspirit"] = "wolves canines dogs worgs animals furry creatures beasts purple blue glowing snarling growling anger angry fury furious rage raging aggression baring teeth heads talent:feral_spirit(shaman)",
	["spell_shaman_firenova"] = "red orange yellow fiery burning hot heat flames flaming blazing scorching searing magic power blast burst explosion rocks spell:fire_nova(shaman)",
	["spell_shaman_focusedstrikes"] = "blue silver lightning magic nature imbued enchanted enchantment empowered steel metal hammer mace weapon thunder electricity talent:focused_strikes(shaman)",
	["spell_shaman_giftearthmother"] = "red pink green yellow flower blossoming blooming leaves stem glowing enchanted enchantment bright light radiant radiance life growing healing restoration magic power talent:malfurion's_gift(druid)",
	["spell_shaman_hex"] = "green toad eyes surprised transformed transformation animal creature magic voodoo power head spell:hex(shaman) companion:tree_frog",
	["spell_shaman_improvedearthshield"] = "yellow red glowing radiant radiance nature magic power elemental barrier enchanted enchantment skin armor defense protection blocking hardened plated plates",
	["spell_shaman_improvedfirenova"] = "red orange yellow fiery burning hot heat flames flaming blazing scorching searing magic power blast burst explosion rocks",
	["spell_shaman_improvedreincarnation"] = "purple flexing humanoid shadowy figure outline silhouette strong radiant radiance enchanted enchantment powerful glowing muscles bodybuilding empowered magic passive:reincarnation(shaman)",
	["spell_shaman_improvedstormstrike"] = "purple silver steel metal mace weapon enchanted enchantment empowered magic spell:unleash_elements(shaman)",
	["spell_shaman_improvelavalash"] = "hammer mace weapon fire fiery burning hot heat flames flaming blazing scorching searing ice icy cold frozen freezing frosty elements elemental smashing swinging moving motion nature's power magic enchanted enchantment red yellow orange blue talent:improved_lava_lash(shaman)",
	["spell_shaman_lavaburst"] = "yellow orange red fire fiery burning hot heat flames flaming blazing scorching searing magma rocks rocky molten explosion blast earth erupting magic power volcano spell:lava_burst(shaman)",
	["spell_shaman_lavaflow"] = "yellow orange fire fiery burning hot heat flames flaming blazing scorching searing molten volcano rocky rocks mountain flowing liquid erupting magic power talent:lava_flows(shaman)",
	["spell_shaman_lavasurge"] = "yellow orange fire fiery burning hot heat flames flaming blazing scorching searing magma liquid exploding blowing blasting bursting rocks erupting volcano magic power talent:lava_surge(shaman)",
	["spell_shaman_maelstromweapon"] = "purple blue scepter staff magic enchanted enchantment empowered lightning thunder elemental electricity talent:maelstrom_weapon(shaman)",
	["spell_shaman_measuredinsight"] = "blue circles spiraling glowing light ball sphere liquid water magic power vortex maelstrom talent:focused_insight(shaman)",
	["spell_shaman_primalstrike"] = "silver blue steel metal hammer mace weapon hitting impacting emblem spell:primal_strike(shaman)",
	["spell_shaman_spectraltransformation"] = "purple glowing threads of fate stars cosmos cosmic space swirling twisting nether spectre phantom lights magic power talent:primal_wisdom(shaman)",
	["spell_shaman_spiritlink"] = "green glowing ring ritual pact friendship bond hands tauren troll humanoid magic power talent:spirit_link_totem(shaman) talent:blessing_of_the_grove(druid)",
	["spell_shaman_spiritwalkersgrace"] = "green boots glowing enchanted enchantment lightbeams fast running walking speed swiftness magic power spell:spiritwalker's_grace(shaman)",
	["spell_shaman_staticshock"] = "blue summoned lightning golem thunder humanoid creature electricity power magic stunned shocked shocking surrounded crackle crackling talent:static_shock(shaman)",
	["spell_shaman_stormearthfire"] = "red yellow orange firestorm fiery burning hot heat flames flaming blazing scorching searing tornado vortex whirlwind jagged shards rocks windy gusts gusty winds elemental magic power",
	["spell_shaman_thunderstorm"] = "blue orange sky lightning thunderbolt jagged electricity shock elemental magic power crackle crackling striking hitting talent:thunderstorm(shaman)",
	["spell_shaman_tidalwaves"] = "blue moonlight tsunami ocean sea sky landscape scenerey background nighttime magic power talent:tidal_waves(shaman)",
	["spell_shaman_totemrecall"] = "gray grey brown wooden placed elemental elements magic power recalled recalling windy winds spell:totemic_recall(shaman)",
	["spell_shaman_unleashweapon_earth"] = "ground brown silver hammer mace steel metal glowing enchanted enchantment impacting hitting magic power spell:rockbiter_weapon(shaman)",
	["spell_shaman_unleashweapon_flame"] = "fire fiery burning hot heat flames flaming blazing scorching searing red silver hammer mace steel metal glowing enchanted enchantment impacting hitting magic power spell:flametongue_weapon(shaman)",
	["spell_shaman_unleashweapon_frost"] = "ice icy cold frozen freezing frosty blue silver hammer mace steel metal glowing enchanted enchantment impacting hitting magic power spell:frostbrand_weapon(shaman)",
	["spell_shaman_unleashweapon_life"] = "green nature healing restoration silver hammer mace steel metal glowing enchanted enchantment impacting hitting magic power spell:earthliving_weapon(shaman)",
	["spell_shaman_unleashweapon_wind"] = "white blue winds windy air silver hammer mace steel metal glowing enchanted enchantment impacting hitting magic power spell:windfury_weapon(shaman)",
	["spell_totem_wardofdraining"] = "red white bloody skull bones voodoo",
	["spell_unused"] = "green glowing lightbeams division line poison toxic magic power",
	["spell_unused2"] = "blue humanoid creature blowing noise sound moonlight nighttime midnight starry stars sky horned horns calling summoning talent:shamanism(shaman)",
	["spell_warlock_demonsoul"] = "purple shadowy unholy figure outline silhouette fire fiery burning hot heat flames flaming blazing scorching searing magic power enchanted enchantment spirit phantom ghost apparition humanoid creature evil spell:demon_soul(warlock)",
	["spell_warlock_focusshadow"] = "purple hands holding ball of light magic power shadowflame essence spirit ghost wisp apparition spell:dark_intent(warlock)",
	["spell_warlock_soulburn"] = "purple skull undead undeath fire fiery burning hot heat flames flaming blazing scorching searing fel shadow magic power apparition phantom ghost spirit eyes sockets teeth demonic creature unholy evil scourge corpse face head spell:soulburn(warlock)",
	["spell_yorsahj_bloodboil_black"] = "white grey gray liquid boiling bubbles bubbling goo pool steaming magic heated boiled surface",
	["spell_yorsahj_bloodboil_blue"] = "liquid boiling bubbles bubbling goo pool steaming magic heated boiled surface",
	["spell_yorsahj_bloodboil_green"] = "poison disease liquid boiling bubbles bubbling goo pool steaming magic heated boiled surface",
	["spell_yorsahj_bloodboil_purple"] = "curse poison liquid boiling bubbles bubbling goo pool steaming magic heated boiled surface",
	["spell_yorsahj_bloodboil_yellow"] = "liquid boiling bubbles bubbling goo pool steaming magic heated boiled surface",
}
